@@ -40,6 +40,8 @@
 
 #undef HAVE_ASINH
 
+#undef HAVE_ATANH
+
 #undef HAVE_CBRT
 
 #undef HAVE_DREM
@@ -67,7 +69,23 @@
 
 #undef HAVE_KEYPAD
 
+#undef HAVE_LIBSDB
+
 #undef HAVE_LIB_T1
 
 #undef HAVE_LIB_T1X
 
+#undef HAVE_VSNPRINTF
+
+#undef HAVE_LIBXEXT
+
+#undef HAVE_LIBXMU
+
+#undef HAVE_LIBMOWITZ
+
+#undef HAVE_LIBXPM
+
+#undef HAVE_LIBGUILE
+#undef HAVE_LIBPYTHON
+#undef HAVE_LIBRUBY
+#undef HAVE_LIBTCL
