@@ -1,6 +1,6 @@
 /*
    Egon Animator
-   Copyright (C) 1997  Ulric Eriksson <ulric@edu.stockholm.se>
+   Copyright (C) 1997-2002  Ulric Eriksson <ulric@siag.nu>
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -37,10 +37,9 @@
 #include <unistd.h>
 
 #include "egon.h"
-#include "types.h"
 #include "user_interface.h"
 #include "../common/common.h"
-#include "../common/cmalloc.h"
+#include <Mowitz/MwUtils.h>
 
 /* ---
 Returns: 0 if successful, otherwise 1
