@@ -1,6 +1,6 @@
 /*
    Egon Animator
-   Copyright (C) 1997  Ulric Eriksson <ulric@edu.stockholm.se>
+   Copyright (C) 1997-2002  Ulric Eriksson <ulric@siag.nu>
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -18,7 +18,8 @@
    MA 02111-1307, USA.
  */
 
-#ifdef GUILE
+#include "../config.h"
+#ifdef HAVE_LIBGUILE
 
 /*
  * guilei.c
@@ -26,6 +27,7 @@
 
 #include <stdio.h>
 #include <stdlib.h>
+#include <string.h>
 #include <ctype.h>
 #include <time.h>
 #include <signal.h>
@@ -38,7 +40,6 @@
 #include <guile/gh.h>
 
 static int siag_row, siag_col;
-static ani_object *siag_matrix;
 
 static int guile_interpreter;
 
@@ -87,7 +88,6 @@ void execute_guile(char *s)
 		hide_cur(w_list);
 	siag_row = 1;
 	siag_col = 1;
-	siag_matrix = w_list->buf->cast;
 	gh_catch(SCM_BOOL_T,
 			(scm_catch_body_t)wrapper, s,
 			(scm_catch_handler_t)catcher, s);
@@ -111,6 +111,9 @@ int init_guile_parser()
 }
 
 #else
-int guile_dummy;
+int init_guile_parser(void)
+{
+        return -1;
+}
 #endif	/* GUILE */
 
