@@ -1,6 +1,6 @@
 /*
    Siag, Scheme In A Grid
-   Copyright (C) 1999  Ulric Eriksson <ulric@edu.stockholm.se>
+   Copyright (C) 1999-2002  Ulric Eriksson <ulric@siag.nu>
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -18,7 +18,8 @@
    MA 02111-1307, USA.
  */
 
-#ifdef PYTHON
+#include "../config.h"
+#ifdef HAVE_LIBPYTHON
 
 /*
  * pythoni.c
@@ -34,7 +35,7 @@
 
 #include "egon.h"
 
-#include <python1.5/Python.h>
+#include "Python.h"
 
 static buffer *siag_buffer;
 
@@ -62,6 +63,9 @@ int init_python_parser(void)
 			NULL, exec_python);
 }
 #else
-int python_is_not_used;
+int init_python_parser(void)
+{
+        return -1;
+}
 #endif	/* PYTHON */
 
