@@ -1,6 +1,6 @@
 /*
    Egon Animator
-   Copyright (C) 1997  Ulric Eriksson <ulric@edu.stockholm.se>
+   Copyright (C) 1997-2002  Ulric Eriksson <ulric@siag.nu>
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -26,8 +26,6 @@
 #include <stdlib.h>
 #include <ctype.h>
 
-#include "types.h"
-
 #include "egon.h"
 #include "../siod/siod.h"
 #include "../common/common.h"
@@ -40,17 +38,17 @@ extern void init_tar(void);
 /* from slib.c */
 extern char *repl_c_string_arg;
 extern long repl_c_string_flag;
-extern LISP repl_c_string_read();
+extern LISP repl_c_string_read(void);
 
 static int siag_row, siag_col;
 
-static LISP get_row()
+static LISP get_row(void)
 {
 	double drow = siag_row;
 	return flocons(drow);
 }
 
-static LISP get_col()
+static LISP get_col(void)
 {
 	double dcol = siag_col;
 	return flocons(dcol);
@@ -97,7 +95,7 @@ void execute_siod(char *s)
 		show_cur(w_list);
 }
 
-static LISP set_pr_scr()
+static LISP set_pr_scr(void)
 {
 	pr_scr_flag = TRUE;
 	return NIL;
@@ -117,7 +115,7 @@ static char *siod_argv[] = {
   "-h20000:10",	/* 100000:10 */
   "-g0",
   "-o1000",
-  "-s100000",	/* 200000 */
+  "-s200000",	/* 200000 */
   "-n2048"};
 static int siod_argc = sizeof siod_argv / sizeof siod_argv[0];
 
