@@ -1,6 +1,6 @@
 /*
    Egon Animator
-   Copyright (C) 1997  Ulric Eriksson <ulric@edu.stockholm.se>
+   Copyright (C) 1997-2000  Ulric Eriksson <ulric@siag.nu>
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -19,8 +19,9 @@
  */
 
 extern int alert_box(char *, char **, int);
-
-extern int select_file(char *, char *, char **, char *);
+extern void about_box(char *);
+extern void about_siag(void);
+extern int select_file(char *, char *, char **, char *, int);
 extern int alert_box(char *, char **, int);
 extern int select_from_list(char *, char **, int);
 extern void error_box(char *);
