@@ -1,6 +1,6 @@
 /*
    image.c
-   Copyright (C) 1997-1999  Ulric Eriksson <ulric@edu.stockholm.se>
+   Copyright (C) 1997-2001  Ulric Eriksson <ulric@siag.nu>
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -27,19 +27,20 @@
 #include <X11/Shell.h>
 #include <X11/xpm.h>
 #include "../common/common.h"
-#include "../common/cmalloc.h"
 #include "../common/bitmaps/image.xpm"
-#include "../xcommon/Image.h"
-#include "../xcommon/icon.h"
+#include <Mowitz/Mowitz.h>
 
 typedef struct {
 	Boolean plugin;
+	Boolean fit;
 } AppData;
 
 static AppData app_data;
 
 #define XtNplugin "plugin"
 #define XtCPlugin "Plugin"
+#define XtNfit "fit"
+#define XtCFit "Fit"
 
 static XtResource resources[] = {
 	{
@@ -50,11 +51,21 @@ static XtResource resources[] = {
 		XtOffsetOf(AppData, plugin),
 		XtRImmediate,
 		(XtPointer)False,
+	},
+	{
+		XtNfit,
+		XtCFit,
+		XtRBoolean,
+		sizeof(Boolean),
+		XtOffsetOf(AppData, fit),
+		XtRImmediate,
+		(XtPointer)False
 	}
 };
 
 static XrmOptionDescRec options[] = {
-	{"-plugin", "*plugin", XrmoptionNoArg, "True"}
+	{"-plugin", "*plugin", XrmoptionNoArg, "True"},
+	{"-fit", "*fit", XrmoptionNoArg, "True"}
 };
 
 static Atom wm_delete_window;
@@ -136,10 +147,10 @@ static void prnt(char *p)
 		return;
 	}
 	sscanf(data[0], "%d %d %d %d", &width, &height, &ncolors, &cpp);
-	cm = (colors *)cmalloc(ncolors*sizeof(colors));
+	cm = (colors *)MwMalloc(ncolors*sizeof(colors));
 
 	for (i = 0; i < ncolors; i++) {
-		cm[i].chars = (char *)cmalloc(cpp);
+		cm[i].chars = (char *)MwMalloc(cpp);
 		memcpy(cm[i].chars, data[i+1], cpp);
 		key = strtok(data[i+1]+cpp, " \t");	/* skip past chars */
 		color = strtok(NULL, " \t");
@@ -212,14 +223,11 @@ static void prnt(char *p)
 	/* print postscript postblurb */
 	printf(" %%\n");
 	printf(" grestore\n");
-#if 0
-	printf(" %%%%Trailer\n");
-#endif
 	printf("END\n");
 
-	for (i = 0; i < ncolors; i++) cfree(cm[i].chars);
-	cfree(cm);
-	cfree(data);
+	for (i = 0; i < ncolors; i++) MwFree(cm[i].chars);
+	MwFree(cm);
+	MwFree(data);
 }
 
 static struct {
@@ -287,15 +295,16 @@ void mainloop(void)
 int main(int argc, char **argv)
 {
 	Window root;
-	int x, y, width, height, border, depth;
+	int x, y, width, height, rw, rh, border, depth;
 	Dimension ow, oh;
 	XtAppContext ac;
 	char b[1024];
-	char *tmpfile = "/tmp/siagimage.xpm";
+	char tmpfile[1024];
 	int n;
 	char *fn = NULL;
 
 	common_init(NULL);
+	sprintf(tmpfile, "%s/siagimage.xpm", siag_tmpdir);
 
 	topLevel = XtVaAppInitialize(&ac, "Image",
 		options, XtNumber(options),
@@ -322,7 +331,7 @@ int main(int argc, char **argv)
 	xa.exactColors = FALSE;
 	xa.valuemask = XpmCloseness | XpmExactColors;
 
-	sprintf(b, "%s/common/any2xpm %s > %s",
+	sprintf(b, "%s/common/any2xpm \"%s\" > \"%s\"",
 		datadir, fn, tmpfile);
 	system(b);
 
@@ -339,9 +348,21 @@ int main(int argc, char **argv)
 	XGetGeometry(XtDisplay(topLevel), pixmap, &root,
 		&x, &y, &width, &height, &border, &depth);
 
+	XGetGeometry(XtDisplay(topLevel), root, &root,
+		&x, &y, &rw, &rh, &border, &depth);
+
 	XGetGeometry(XtDisplay(topLevel), pixmap, &root,
 		&x, &y, &width, &height, &border, &depth);
 
+	/* scale to fit */
+	if (app_data.fit && (width > rw || height > rh)) {
+		double dw = (double)width/(double)rw;
+		double dh = (double)(height+30)/(double)rh;
+		double d = (dw > dh)?dw:dh;
+		width /= d;
+		height /= d;
+	}
+
 	XtVaGetValues(topLevel,
 		XtNwidth, &ow,
 		XtNheight, &oh,
@@ -351,18 +372,19 @@ int main(int argc, char **argv)
 		ow = width;
 		oh = height;
 	}
+
 	XtVaSetValues(topLevel,
 		XtNwidth, ow,
 		XtNheight, oh,
 		XtNborderWidth, 0,
 		(char *) 0);
 	image = XtVaCreateManagedWidget("image",
-		imageWidgetClass, topLevel,
+		mwImageWidgetClass, topLevel,
 		XtNbitmap, pixmap,
 		(char *)0);
 
 	XtRealizeWidget(topLevel);
-	icon_set(topLevel, image_xpm);
+	MwSetIcon(topLevel, image_xpm);
 	wm_delete_window = XInternAtom(XtDisplay(topLevel),
 				"WM_DELETE_WINDOW", False);
 	XtOverrideTranslations(topLevel,
