@@ -1,6 +1,6 @@
 /*
    Dummy Plugin
-   Copyright (C) 1997, 1998  Ulric Eriksson <ulric@edu.stockholm.se>
+   Copyright (C) 1997, 1998  Ulric Eriksson <ulric@siag.nu>
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -36,7 +36,7 @@ extern void init_tar(void);
 /* from slib.c */
 extern char *repl_c_string_arg;
 extern long repl_c_string_flag;
-extern LISP repl_c_string_read();
+extern LISP repl_c_string_read(void);
 
 static void siag_puts(char *p)
 {
