@@ -1,6 +1,6 @@
 /*
    Pathetic Writer
-   Copyright (C) 1997-1999  Ulric Eriksson <ulric@edu.stockholm.se>
+   Copyright (C) 1997-2002  Ulric Eriksson <ulric@siag.nu>
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -34,7 +34,7 @@ functions.
 #include <sys/time.h>
 #include <sys/types.h>
 
-#include "../common/cmalloc.h"
+#include <Mowitz/MwUtils.h>
 #include "../common/common.h"
 #include "../common/plugin.h"
 #include "pw.h"
@@ -42,10 +42,18 @@ functions.
 
 typedef struct {
 	char *name;
-	 LISP(*function) ();
-} s_fn_table;
+	 LISP(*function) (void);
+} s_fn_table0;
 
-extern s_fn_table fn_table[];
+typedef struct {
+	char *name;
+	 LISP(*function) (LISP);
+} s_fn_table1;
+
+typedef struct {
+	char *name;
+	 LISP(*function) (LISP, LISP);
+} s_fn_table2;
 
 /* moving around */
 
@@ -100,23 +108,9 @@ static LISP remove_line(void)
 
 /* ---
 */
-static LISP spawn(LISP command)
+static LISP lspawn(LISP command)
 {
-	char *argv[20], *p, cmd[1024];
-	int argc = 0;
-
-	strcpy(cmd, get_c_string(command));
-	for (p = strtok(cmd, " \t\r\n");
-		p && argc < 20;
-		p = strtok(NULL, " \t\r\n")) {
-		argv[argc++] = p;
-	}
-	argv[argc] = NULL;
-	if (!fork()) {
-		/* this is the child */
-		execvp(argv[0], argv);
-		exit(0);
-	}
+	MwSpawn(get_c_string(command));
 	return NIL;
 }
 
@@ -143,7 +137,7 @@ static LISP load_buffer(void)
 	}
 	strcpy(name, "");
 	fn[0] = '\0';
-	if (select_file(path, name, loader_patterns, fmt)) {
+	if (select_file(path, name, loader_patterns, fmt, 0)) {
 		sprintf(fn, "%s/%s", path, name);
 		b = new_buffer(buffer_name(fn), fn);
 		llpr("Loading");
@@ -153,6 +147,7 @@ static LISP load_buffer(void)
 
 		b->change = FALSE;
 		w_list->buf = b;
+		w_list->sht = 0;
 		pr_scr_flag = TRUE;
 	}
 	activate_window(w_list);
@@ -163,7 +158,7 @@ static LISP load_buffer(void)
 Load using an external program
 
    1. Ask for the program to use
-   2. Run the program and save output to file in /tmp
+   2. Run the program and save output to file in siag_tmpdir
    3. Load the file using NULL format (i.e. ask for type)
 */
 
@@ -189,8 +184,8 @@ static LISP load_external(void)
 		while (!feof(fp) && loaders < 20) {
 			fgets(b, 250, fp);
 			if ((p = strtok(b, ":")) && (q = strtok(NULL, "\n"))) {
-				loadname[loaders] = cstrdup(p);
-				loadprog[loaders] = cstrdup(q);
+				loadname[loaders] = MwStrdup(p);
+				loadprog[loaders] = MwStrdup(q);
 				loaders++;
 			}
 		}
@@ -202,7 +197,7 @@ static LISP load_external(void)
 			loadname, loaders);
 
 	if (i >= 0 && ask_for_str("Parameters:", param)) {
-		sprintf(fn, "/tmp/pw%ld", (long)getpid());
+		sprintf(fn, "%s/pw%ld", siag_tmpdir, (long)getpid());
 		sprintf(cmd, "%s %s > %s", loadprog[i], param, fn);
 		if (system(cmd)) {
 			llpr("External program failed");
@@ -217,6 +212,7 @@ static LISP load_external(void)
 
 		b->change = FALSE;
 		w_list->buf = b;
+		w_list->sht = 0;
 		pr_scr_flag = TRUE;
 	}
 	activate_window(w_list);
@@ -332,7 +328,7 @@ static LISP save_buffer_as(void)
 	if (p) strcpy(name, p+1);
 	else strcpy(name, w_list->buf->path);
 	fn[0] = '\0';
-	if (select_file(path, name, saver_patterns, fmt)) {
+	if (select_file(path, name, saver_patterns, fmt, 1)) {
 		sprintf(fn, "%s/%s", path, name);
 		llpr("Saving");
 		if (savematrix(fn, w_list->buf, fmt))
@@ -350,7 +346,7 @@ static LISP save_buffer_as(void)
 Save using an external program
 
    1. Ask for the program to use
-   2. Save to a file in /tmp using NULL format (i.e. ask for type)
+   2. Save to a file in siag_tmpdir using NULL format (i.e. ask for type)
    3. Run the program and read the file as input
 */
 
@@ -375,8 +371,8 @@ static LISP save_external(void)
 		while (!feof(fp) && savers < 20) {
 			fgets(b, 250, fp);
 			if ((p = strtok(b, ":")) && (q = strtok(NULL, "\n"))) {
-				savename[savers] = cstrdup(p);
-				saveprog[savers] = cstrdup(q);
+				savename[savers] = MwStrdup(p);
+				saveprog[savers] = MwStrdup(q);
 				savers++;
 			}
 		}
@@ -390,7 +386,7 @@ static LISP save_external(void)
 	if (i >= 0 && ask_for_str("Parameters:", param)) {
 		llpr("Saving");
 
-		sprintf(fn, "/tmp/pw%ld", (long)getpid());
+		sprintf(fn, "%s/pw%ld", siag_tmpdir, (long)getpid());
 		if (savematrix(fn, w_list->buf, NULL)) {
 			error_box("Couldn't save");
 			return NIL;
@@ -518,17 +514,34 @@ static LISP lalertbox(LISP prompt, LISP buttons)
 
 	while (bno < 10 && NNULLP(buttons)) {
 		char *c = get_c_string(car(buttons));
-		if (c) btext[bno] = cstrdup(c);
-		else btext[bno] = cstrdup("button");
+		if (c) btext[bno] = MwStrdup(c);
+		else btext[bno] = MwStrdup("button");
 		buttons = cdr(buttons);
 		bno++;
 	}
 	if (p == NULL) p = "prompt";
 	n = alert_box(p, btext, bno);
-	while (bno) cfree(btext[--bno]);
+	while (bno) MwFree(btext[--bno]);
 	return flocons(n);
 }
 
+static LISP laboutbox(void)
+{
+        char msg[1024];
+        sprintf(msg, "%s\n\n%s\n\nUlric Eriksson, ulric@siag.nu\n\n%s\n",
+		version,
+		_("A word processor for X"),
+		_("Part of Siag Office"));
+        about_box(msg);
+        return NIL;
+}
+ 
+static LISP laboutsiag(void)
+{
+        about_siag();
+        return NIL;
+}
+
 /* ---
 */
 static LISP quit_pw(void)
@@ -537,7 +550,7 @@ static LISP quit_pw(void)
 	buffer *b = b_list;
 	do {
 		if (b->change /*&& !plugin*/) {
-			sprintf(prompt, translate("Save %s?"), b->name);
+			sprintf(prompt, _("Save %s?"), b->name);
 			switch (alert_box(prompt, quit_buttons, 3)) {
 			case 0:
 				savematrix(b->path, b, NULL);
@@ -591,7 +604,7 @@ static LISP set_line_height(void)
 	sheet *st = w_list->buf->sht;
 
 	sprintf(b, "%d", line_height(w_list->buf, s, st[s].point_pos.row));
-	if (ask_for_str("Height: ", b))
+	if (ask_for_str("Height:", b))
 		height = atoi(b);
 
 	if (height > 5 && height < 200) {
@@ -633,15 +646,15 @@ static LISP define_style(void)
 	sheet *st = w_list->buf->sht;
 	int r = st[w_list->sht].point_pos.row;
 	int sty = ret_style(w_list->buf, w_list->sht, r);
-	sfmt fmt;
+	MwFmt fmt;
 	style s;
 
-	decode_format(w_list->current_fmt, ~0, &fmt);
+	MwDecodeFormat(w_list->current_fmt, ~0, &fmt);
 	s = style_table[fmt.style];
 	lookup_style(s.name, style2name(s.follower),
 		fmt.family, fmt.size, fmt.bold, fmt.italic,
-		fmt.uline, fmt.fg);
-	sprintf(b, translate("Style %s changed"), style_table[sty].name);
+		fmt.uline, fmt.strike, fmt.fg);
+	sprintf(b, MwTranslate("Style %s changed"), style_table[sty].name);
 	llpr(b);
 	return NIL;
 }
@@ -659,7 +672,7 @@ static LISP cleanup_style(void)
 
 	for (r = 1; r <= line_last_used(b, s); r++) {
 		if (ret_style(b, s, r) == sty) {
-			ins_format(b, s, r, 0, rc_strlen(b->sht[s].text[r].p), fmt);
+			ins_format(b, s, r, 0, MwRcStrlen(b->sht[s].text[r].p), fmt);
 			b->sht[s].text[r].height = check_line_height(b, s, r);
 			b->change = TRUE;
 			pr_scr_flag = TRUE;
@@ -716,7 +729,7 @@ Ispell doesn't have a mode in which every line read on stdin
 is treated as a single word, regardless of character set.
 I consider this to be a bug in ispell.
 
-Before running the checker, PW should offer to save the buffer.
+Before running the checker, PW offers to save the buffer.
 
 This is still only a test version. Error checking is mostly
 missing.
@@ -778,7 +791,7 @@ static LISP dump_words(void)
 
 	if (row > line_last_used(buf, s)) return NIL;
 
-	p = (char *)rc_makeplain(buf->sht[s].text[row].p);
+	p = (char *)MwRcMakeplain(buf->sht[s].text[row].p);
 	llpr(p);
 
 	for (i = 0; p[i]; i++) {
@@ -800,7 +813,7 @@ static LISP dump_words(void)
 		b[end-start+1] = '\0';
 		fprintf(stderr, "%s\n", b);
 	}
-	cfree(p);
+	MwFree(p);
 	return NIL;
 }
 
@@ -837,8 +850,8 @@ static int spell_word(buffer *buf, char *p, int s, unsigned int r,
 		strcpy(d, b);
 	}
 	n = spell_select(b, d);
-	chomp(b);
-	chomp(d);
+	MwChomp(b);
+	MwChomp(d);
 	switch (n) {
 	case SPELL_REPLACE:
 		/* replace in the buffer */
@@ -882,12 +895,12 @@ static int spell_line(buffer *buf, int s, unsigned int r)
 	char b[1024];
 	int i, start = -1, end = -1;
 
-	if (ret_style(buf, s, r) == STY_EMBED) return 0;
+	if (ret_style(buf, s, r) == MW_STY_EMBED) return 0;
 	p = (char *)peek_line(buf, s, r);
 	if (!p) return 1;
 	strncpy(b, p, 1020);
 	b[1020] = '\0';
-	cfree(p);
+	MwFree(p);
 	llpr(b);	/* display it so we know where we are */
 
 	for (i = 0; b[i]; i++) {
@@ -925,7 +938,8 @@ static LISP spell_buffer(void)
 
 	if (b->change) {
 		char prompt[1024];
-		sprintf(prompt, "Save %s before checking spelling?", b->name);
+		sprintf(prompt, _("Save %s before checking spelling?"),
+			b->name);
 		switch(alert_box(prompt, quit_buttons, 3)) {
 		case 0:
 			savematrix(b->path, b, NULL);
@@ -1136,7 +1150,7 @@ static LISP lset_style(LISP row, LISP sty)
 	w_list->current_fmt = fmt;
 	set_style(buf, sht, r, s);
 	buf->change = TRUE;
-	ins_format(buf, sht, r, 0, rc_strlen(buf->sht[sht].text[r].p), fmt);
+	ins_format(buf, sht, r, 0, MwRcStrlen(buf->sht[sht].text[r].p), fmt);
 	pr_scr_flag = TRUE;
 	return NIL;
 }
@@ -1353,7 +1367,7 @@ static LISP lpack_area(LISP r1, LISP c1, LISP r2, LISP c2)
         b = pack_area(w_list->buf, w_list->sht, get_c_long(r1), get_c_long(c1),
                 get_c_long(r2), get_c_long(c2), &size);
         result = strcons(size, b);
-        cfree(b);
+        MwFree(b);
         return result;
 }
 
@@ -1366,58 +1380,6 @@ static LISP lunpack_area(LISP b, LISP r, LISP c)
         return NIL;
 }
 
-
-/* ---
-*/
-static LISP lregister_x_font(LISP name, LISP x, LISP xi, LISP xb, LISP xbi)
-{
-	return flocons(register_x_font(get_c_string(name),
-					get_c_string(x),
-					get_c_string(xi),
-					get_c_string(xb),
-					get_c_string(xbi)));
-}
-
-/* ---
-*/
-static LISP lregister_ps_font(LISP name, LISP x, LISP xi, LISP xb, LISP xbi)
-{
-	return flocons(register_ps_font(get_c_string(name),
-					get_c_string(x),
-					get_c_string(xi),
-					get_c_string(xb),
-					get_c_string(xbi)));
-}
-
-/* ---
-*/
-static LISP lregister_t1_font(LISP name, LISP x, LISP xi, LISP xb, LISP xbi)
-{
-	return flocons(register_t1_font(get_c_string(name),
-					get_c_string(x),
-					get_c_string(xi),
-					get_c_string(xb),
-					get_c_string(xbi)));
-}
-
-/* ---
-*/
-static LISP lfont_alias(LISP alias, LISP name)
-{
-	return flocons(font_alias(get_c_string(alias),
-				get_c_string(name)));
-}
-
-/* ---
-*/
-static LISP lregister_color(LISP name, LISP r, LISP g, LISP b)
-{
-	return flocons(register_color(get_c_string(name),
-					get_c_long(r),
-					get_c_long(g),
-					get_c_long(b)));
-}
-
 /* ---
 */
 static LISP ladd_sheet(void)
@@ -1511,7 +1473,7 @@ ap is a list of 9 arguments
 static LISP lregister_style_wrapper(LISP ap)
 {
 	char *name, *next, *family, *fg;
-	int size, b, i, u;
+	int size, b, i, u, s;
 
 	name = get_c_string(CAR(ap));
 	ap = CDR(ap);
@@ -1527,9 +1489,11 @@ static LISP lregister_style_wrapper(LISP ap)
 	ap = CDR(ap);
 	u = get_c_long(CAR(ap));
 	ap = CDR(ap);
+	s = get_c_long(CAR(ap));
+	ap = CDR(ap);
 	fg = get_c_string(CAR(ap));
 
-	return flocons(lookup_style(name, next, family, size, b, i, u, fg));
+	return flocons(lookup_style(name, next, family, size, b, i, u, s, fg));
 }
 
 static LISP ldebug_format(void)
@@ -1539,17 +1503,25 @@ static LISP ldebug_format(void)
 	sheet *st = b->sht;
 	int r = st[s].point_pos.row;
 	int c = st[s].point_pos.col;
-	sfmt fmt;
+	MwFmt fmt;
 	int f = ret_format(b, s, r, c);
-	decode_format(f, ~0, &fmt);
-	fprintf(stderr, "%s %d %s%s%s%s%s %s/%s\n",
+	char *hadj;
+	MwDecodeFormat(f, ~0, &fmt);
+	switch (fmt.hadj) {
+	case MW_HADJ_LEFT:		hadj = "left "; break;
+	case MW_HADJ_CENTER:	hadj = "center "; break;
+	case MW_HADJ_RIGHT:	hadj = "right "; break;
+	case MW_HADJ_FULL:		hadj = "full "; break;
+	default:		hadj = "ERROR "; break;
+	}
+	fprintf(stderr, "%s %d %s%s%s%s%s%s %s/%s\n",
 			fmt.family,
 			fmt.size,
 			fmt.bold?"bold ":"",
 			fmt.italic?"italic ":"",
 			fmt.uline?"uline ":"",
-			fmt.hadj==HADJ_LEFT?"left ":
-				(fmt.hadj==HADJ_CENTER?"center ":"right "),
+			fmt.strike?"strike ":"",
+			hadj,
 			style2name(fmt.style),
 			fmt.fg,
 			fmt.bg);
@@ -1563,44 +1535,47 @@ and turns it into an index into the format table.
 */
 static LISP lencode_format(LISP f)
 {
-	sfmt fmt;
+	MwFmt fmt;
 	int result;
 
-	decode_format(0, ~0, &fmt);	/* put valid fields in fmt */
+	MwDecodeFormat(0, ~0, &fmt);	/* put valid fields in fmt */
 	while (NNULLP(f)) {
 		char *name = get_c_string(CAR(CAR(f)));
-		int mask = fmt_attr2mask(name);
+		int mask = MwFmtAttrToMask(name);
 		LISP value = CDR(CAR(f));
 		f = CDR(f);
 		switch (mask) {
-		case SFMT_FAMILY:
+		case MW_FMT_FAMILY:
 			fmt.family = get_c_string(value);
 			break;
-		case SFMT_SIZE:
+		case MW_FMT_SIZE:
 			fmt.size = get_c_long(value);
 			break;
-		case SFMT_FG:
+		case MW_FMT_FG:
 			fmt.fg = get_c_string(value);
 			break;
-		case SFMT_BG:
+		case MW_FMT_BG:
 			fmt.bg = get_c_string(value);
 			break;
-		case SFMT_BOLD:
+		case MW_FMT_BOLD:
 			fmt.bold = get_c_long(value);
 			break;
-		case SFMT_ITALIC:
+		case MW_FMT_ITALIC:
 			fmt.italic = get_c_long(value);
 			break;
-		case SFMT_ULINE:
+		case MW_FMT_ULINE:
 			fmt.uline = get_c_long(value);
 			break;
-		case SFMT_HADJ:
+		case MW_FMT_STRIKE:
+			fmt.strike = get_c_long(value);
+			break;
+		case MW_FMT_HADJ:
 			fmt.hadj = get_c_long(value);
 			break;
-		case SFMT_VADJ:
+		case MW_FMT_VADJ:
 			fmt.vadj = get_c_long(value);
 			break;
-		case SFMT_STYLE:
+		case MW_FMT_STYLE:
 			fmt.style = name2style(get_c_string(value));
 			break;
 		default:
@@ -1608,7 +1583,7 @@ static LISP lencode_format(LISP f)
 		}
 		
 	}
-	result = encode_format(~0, &fmt);
+	result = MwEncodeFormat(~0, &fmt);
 	return flocons(result);
 }
 
@@ -1631,9 +1606,9 @@ associative list of the format
 */
 static LISP ldecode_format(LISP f)
 {
-	sfmt fmt;
+	MwFmt fmt;
 
-	decode_format(get_c_long(f), ~0, &fmt);
+	MwDecodeFormat(get_c_long(f), ~0, &fmt);
 	return cons(SS("family", fmt.family),
 		 cons(SL("size", fmt.size),
 		   cons(SS("fg", fmt.fg),
@@ -1641,10 +1616,36 @@ static LISP ldecode_format(LISP f)
 		       cons(SL("bold", fmt.bold),
 			 cons(SL("italic", fmt.italic),
 			   cons(SL("uline", fmt.uline),
-			     cons(SL("hadj", fmt.hadj),
-			       cons(SL("vadj", fmt.vadj),
-				 cons(SS("style", style2name(fmt.style)),
-				      NIL))))))))));
+			     cons(SL("strike", fmt.strike),
+			       cons(SL("hadj", fmt.hadj),
+			         cons(SL("vadj", fmt.vadj),
+				   cons(SS("style", style2name(fmt.style)),
+				        NIL)))))))))));
+}
+
+/* ---
+*/
+static LISP lselect_attribute(LISP attr)
+{
+        char *name = get_c_string(attr);
+        int choice = -1;
+        char **list = NULL;
+        int nlist = 0;
+
+        if (!MwStrcasecmp(name, "family"))
+                list = MwFontList(&nlist);
+        else if (!MwStrcasecmp(name, "style"))
+                list = style_list(&nlist);
+        else if (!MwStrcasecmp(name, "fg") || !MwStrcasecmp(name, "bg"))
+                list = MwColorList(&nlist);
+
+        if (list) {
+                char prompt[250];
+                sprintf(prompt, _("Change %s:"), name);
+                choice = select_from_list(prompt, list, nlist);
+        }
+        if (choice < 0) return NIL;
+        return strcons(strlen(list[choice]), list[choice]);
 }
 
 /* ---
@@ -1666,7 +1667,7 @@ static void insert_plugin(int mode, char *plugin_name)
         char pn[1024];
         char cmd[1024];
         char fmt[80];
-        char *p;
+        char p[1024];
         buffer *buf = w_list->buf;
         int n;
         plugin_t plugin;
@@ -1683,7 +1684,7 @@ static void insert_plugin(int mode, char *plugin_name)
                 else strcpy(name, plugin_name);
                 strcpy(fn, plugin_name);
         } else {
-                if (!select_file(path, name, plugin_patterns, fmt)) return;
+                if (!select_file(path, name, plugin_patterns, fmt, 0)) return;
                 sprintf(fn, "%s/%s", path, name);
         }
 
@@ -1694,15 +1695,15 @@ static void insert_plugin(int mode, char *plugin_name)
         plugin.displayed = 0;
 
         if (mode == PLUGIN_COPY) {
-                plugin.name = cstrdup(pn);
+                plugin.name = MwStrdup(pn);
                 /* copy the file */
-                p = plugin_basedir(buf, NULL);
+                plugin_basedir(p, buf->name);
                 sprintf(pn, "%s/%s", p, plugin.name);
                 sprintf(cmd, "(mkdir %s;cp %s %s)2>/dev/null", p, fn, pn);
                 system(cmd);
         } else {
                 strcpy(pn, fn);
-                plugin.name = cstrdup(pn);
+                plugin.name = MwStrdup(pn);
         }
 
         /* start the plugin */
@@ -1711,7 +1712,7 @@ static void insert_plugin(int mode, char *plugin_name)
 
         /* prepare the buffer */
         n = buf->sht[w_list->sht].nplugin++;
-        buf->sht[w_list->sht].plugin = (plugin_t *)crealloc(buf->sht[w_list->sht].plugin,
+        buf->sht[w_list->sht].plugin = (plugin_t *)MwRealloc(buf->sht[w_list->sht].plugin,
                 buf->sht[w_list->sht].nplugin*sizeof(plugin_t));
         buf->sht[w_list->sht].plugin[n] = plugin;
         buf->change = TRUE;
@@ -1761,7 +1762,7 @@ static LISP lplugin_select(void)
 static LISP lplugin_export(void)
 {
         int n;
-        char fn[1024], pn[1024], cmd[1024], path[1024], fmt[80];
+        char p[1024], fn[1024], pn[1024], cmd[1024], path[1024], fmt[80];
         buffer *buf = w_list->buf;
 	int s = w_list->sht;
 
@@ -1773,10 +1774,11 @@ static LISP lplugin_export(void)
         /* ask for file name */
         getcwd(path, 1024);
         strcpy(fn, buf->sht[s].plugin[n].name);
-        if (!select_file(path, fn, NULL, fmt)) return NIL;
+        if (!select_file(path, fn, NULL, fmt, 1)) return NIL;
 
         /* save the file */
-        sprintf(pn, "%s/%s", plugin_basedir(buf, NULL), buf->sht[s].plugin[n].name);
+        sprintf(pn, "%s/%s", plugin_basedir(p, buf->name),
+		buf->sht[s].plugin[n].name);
         sprintf(cmd, "cp %s %s/%s", pn, path, fn);
         system(cmd);
         return NIL;
@@ -1802,7 +1804,7 @@ static LISP lplugin_delete(void)
 
         /* remove plugin */
         plugin_stop(buf->sht[s].plugin[n].ph);
-        cfree(buf->sht[s].plugin[n].name);
+        MwFree(buf->sht[s].plugin[n].name);
         buf->sht[s].nplugin--;
         for (; n < buf->sht[s].nplugin; n++)
                 buf->sht[s].plugin[n] = buf->sht[s].plugin[n+1];
@@ -1924,7 +1926,7 @@ static LISP lpaper_set(LISP b, LISP p)
 	char *n;
 	int w, h, o;
 
-	n = cstrdup(get_c_string(CAR(p)));
+	n = MwStrdup(get_c_string(CAR(p)));
 	w = get_c_long(CAR(CDR(p)));
 	h = get_c_long(CAR(CDR(CDR(p))));
 	o = get_c_long(CAR(CDR(CDR(CDR(p)))));
@@ -2070,8 +2072,8 @@ static LISP lheadfoot_set(LISP b, LISP hf)
 	char *h, *f;
 	int fp;
 
-	h = cstrdup(get_c_string(CAR(hf)));
-	f = cstrdup(get_c_string(CAR(CDR(hf))));
+	h = MwStrdup(get_c_string(CAR(hf)));
+	f = MwStrdup(get_c_string(CAR(CDR(hf))));
 	fp = get_c_long(CAR(CDR(CDR(hf))));
 	if (NULLP(b)) {
 		header = h;
@@ -2126,41 +2128,6 @@ static LISP lfirst_page_set(LISP b, LISP no)
 	return NIL;
 }
 
-static LISP ltab_distance_get(LISP b)
-{
-	int n;
-
-	if (NULLP(b)) {
-		n = tab_distance;
-	} else {
-		buffer *buf;
-		char *bn = get_c_string(b);
-		if (bn[0]) buf = find_buffer_by_name(bn);
-		else buf = w_list->buf;
-		if (!buf) return NIL;
-		n = buf->tab_distance;
-	}
-	return flocons(n);
-}
-
-static LISP ltab_distance_set(LISP b, LISP no)
-{
-	int n = get_c_long(no);
-
-	if (NULLP(b)) {
-		tab_distance = n;
-	} else {
-		buffer *buf;
-		char *bn = get_c_string(b);
-		if (bn[0]) buf = find_buffer_by_name(bn);
-		else buf = w_list->buf;
-		if (!buf) return NIL;
-		buf->tab_distance = n;
-		buf->change = pr_scr_flag = TRUE;
-		buffer_cleanup(buf);
-	}
-	return NIL;
-}
 
 static LISP lmake_backups(LISP p)
 {
@@ -2178,10 +2145,19 @@ static LISP ldisplay_bops(LISP n)
 	return result;
 }
 
+static LISP lset_zoom(LISP n)
+{
+	zoom = get_c_double(n);
+	if (zoom < .1) zoom = .1;
+	if (zoom > 10) zoom = 10;
+	pr_scr_flag = 1;
+	return NIL;
+}
+
 /* Set up the table of functions and names */
 
 /* Commands that take no arguments */
-s_fn_table fn_table[] =
+s_fn_table0 fn_table[] =
 {
 	{"listsel-test", listsel_test},
 
@@ -2235,15 +2211,17 @@ s_fn_table fn_table[] =
 	{"get-sheet", lget_sheet},
 	{"debug-format", ldebug_format},
 	{"get-current-fmt", get_current_fmt},
+	{"aboutbox", laboutbox},
+	{"aboutsiag", laboutsiag},
 	{NULL, NULL}
 };
 
 /* Commands that take 1 argument */
 
-s_fn_table fn_table1[] = {
+s_fn_table1 fn_table1[] = {
 /*	{"auto-recalc", auto_recalc},*/
 	/* low level functions */
-	{"spawn", spawn},
+	{"spawn", lspawn},
 	{"execute-interpreter-command", execute_interpreter_command},
 	{"buffer-changed", buffer_changed},
 	{"join-lines", join_lines_at},
@@ -2260,18 +2238,19 @@ s_fn_table fn_table1[] = {
 	{"decode-format", ldecode_format},
 	{"encode-format", lencode_format},
 	{"set-current-fmt", set_current_fmt},
+	{"select-attribute", lselect_attribute},
 	{"paper-get", lpaper_get},
 	{"margin-get", lmargin_get},
 	{"headfoot-get", lheadfoot_get},
 	{"first-page-get", lfirst_page_get},
-	{"tab-distance-get", ltab_distance_get},
 	{"make-backups", lmake_backups},
 	{"display-bops", ldisplay_bops},
+	{"set-zoom", lset_zoom},
 	{NULL, NULL}
 };
 
 /* Commands that take 2 arguments */
-s_fn_table fn_table2[] = {
+s_fn_table2 fn_table2[] = {
 	{"split-line", split_line_at},
 	{"delete-lines", delete_lines},
 	{"ask-for-str", lask_for_str},
@@ -2279,13 +2258,11 @@ s_fn_table fn_table2[] = {
 	{"set-style", lset_style},
 	{"set-bop", lset_bop},
 	{"set-hadjust", set_hadjust},
-	{"font-alias", lfont_alias},
 	{"move-sheet", lmove_sheet},
 	{"paper-set", lpaper_set},
 	{"margin-set", lmargin_set},
 	{"headfoot-set", lheadfoot_set},
 	{"first-page-set", lfirst_page_set},
-	{"tab-distance-set", ltab_distance_set},
 	{NULL, NULL}
 };
 
@@ -2306,10 +2283,6 @@ void init_cmds(void)
 	init_subr_3("savematrix", lsavematrix);
 	init_subr_4("pack-area", lpack_area);
 	init_subr_3("unpack-area", lunpack_area);
-	init_subr_5("register-x-font", lregister_x_font);
-	init_subr_5("register-ps-font", lregister_ps_font);
-	init_subr_5("register-t1-font", lregister_t1_font);
-	init_subr_4("register-color", lregister_color);
         init_subr_3("plugin-register", lplugin_register);
         init_subr_1("plugin-import", lplugin_import);
 	init_subr_1("plugin-link", lplugin_link);
