@@ -1,6 +1,6 @@
 /*
    Pathetic Writer
-   Copyright (C) 1997-1999  Ulric Eriksson <ulric@edu.stockholm.se>
+   Copyright (C) 1997-2002  Ulric Eriksson <ulric@siag.nu>
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -27,7 +27,8 @@
 #include <string.h>
 
 #include "../siod/siod.h"
-#include "../common/cmalloc.h"
+#include "../common/common.h"
+#include <Mowitz/MwUtils.h>
 #include "pw.h"
 
 #define MAX_FORMATS (20)
@@ -44,18 +45,50 @@ struct {
 	char *pattern;
 } fileformats[MAX_FORMATS];
 
+/* These are not declared in calc.h because they will only be called here */
+extern void fileio_pw_init(void);
+extern void fileio_txt_init(void);
+extern void fileio_rtf_init(void);
+extern void fileio_html_init(void);
+extern void fileio_ps_init(void);
+extern void fileio_extconv_init(void);
+
+static int siag_fmt;
+
+static int fmt_index(char *fmt)
+{
+	int i;
+
+	if (fmt == NULL) return siag_fmt;
+
+	for (i = 0; i < format_count; i++) {
+		if (!strcmp(_(fileformats[i].pattern), fmt)) return i;
+	}
+	return -1;
+}
+
 static int save_all(char *fn, buffer *buf)
 {
-	int n = select_from_list("Which format?", saver_patterns, nsaver);
+	char *fmt = guess_file_format(fn);
+	int n = fmt_index(fmt);
+	if (fmt && n >= 0 && fileformats[n].save) {
+		return savematrix(fn, buf, fmt);
+	}
+	n = select_from_list(_("Which format?"), saver_patterns, nsaver);
 	if (n < 0) return -1;
-	return savematrix(fn, buf, fileformats[n].pattern);
+	return savematrix(fn, buf, saver_patterns[n]);
 }
 
 static int load_all(char *fn, buffer *buf)
 {
-	int n = select_from_list("Which format?", loader_patterns, nloader);
+	char *fmt = guess_file_format(fn);
+	int n = fmt_index(fmt);
+	if (fmt && n >= 0 && fileformats[n].load) {
+		return loadmatrix(fn, buf, fmt);
+	}
+	n = select_from_list(_("Which format?"), loader_patterns, nloader);
 	if (n < 0) return -1;
-	return loadmatrix(fn, buf, fileformats[n].pattern);
+	return loadmatrix(fn, buf, loader_patterns[n]);
 }
 
 static int myformat(char *fn)
@@ -73,7 +106,7 @@ void register_format(int (*load)(char *, buffer *),
 			int (*save)(char *, buffer *),
 			int (*myformat)(char *), char *p)
 {
-	char *pattern = cstrdup(p);
+	char *pattern = MwStrdup(p);
 	fileformats[format_count].load = load;
 	fileformats[format_count].save = save;
 	fileformats[format_count].myformat = myformat;
@@ -89,16 +122,6 @@ void register_format(int (*load)(char *, buffer *),
 	}
 }
 
-/* These are not declared in calc.h because they will only be called here */
-extern void fileio_pw_init(void);
-extern void fileio_txt_init(void);
-extern void fileio_rtf_init(void);
-extern void fileio_html_init(void);
-extern void fileio_ps_init(void);
-extern void fileio_extconv_init(void);
-
-static int siag_fmt;
-
 /* ---
 */
 void fileio_init()
@@ -116,17 +139,6 @@ void fileio_init()
 	register_format(load_all, save_all, myformat, "All files (*)");
 }
 
-static int fmt_index(char *fmt)
-{
-	int i;
-
-	if (fmt == NULL) return siag_fmt;
-
-	for (i = 0; i < format_count; i++)
-		if (!strcmp(fileformats[i].pattern, fmt)) return i;
-	return -1;
-}
-
 /* ---
 */
 int savematrix(char *fn, buffer *buf, char *format)
@@ -244,13 +256,27 @@ static struct {
 } *conv = NULL;
 static int nconv = 0;
 
-#define TMPNAME "/tmp/conv_ext.tmp"
+static char *tempname;
+static char *maketempname(void)
+{
+	char p[1024];
+	if (tempname == NULL) {
+		sprintf(p, "%s/conv_ext.tmp", siag_tmpdir);
+		tempname = MwStrdup(p);
+	}
+	return tempname;
+}
+
+#define TMPNAME (maketempname())
+
+#define BLACKLIST "\\\"\'$?*|&;()<>[]{}! \t\n\r"
 
 static int save_ext(char *fn, buffer *buf)
 {
 	int loader, saver;
 	int i, n;
 	char cmd[1024];
+	char qn[1024];
 
 	for (i = 0; i < nconv; i++) {
 		if (!strcmp(fmt_name, conv[i].name)) break;
@@ -259,7 +285,8 @@ static int save_ext(char *fn, buffer *buf)
 	get_format_handlers(conv[i].sext, &loader, &saver);
 	if (saver < 0) return 1;
 	n = savematrix(TMPNAME, buf, fileformats[saver].pattern);
-	sprintf(cmd, conv[i].scmd, TMPNAME, fn);
+	MwQuotecpy(qn, fn, BLACKLIST);
+	sprintf(cmd, conv[i].scmd, TMPNAME, qn);
 	system(cmd);
 	remove(TMPNAME);
 	return n;
@@ -270,6 +297,7 @@ static int load_ext(char *fn, buffer *buf)
 	int loader, saver;
 	int i, n;
 	char cmd[1024];
+	char qn[1024];
 
 	for (i = 0; i < nconv; i++) {
 		if (!strcmp(fmt_name, conv[i].name)) break;
@@ -277,7 +305,8 @@ static int load_ext(char *fn, buffer *buf)
 	if (i == nconv) return 1;
 	get_format_handlers(conv[i].lext, &loader, &saver);
 	if (loader < 0) return 1;
-	sprintf(cmd, conv[i].lcmd, fn, TMPNAME);
+	MwQuotecpy(qn, fn, BLACKLIST);
+	sprintf(cmd, conv[i].lcmd, qn, TMPNAME);
 	system(cmd);
 	n = loadmatrix(TMPNAME, buf, fileformats[loader].pattern);
 	remove(TMPNAME);
@@ -295,12 +324,12 @@ static void register_converter(char *fmt, char *lext, char *lcmd,
 	int (*saver)(char *, buffer *);
 	int (*loader)(char *, buffer *);
 
-	conv = crealloc(conv, (nconv+1)*sizeof conv[0]);
-	conv[nconv].name = cstrdup(fmt);
+	conv = MwRealloc(conv, (nconv+1)*sizeof conv[0]);
+	conv[nconv].name = MwStrdup(fmt);
 	if (lext) {
 		loader = load_ext;
-		conv[nconv].lext = cstrdup(lext);
-		conv[nconv].lcmd = cstrdup(lcmd);
+		conv[nconv].lext = MwStrdup(lext);
+		conv[nconv].lcmd = MwStrdup(lcmd);
 	} else {
 		loader = NULL;
 		conv[nconv].lext = NULL;
@@ -308,8 +337,8 @@ static void register_converter(char *fmt, char *lext, char *lcmd,
 	}
 	if (sext) {
 		saver = save_ext;
-		conv[nconv].sext = cstrdup(sext);
-		conv[nconv].scmd = cstrdup(scmd);
+		conv[nconv].sext = MwStrdup(sext);
+		conv[nconv].scmd = MwStrdup(scmd);
 	} else {
 		saver = NULL;
 		conv[nconv].sext = NULL;
