@@ -1,6 +1,6 @@
 /*
    Pathetic Writer
-   Copyright (C) 1997, 1998  Ulric Eriksson <ulric@edu.stockholm.se>
+   Copyright (C) 1997-2002  Ulric Eriksson <ulric@siag.nu>
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -18,7 +18,8 @@
    MA 02111-1307, USA.
  */
 
-#ifdef GUILE
+#include "../config.h"
+#ifdef HAVE_LIBGUILE
 
 /*
  * guilei.c
@@ -26,6 +27,7 @@
 
 #include <stdio.h>
 #include <stdlib.h>
+#include <string.h>
 #include <ctype.h>
 #include <time.h>
 #include <signal.h>
@@ -92,7 +94,7 @@ void execute_guile(char *cmd)
 
 /* ---
 */
-int init_guile_parser()
+int init_guile_parser(void)
 {
 	gh_new_procedure0_0("row", get_row);
 	gh_new_procedure0_0("col", get_col);
@@ -103,6 +105,9 @@ int init_guile_parser()
 }
 
 #else
-int guile_dummy;
+int init_guile_parser(void)
+{
+        return -1;
+}
 #endif	/* GUILE */
 
