@@ -1,6 +1,6 @@
 /*
    Pathetic Writer
-   Copyright (C) 1997-1999  Ulric Eriksson <ulric@edu.stockholm.se>
+   Copyright (C) 1997-2002  Ulric Eriksson <ulric@siag.nu>
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -28,7 +28,7 @@
 #include <ctype.h>
 
 #include "../common/common.h"
-#include "../common/cmalloc.h"
+#include <Mowitz/MwUtils.h>
 #include "../common/plugin.h"
 
 #include "pw.h"
@@ -62,25 +62,25 @@ int name2style(char *name)
 
 	if (!name) return -1;
 	for (i = 0; i < nstyle; i++) {
-		if (!cstrcasecmp(name, style_table[i].name)) return i;
+		if (!MwStrcasecmp(name, style_table[i].name)) return i;
 	}
 	return -1;
 }
 
 static struct bp_style {
-	sfmt fmt;	/* the format we haven't initialized */
+	MwFmt fmt;	/* the format we haven't initialized */
 	int n;		/* index into style_table */
 } *bp_styles = NULL;
 static int nbp_styles = 0;	/* size of backlog */
 
-static void add_bp_style(int n, sfmt fmt)
+static void add_bp_style(int n, MwFmt fmt)
 {
 	int i = nbp_styles++;
-	bp_styles = crealloc(bp_styles, nbp_styles*sizeof *bp_styles);
+	bp_styles = MwRealloc(bp_styles, nbp_styles*sizeof *bp_styles);
 	bp_styles[i].fmt = fmt;
-	bp_styles[i].fmt.family = cstrdup(fmt.family);
-	bp_styles[i].fmt.fg = cstrdup(fmt.fg);
-	bp_styles[i].fmt.bg = cstrdup(fmt.bg);
+	bp_styles[i].fmt.family = MwStrdup(fmt.family);
+	bp_styles[i].fmt.fg = MwStrdup(fmt.fg);
+	bp_styles[i].fmt.bg = MwStrdup(fmt.bg);
 	bp_styles[i].n = n;
 }
 
@@ -92,17 +92,17 @@ void do_bp_styles(void)
 
 	for (i = 0; i < nbp_styles; i++) {
 		style_table[bp_styles[i].n].format =
-			encode_format(~0, &bp_styles[i].fmt);
-		cfree(bp_styles[i].fmt.family);
-		cfree(bp_styles[i].fmt.fg);
-		cfree(bp_styles[i].fmt.bg);
+			MwEncodeFormat(~0, &bp_styles[i].fmt);
+		MwFree(bp_styles[i].fmt.family);
+		MwFree(bp_styles[i].fmt.fg);
+		MwFree(bp_styles[i].fmt.bg);
 	}
-	cfree(bp_styles);
+	MwFree(bp_styles);
 }
 
 /* ---
 A struct style has the fields name, format index, format, next.
-The format has the fields family, size, bold, italic, uline, fg, bg, style.
+The format has the fields family, size, bold, italic, uline, strike, fg, bg, style.
 
 I omit the format index because we will compute it here.
 The style in the format is useless here.
@@ -125,35 +125,36 @@ the function patch_styles from init_windows.
 
 int lookup_style(char *name, char *next,
 		char *family, int size, int bold, int italic,
-		int uline, char *fg)
+		int uline, int strike, char *fg)
 {
-	sfmt fmt;
+	MwFmt fmt;
 	style s;
 	int i;
 
-	s.name = cstrdup(name);
+	s.name = MwStrdup(name);
 
 	/* get the default format, so all fields are valid */
-	decode_format(0, ~0, &fmt);
+	MwDecodeFormat(0, ~0, &fmt);
 	/* then change the ones we are interested in */
 	fmt.family = family;
 	fmt.size = size;
 	fmt.bold = bold;
 	fmt.italic = italic;
 	fmt.uline = uline;
+	fmt.strike = strike;
 	fmt.fg = fg;
 
 	/* now figure out where to put it */
 	i = name2style(name);
 	if (i == -1) {	/* new style */
 		i = nstyle++;
-		style_table = crealloc(style_table, nstyle*sizeof *style_table);
+		style_table = MwRealloc(style_table, nstyle*sizeof *style_table);
 	} else {	/* redefine existing */
-		cfree(style_table[i].name);
+		MwFree(style_table[i].name);
 	}
 
 	if (ok2print) {		/* UI is initialised */
-		s.format = encode_format(~0, &fmt);
+		s.format = MwEncodeFormat(~0, &fmt);
 	} else {		/* do it later, then */
 		s.format = 0;
 		add_bp_style(i, fmt);
@@ -175,9 +176,9 @@ static int compar(const void *p, const void *q)
 char **style_list(int *n)
 {
 	int i;
-	char **list = (char **)cmalloc((nstyle+1)*sizeof(char *));
+	char **list = (char **)MwMalloc((nstyle+1)*sizeof(char *));
 	for (i = 0; i < nstyle; i++)
-		list[i] = cstrdup(style_table[i].name);
+		list[i] = MwStrdup(style_table[i].name);
 	list[i] = NULL;
 	qsort(list, i, sizeof(char *), compar);
 	*n = i;
@@ -188,9 +189,9 @@ char **style_list(int *n)
 */
 int style_height(int s)
 {
-	int fmt = style_table[s].format;
-	int font = format_table[fmt].font;
-	return ps_font_height(font);
+	MwRichchar p = {'X', 0};
+	p.fmt = style_table[s].format;
+	return MwRcStrheight(&p, 1);
 }
 
 /* ---
@@ -198,16 +199,16 @@ this should work exactly like the format code in fonts.c, because I don't
 know what fields will be added or removed in the future.
 
 the styles are saved in a single level, just like the formats.
-Attributes: name, height, next, family, size, bold, italic, uline, fg
+Attributes: name, height, next, family, size, bold, italic, uline, strike, fg
 */
 
 void save_styles(FILE *fp, int i)
 {
-	sfmt fmt;
+	MwFmt fmt;
 	style st;
 
 	st = style_table[i];
-	decode_format(st.format, ~0, &fmt);
+	MwDecodeFormat(st.format, ~0, &fmt);
 	fprintf(fp, ".style %d\n", i);
 	fprintf(fp, "name %s\n", st.name);
 	fprintf(fp, "next %d\n", st.follower);
@@ -216,6 +217,7 @@ void save_styles(FILE *fp, int i)
 	fprintf(fp, "bold %d\n", fmt.bold);
 	fprintf(fp, "italic %d\n", fmt.italic);
 	fprintf(fp, "uline %d\n", fmt.uline);
+	fprintf(fp, "strike %d\n", fmt.strike);
 	fprintf(fp, "fg %s\n", fmt.fg);
 	fprintf(fp, "end\n");
 }
@@ -225,10 +227,10 @@ void save_styles(FILE *fp, int i)
 int load_styles(FILE *fp)
 {
 	style st = style_table[0];
-	sfmt fmt;
+	MwFmt fmt;
 
 	char name[1000], family[1000], fg[1000], b[1000];
-	decode_format(0, ~0, &fmt);
+	MwDecodeFormat(0, ~0, &fmt);
 	strcpy(name, st.name);
 	st.name = name;
 	strcpy(family, fmt.family);
@@ -236,7 +238,7 @@ int load_styles(FILE *fp)
 	strcpy(fg, fmt.fg);
 	fmt.fg = fg;
 	while (fgets(b, sizeof b, fp) && strncmp(b, "end", 3)) {
-		chomp(b);
+		MwChomp(b);
 		if (!strncmp(b, "name ", 5))
 			strcpy(st.name, b+5);
 		else if (!strncmp(b, "next ", 5))
@@ -251,13 +253,15 @@ int load_styles(FILE *fp)
 			fmt.italic = strtol(b+7, NULL, 10);
 		else if (!strncmp(b, "uline ", 6))
 			fmt.uline = strtol(b+6, NULL, 10);
+		else if (!strncmp(b, "strike ", 7))
+			fmt.strike = strtol(b+7, NULL, 10);
 		else if (!strncmp(b, "fg ", 3))
 			strcpy(fmt.fg, b+3);
 		/* ignore anything we don't grok */
 	}
 	return lookup_style(st.name, style2name(st.follower),
 			fmt.family, fmt.size, fmt.bold, fmt.italic,
-			fmt.uline, fmt.fg);
+			fmt.uline, fmt.strike, fmt.fg);
 }
 
 /* end of style code */
@@ -269,10 +273,10 @@ int load_styles(FILE *fp)
 
 void free_text(rich_text *c)
 {
-	cfree(c);
+	MwFree(c);
 }
 
-static rich_char empty_char = {
+static MwRichchar empty_char = {
 	'\0', 0
 };
 
@@ -291,15 +295,15 @@ void alloc_line(buffer *b, int sht, int row)
 		return;
 	}
 	b->sht[sht].alloc_lines = b->sht[sht].used_lines = MAX(b->sht[sht].used_lines, row);
-	b->sht[sht].text = (rich_text *)crealloc(b->sht[sht].text,
+	b->sht[sht].text = (rich_text *)MwRealloc(b->sht[sht].text,
 			(b->sht[sht].alloc_lines+1)*sizeof(rich_text));
 	i++;	/* don't overwrite the last used line */
 	while (i <= b->sht[sht].alloc_lines) {
 		b->sht[sht].text[i].height = style_height(0);
 		b->sht[sht].text[i].sty = 0;
-		b->sht[sht].text[i].adj = HADJ_LEFT;
+		b->sht[sht].text[i].adj = MW_HADJ_LEFT;
 		b->sht[sht].text[i].bop = 1;
-		b->sht[sht].text[i++].p = rc_strdup(&empty_char);
+		b->sht[sht].text[i++].p = MwRcStrdup(&empty_char);
 	}
 	b->sht[sht].used_lines = b->sht[sht].alloc_lines;
 }
@@ -318,7 +322,6 @@ void position_kludge(buffer *b, int sht, int r)
 	do {
 		if (w->buf == b) {
 			sheet *s = w->buf->sht;
-			if (s[sht].top.row >= r) s[sht].top = p;
 			if (s[sht].blku.row >= r) s[sht].blku = p;
 			if (s[sht].blkl.row >= r) s[sht].blkl = p;
 		}
@@ -347,9 +350,6 @@ void position_kludge2(void)
 		st = b->sht;
 		r = line_last_used(b, s);
 		if (r < 1) r = 1;
-		st[s].top.row = MIN(st[s].top.row, r);
-		st[s].top.col = MIN(st[s].top.col,
-				col_last_used(b, s, st[s].top.row));
 		st[s].blku.row = MIN(st[s].blku.row, r);
 		st[s].blku.col = MIN(st[s].blku.col,
 				col_last_used(b, s, st[s].blku.row));
@@ -385,7 +385,7 @@ int split_line(buffer *buf, int s, int row, int col)
 	position_kludge(buf, s, row);
 
 	alloc_line(buf, s, row+1);
-	if (buf->sht[s].text[row].sty == STY_EMBED) {
+	if (buf->sht[s].text[row].sty == MW_STY_EMBED) {
 		if (col == 0) downshift_text(buf, s, row);
 		else downshift_text(buf, s, row+1);
 		return 1;
@@ -395,8 +395,8 @@ int split_line(buffer *buf, int s, int row, int col)
 	buf->sht[s].text[row+1].sty = buf->sht[s].text[row].sty;
 	buf->sht[s].text[row+1].adj = buf->sht[s].text[row].adj;
 	buf->sht[s].text[row+1].bop = 0;
-	buf->sht[s].text[row+1].p = rc_strdup(buf->sht[s].text[row].p+col);
-	if (rc_strlen(buf->sht[s].text[row].p) > col)
+	buf->sht[s].text[row+1].p = MwRcStrdup(buf->sht[s].text[row].p+col);
+	if (MwRcStrlen(buf->sht[s].text[row].p) > col)
 		buf->sht[s].text[row].p[col] = empty_char;	/* truncate */
 	/* check line heights for both lines */
 	check_line_height(buf, s, row);
@@ -409,13 +409,13 @@ int split_line(buffer *buf, int s, int row, int col)
 */
 int join_lines(buffer *buf, int s, int row)
 {
-	rich_char *p;
+	MwRichchar *p;
 	position_kludge(buf, s, row);
 
 	if (row >= buf->sht[s].used_lines) return 0;	/* nothing to join */
 
 	/* special case if either line is embedded object */
-	if (buf->sht[s].text[row].sty == STY_EMBED) {
+	if (buf->sht[s].text[row].sty == MW_STY_EMBED) {
 		/* can only join with empty line */
 		if (line_length(buf, s, row+1) == 0) {
 			upshift_text(buf, s, row+1);
@@ -423,7 +423,7 @@ int join_lines(buffer *buf, int s, int row)
 		} else return 0;	/* can't do that */
 	}
 
-	if (buf->sht[s].text[row+1].sty == STY_EMBED) {
+	if (buf->sht[s].text[row+1].sty == MW_STY_EMBED) {
 		if (line_length(buf, s, row) == 0) {
 			upshift_text(buf, s, row);
 			return 1;
@@ -431,8 +431,8 @@ int join_lines(buffer *buf, int s, int row)
 	}
 
 	p = buf->sht[s].text[row].p;
-	buf->sht[s].text[row].p = rc_strins(p, buf->sht[s].text[row+1].p, rc_strlen(p));
-	cfree(p);
+	buf->sht[s].text[row].p = MwRcStrins(p, buf->sht[s].text[row+1].p, MwRcStrlen(p));
+	MwFree(p);
 	upshift_text(buf, s, row+1);
 	return 1;
 }
@@ -441,17 +441,18 @@ int join_lines(buffer *buf, int s, int row)
 */
 int ins_text(buffer *buf, int s, position pos, unsigned char *t, int fmt)
 {
-	rich_char *p;
-	rich_char *q;
-	if (ret_style(buf, s, pos.row) == STY_EMBED) return 0;	/* nope */
+	MwRichchar *p;
+	MwRichchar *q;
+	if (ret_style(buf, s, pos.row) == MW_STY_EMBED) return 0;	/* nope */
 
 	alloc_line(buf, s, pos.row);
 	p = buf->sht[s].text[pos.row].p;
-	q = rc_makerich(t, fmt);
-	buf->sht[s].text[pos.row].p = rc_strins(p, q, pos.col);
-	check_line_height(buf, s, pos.row);
-	cfree(p);
-	cfree(q);
+	q = MwRcMakerich(t, fmt);
+	buf->sht[s].text[pos.row].p = MwRcStrins(p, q, pos.col);
+	if (buf->height_interest)
+		check_line_height(buf, s, pos.row);
+	MwFree(p);
+	MwFree(q);
 	return 1;
 }
 
@@ -475,7 +476,7 @@ unsigned char *peek_line(buffer *b, int s, int r)
 	if (b == NULL) return NULL;
 	if (r > b->sht[s].used_lines) return NULL;
 	if (b->sht[s].text == NULL) return NULL;
-	return rc_makeplain(b->sht[s].text[r].p);
+	return MwRcMakeplain(b->sht[s].text[r].p);
 }
 
 /* ---
@@ -485,7 +486,7 @@ int peek_char(buffer *b, int s, int r, int c)
 	int result;
 	unsigned char *p = peek_line(b, s, r);
 	result = p[c];
-	cfree(p);
+	MwFree(p);
 	return result;
 }
 
@@ -497,9 +498,9 @@ static int find_suitable_space(buffer *b, int s, int r)
 {
 	int c = 0;
 	int space = 0;	/* current "suitable" space */
+	int len = line_length(b, s, r);
 
-	while (c < line_length(b, s, r)
-	       && line_width(b, s, r, c) <=
+	while (c < len && line_width(b, s, r, c) <=
 			b->paper_width-b->left_margin-b->right_margin) {
 		if (isspace(peek_char(b, s, r, c))) space = c;
 		c++;
@@ -525,6 +526,7 @@ int rebreak_line(buffer *buf, int s, int row)
 		join_lines(buf, s, row);
 		pr_scr_flag = TRUE;
 	}
+
 	while (line_width(buf, s, row, line_length(buf, s, row)) > maxwidth) {
 		int col = find_suitable_space(buf, s, row);
 		if (col <= 0) break;	/* none found */
@@ -543,17 +545,17 @@ returns number of deleted characters
 
 int del_char(buffer *buf, int s, int row, int col)
 {
-	if (buf->sht[s].text[row].sty == STY_EMBED) {
+	if (buf->sht[s].text[row].sty == MW_STY_EMBED) {
 		if (col == 0) {		/* remove the object and the line */
-			char *p = (char *)rc_makeplain(buf->sht[s].text[row].p);
+			char *p = (char *)MwRcMakeplain(buf->sht[s].text[row].p);
 			embed_unload(p);	/* can't be NULL */
-			cfree(p);
+			MwFree(p);
 			upshift_text(buf, s, row);
 			return 1;
 		} else return 0;
 	}
 
-	rc_strcpy(buf->sht[s].text[row].p+col, buf->sht[s].text[row].p+col+1);
+	MwRcStrcpy(buf->sht[s].text[row].p+col, buf->sht[s].text[row].p+col+1);
 	buf->change = TRUE;
 	return 1;
 }
@@ -582,12 +584,12 @@ int del_lines(buffer *buf, int s, int row, int count)
 
 	/* delete count lines, starting at row */
 	for (i = 0; i < count; i++) {
-		if (buf->sht[s].text[row+i].sty == STY_EMBED) {
-			char *p = (char *)rc_makeplain(buf->sht[s].text[row].p);
+		if (buf->sht[s].text[row+i].sty == MW_STY_EMBED) {
+			char *p = (char *)MwRcMakeplain(buf->sht[s].text[row].p);
 			embed_unload(p);
-			cfree(p);
+			MwFree(p);
 		}
-		cfree(buf->sht[s].text[row+i].p);
+		MwFree(buf->sht[s].text[row+i].p);
 	}
 
 	/* shift the rest of the lines up */
@@ -609,10 +611,10 @@ int del_lines(buffer *buf, int s, int row, int count)
 */
 int ins_format(buffer *buf, int s, int row, int c1, int c2, int format)
 {
-	rich_char *line;
+	MwRichchar *line;
 	alloc_line(buf, s, row);
 	line = buf->sht[s].text[row].p;
-	while (c1 < c2 && c1 < rc_strlen(line)) {
+	while (c1 < c2 && c1 < MwRcStrlen(line)) {
 		line[c1++].fmt = format;
 	}
 	return 1;
@@ -622,7 +624,7 @@ int ins_format(buffer *buf, int s, int row, int c1, int c2, int format)
 */
 int ret_format(buffer *buf, int s, int row, int col)
 {
-	rich_char *line;
+	MwRichchar *line;
 	if (row > buf->sht[s].used_lines) return style_table[0].format;
 	line = buf->sht[s].text[row].p;
 	if (!line || line[0].c == '\0') {
@@ -630,14 +632,14 @@ int ret_format(buffer *buf, int s, int row, int col)
 		int pr = row-1;
 		while (pr >= 1 && ret_style(buf, s, pr) == ret_style(buf, s, row)) {
 			line = buf->sht[s].text[pr].p;
-			col = rc_strlen(line);
+			col = MwRcStrlen(line);
 			if (col) return line[col-1].fmt;
 			pr--;
 		}
 		/* give up and return the default format for the style */
 		return style_table[buf->sht[s].text[row].sty].format;
 	}
-	if (col >= rc_strlen(line)) col = rc_strlen(line)-1;
+	if (col >= MwRcStrlen(line)) col = MwRcStrlen(line)-1;
 	return line[col].fmt;
 }
 
@@ -654,7 +656,7 @@ void set_style(buffer *b, int s, int row, int sty)
 */
 int ret_style(buffer *b, int s, int row)
 {
-	if (row > b->sht[s].used_lines) return STY_DEFAULT;
+	if (row > b->sht[s].used_lines) return MW_STY_DEFAULT;
 	return b->sht[s].text[row].sty;
 }
 
@@ -678,8 +680,8 @@ int ret_bop(buffer *b, int s, int row)
 */
 int ret_hadj(buffer *b, int s, int row)
 {
-	if (row > b->sht[s].used_lines) return HADJ_LEFT;
-	return b->sht[s].text[row].adj & HADJ_MASK;
+	if (row > b->sht[s].used_lines) return MW_HADJ_LEFT;
+	return b->sht[s].text[row].adj & MW_HADJ_MASK;
 }
 
 /* ---
@@ -711,7 +713,7 @@ void downshift_text(buffer *b, int s, int row)
 	}
 	b->sht[s].text[r].sty = 0;
 	b->sht[s].text[r].height = style_height(0);
-	b->sht[s].text[r].adj = HADJ_LEFT;
+	b->sht[s].text[r].adj = MW_HADJ_LEFT;
 	b->sht[s].text[r].p = NULL;
 	for (i = 0; i < b->sht[s].nplugin; i++) {
 		if (b->sht[s].plugin[i].row >= row) b->sht[s].plugin[i].row++;
@@ -732,12 +734,12 @@ void upshift_text(buffer *b, int s, int row)
 	/* this line is still allocated. We clear it just in case */
 	b->sht[s].text[r].sty = 0;
         b->sht[s].text[r].height = style_height(0);
-        b->sht[s].text[r].adj = HADJ_LEFT;
+        b->sht[s].text[r].adj = MW_HADJ_LEFT;
 	b->sht[s].text[r].p = NULL;
 	for (i = 0; i < b->sht[s].nplugin; i++) {
 		if (b->sht[s].plugin[i].row == row) {
 			plugin_stop(b->sht[s].plugin[i].ph);
-			cfree(b->sht[s].plugin[i].name);
+			MwFree(b->sht[s].plugin[i].name);
 			b->sht[s].nplugin--;
 			for (j = i; j < b->sht[s].nplugin; j++)
 				b->sht[s].plugin[j] = b->sht[s].plugin[j+1];
@@ -776,7 +778,7 @@ char *pack_string_area(buffer *buf, int s,
 	char *p, *data;
 
 	*size = 32000;
-	p = cmalloc(*size);
+	p = MwMalloc(*size);
 	data = p;
 
 	if (r2 > line_last_used(buf, s)) r2 = line_last_used(buf, s);
@@ -797,6 +799,7 @@ this one only does plaintext for now
 char *pack_area(buffer *buf, int s,
 		int r1, int c1, int r2, int c2, unsigned int *size)
 {
+	if (r1 == -1 || r2 == -1 || c1 == -1 || c2 == -1) return NULL;
 	return pack_string_area(buf, s, r1, c1, r2, c2, size);
 }
 
