@@ -189,7 +189,8 @@
 	(lc (position-col (get-blkl))))
     (if (> ur 0)
       (begin
-    	(split-line lr lc)
+    (llpr "foo")
+    	(split-line lr (+ lc 1))
     	(split-line ur uc)
     	(delete-lines (+ ur 1) (+ (- lr ur) 1))
     	(join-lines ur)
@@ -258,7 +259,16 @@
   (rebreak-line (position-row (get-point))))
 
 (define (change-hadjust hadj)
-  (set-hadjust (position-row (get-point)) hadj))
+  (let ((r (position-row (get-point)))
+	(r1 (position-row (get-blku)))
+	(r2 (position-row (get-blkl))))
+    (if (or (< r r1) (> r r2))
+      (set-hadjust r hadj)
+      (while (<= r1 r2)
+        (set-hadjust r1 hadj)
+        (set! r1 (+ r1 1))))))
+
+;  (set-hadjust (position-row (get-point)) hadj))
 
 ;(define (change-vadjust vadj)
 ;  (if (= vadj (bit-and (get-format nil (get-point)) VADJ_MASK))
@@ -267,6 +277,7 @@
 
 (define HADJ_MASK (bit-or 4096 8192))
 (define HADJ_LEFT 0)
+(define HADJ_FULL 4096)
 (define HADJ_CENTER 8192)
 (define HADJ_RIGHT (bit-or 4096 8192))
 (define VADJ_MASK (bit-or 16384 32768))
@@ -289,9 +300,9 @@
   (let ((r r1))
     (while (<= r r2)
       (line-format buf
-		   r1
+		   r
 		   (if (= r r1) c1 COLS-MIN)
-		   (if (= r r2) c2 (col-last-used r))
+		   (if (= r r2) (+ c2 1) (col-last-used r))
 		   name
 		   value)
       (set! r (+ r 1))))
@@ -320,6 +331,12 @@
       (set-current-fmt (encode-format fmt))))
   (set-pr-scr))
 
+; Interactively select value from a list
+(define (new_attribute name)
+  (let ((value (select-attribute name)))
+    (if (not (null? value))
+      (new-format name value))))
+
 (define (toggle-format name)
   (let* ((r (get-point-row))
 	 (c (get-point-col))
@@ -361,7 +378,7 @@
       (set! lpr-command printcmd))))
 
 ; load the fonts
-(require (string-append datadir "/common/fonts.scm"))
+;(require (string-append datadir "/common/fonts.scm"))
 
 ; and the styles
 (define (register-style . ap)
@@ -534,20 +551,62 @@
     (try-executable dirs fn)))
 
 (define (register-converters)
-  (if (executable-file "catdoc")
-    (register-converter "MS Word 2.0 - 95 (*.doc)"
-		        "*.txt" "catdoc %s > %s"
-		        "*.rtf" "cp %s %s"))
-  (if (executable-file "blaha")
-    (register-converter "Blaha (*.blaha)"
-			"*.txt" "blaha < %s > %s"
-			"*.txt" "blaha < %s > %s"))
-  (if (executable-file "mswordview")
-    (register-converter "MS Word 97 (*.doc)"
-                        "*.html" "mswordview -n %s -o %s"
-                        "*.rtf" "cp %s %s"))
+; If wvHtml is available, use it for all Word versions
+  (if (executable-file "wvWare")
+    (register-converter "MS Word (*.doc)"
+;			"*.html" "wvHtml -c iso-8859-15 %s > %s"
+			"*.html" "wvWare -c iso-8859-15 %s > %s 2> /dev/null"
+			nil nil)
+; otherwise look for catdoc and mswordview
+    (begin
+      (if (executable-file "catdoc")
+        (register-converter "MS Word 2.0 - 95 (*.doc)"
+		            "*.txt" "catdoc %s > %s"
+		            nil nil))
+      (if (executable-file "mswordview")
+        (register-converter "MS Word 97 (*.doc)"
+                            "*.html" "mswordview -n %s -o %s"
+                            nil nil))))
+  (if (executable-file "wp2x")
+    (register-converter "Word Perfect 5.1 (*.wp)"
+			"*.html" "wp2x html.cfg %s > %s"
+			nil nil))
+  (if (executable-file "pptHtml")
+    (register-converter "MS Powerpoint (*.ppt)"
+			"*.html" "pptHtml %s > %s"
+			nil nil))
+  (if (executable-file "pdftohtml.bin")
+    (register-converter "PDF loader (*.pdf)"
+			"*.html" "pdftohtml.bin -i -noframes -stdout %s > %s"
+			nil nil))
+  (if (executable-file "ps2pdf")
+    (register-converter "PDF saver (*.pdf)"
+			nil nil
+			"*.ps" "ps2pdf %s %s"))
+  (if (executable-file "groff")
+    (register-converter "Man page (*.[0-9])"
+			"*.txt" "groff -Tascii -mandoc %s > %s"
+			nil nil))
+  (if (executable-file "lyx2html")
+    (register-converter "LyX (*.lyx)"
+			"*.html" "lyx2html %s %s"
+			nil nil))
+  (if (executable-file "psiconv")
+    (register-converter "Psion (*.psi)"
+			"*.html" "psiconv %s > %s"
+			nil nil))
+  (register-converter "Abi Word (*.abw)"
+		      "*.html" "cp %s %s"
+		      nil nil)
+  (if (executable-file "wrd2html")
+    (register-converter "Psion Word (*.wrd)"
+			"*.html" "wrd2html %s > %s"
+			nil nil))
   (if (executable-file "2rtf")
     (register-converter "AUIS ez (*.ez)"
 			"*.rtf" "2rtf %s %s"
 			nil nil)))
 
+(define (zoom-adjust)
+  (set-zoom (/ (string->number (ask-for-str "Zoom %:" "130")) 100)))
+
