@@ -1,6 +1,6 @@
 /*
    Pathetic Writer
-   Copyright (C) 1997, 1998  Ulric Eriksson <ulric@edu.stockholm.se>
+   Copyright (C) 1997, 1998  Ulric Eriksson <ulric@siag.nu>
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -38,7 +38,7 @@ extern void init_tar(void);
 /* from slib.c */
 extern char *repl_c_string_arg;
 extern long repl_c_string_flag;
-extern LISP repl_c_string_read();
+extern LISP repl_c_string_read(void);
 
 static int siag_row, siag_col;
 
@@ -107,11 +107,6 @@ static LISP lget_mark(void)
 	return MAKE_POSITION(get_mark(w_list));
 }
 
-static LISP lget_top(void)
-{
-	return MAKE_POSITION(get_top(w_list));
-}
-
 static LISP lget_blku(void)
 {
 	int s = w_list->sht;
@@ -126,13 +121,6 @@ static LISP lget_blkl(void)
 	return MAKE_POSITION(st[s].blkl);
 }
 
-static LISP lset_top(LISP top)
-{
-	set_top(w_list, make_position(POSITION_ROW(top),
-					POSITION_COL(top)));
-	return NIL;
-}
-
 static LISP lset_point(LISP point)
 {
 	set_point(w_list, make_position(POSITION_ROW(point),
@@ -182,10 +170,8 @@ void init_position(void)
 {
 	init_subr_0("get-point", lget_point);
 	init_subr_0("get-mark", lget_mark);
-	init_subr_0("get-top", lget_top);
 	init_subr_0("get-blku", lget_blku);
 	init_subr_0("get-blkl", lget_blkl);
-	init_subr_1("set-top", lset_top);
 	init_subr_1("set-point", lset_point);
 	init_subr_1("set-mark", lset_mark);
 	init_subr_0("line-last-used", line_last_used_fun);
