@@ -1,6 +1,6 @@
 /*
    Siag, Scheme In A Grid
-   Copyright (C) 1996-1999  Ulric Eriksson <ulric@edu.stockholm.se>
+   Copyright (C) 1996-2002  Ulric Eriksson <ulric@siag.nu>
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -29,8 +29,8 @@
 #include <unistd.h>
 
 #include "../common/common.h"
-#include "../common/cmalloc.h"
-#include "../common/fonts.h"
+#include <Mowitz/MwUtils.h>
+#include <Mowitz/MwFormat.h>
 #include "../common/plugin.h"
 #include "calc.h"
 
@@ -119,15 +119,15 @@ char *put_property(buffer *b, char *key, char *value)
 			for (q = b->p_list; q->next != p; q = q->next);
 			q->next = p->next;
 		}
-		cfree(p->key);
-		cfree(p->value);
-		cfree(p);
+		MwFree(p->key);
+		MwFree(p->value);
+		MwFree(p);
 	}
 	/* add new value, if there is one */
 	if (value) {
-		p = (property_list *)cmalloc(sizeof(property_list));
-		p->key = cstrdup(key);
-		p->value = cstrdup(value);
+		p = (property_list *)MwMalloc(sizeof(property_list));
+		p->key = MwStrdup(key);
+		p->value = MwStrdup(value);
 		p->next = b->p_list;
 		b->p_list = p;
 		return p->value;
@@ -155,7 +155,7 @@ sheet new_sheet(void)
 {
 	sheet s;
 	char *p = "Empty Sheet";
-	s.name = cstrdup(p);
+	s.name = MwStrdup(p);
 	s.alloc_lines = 0;
 	s.longest_line = 0;
 	s.alloc_cols = NULL;
@@ -191,7 +191,7 @@ int buffer_add_sheet(buffer *b, int n)
 
 	if (n < 0 || n > b->nsht) return b->nsht;
 	b->nsht++;
-	b->sht = (sheet *)crealloc(b->sht, b->nsht*sizeof(sheet));
+	b->sht = (sheet *)MwRealloc(b->sht, b->nsht*sizeof(sheet));
 	for (i = b->nsht-1; i > n; i--) {
 		b->sht[i] = b->sht[i-1];
 	}
@@ -200,11 +200,11 @@ int buffer_add_sheet(buffer *b, int n)
 	   and even then it will still work, sort of.
 	*/
 	for (i = b->nsht; i < 1000; i++) {
-		sprintf(name, translate("Sheet %d"), i);
+		sprintf(name, _("Sheet %d"), i);
 		if (!sheet_name_taken(b, name)) break;
 	}
-	cfree(b->sht[n].name);
-	b->sht[n].name = cstrdup(name);
+	MwFree(b->sht[n].name);
+	b->sht[n].name = MwStrdup(name);
 	return b->nsht;
 }
 
@@ -226,9 +226,18 @@ int buffer_remove_sheet(buffer *b, int n)
 */
 void buffer_rename_sheet(buffer *b, int n, char *name)
 {
-	if (n < 0 || n > b->nsht) return;
-	cfree(b->sht[n].name);
-	b->sht[n].name = cstrdup(name);
+	int i;
+	char nn[1024];
+
+	if (n < 0 || n > b->nsht) return;		/* out of bounds */
+	if (!strcmp(name, b->sht[n].name)) return;	/* no change */
+	strcpy(nn, name);
+	i = 1;
+	while (sheet_name_taken(b, nn)) {
+		sprintf(nn, "%s<%d>", name, i++);
+	}
+	MwFree(b->sht[n].name);
+	b->sht[n].name = MwStrdup(nn);
 }
 
 #define NSHT 1
@@ -245,7 +254,7 @@ buffer *new_buffer(char *name, char *path)
 	buffer *b;
 	int s;
 
-	b = (buffer *)cmalloc(sizeof(buffer));
+	b = (buffer *)MwMalloc(sizeof(buffer));
 
 	if (b_list == NULL)
 		b_list = b;	/* first buffer ever */
@@ -298,6 +307,7 @@ buffer *free_buffer(buffer *b)
 	int i;
 	buffer *pb, *next;
 	int s;
+	char p[1024];
 
 	next = b->next;
 	if (next == b)
@@ -324,7 +334,11 @@ buffer *free_buffer(buffer *b)
 			b->sht[s].plugin[i].displayed = 0;
 		}
 	}
-	cfree((char *) b);
+
+	plugin_basedir(p, b->name);
+	rmdir(p);
+
+	MwFree((char *) b);
 
 	return next;
 }
@@ -360,23 +374,6 @@ void plugin_unique_name(char *from, char *to)
 		sprintf(to, "%d_%s", i, from);
 }
 
-/* ---
-figure out where to put the plugins
-*/
-
-char *plugin_basedir(buffer *buf, char *dir)
-{
-	int i;
-	static char b[1024];
-	pid_t pid = getpid();
-
-	if (!dir) dir = b;
-	sprintf(dir, "%s/%ld/%s", siag_basedir, (long)pid, buf->name);
-	/* now, we don't want to keep any ugly characters */
-	for (i = strlen(dir)-strlen(buf->name); dir[i]; i++)
-		if (!isalnum(dir[i])) dir[i] = '_';
-	return dir;
-}
 
 /* ---
    buffer *find_buffer_by_name(char *name)
@@ -465,7 +462,11 @@ buffer *find_sheet_by_name(char *name, buffer *defb, int *s)
 */
 int cell_width(buffer *b, int s, int col)
 {
-	if (b->sht[s].width == NULL || col > b->sht[s].used_cols) return b->sw;
+	if (b == NULL) return 80;
+	if (s >= b->nsht ||
+	    b->sht[s].width == NULL ||
+	    col > b->sht[s].used_cols)
+		return b->sw;
 	return b->sht[s].width[col];
 }
 
@@ -473,7 +474,11 @@ int cell_width(buffer *b, int s, int col)
 */
 int cell_height(buffer *b, int s, int row)
 {
-	if (b->sht[s].height == NULL || row > b->sht[s].used_lines) return b->sh;
+	if (b == NULL) return 20;
+	if (s >= b->nsht ||
+	    b->sht[s].height == NULL ||
+	    row > b->sht[s].used_lines)
+		return b->sh;
 	return b->sht[s].height[row];
 }
 
@@ -484,12 +489,12 @@ void set_width(buffer *b, int s, int col, int width)
 	int i;
 
 	if (b->sht[s].width == NULL) {
-		b->sht[s].width = (int *)cmalloc((col+1) * sizeof(int));
+		b->sht[s].width = (int *)MwMalloc((col+1) * sizeof(int));
 		for (i = 0; i < col; i++)
 			b->sht[s].width[i] = b->sw;
 		b->sht[s].used_cols = col;
 	} else if (col > b->sht[s].used_cols) {
-		b->sht[s].width = (int *)crealloc((void *)b->sht[s].width, (col+1)*sizeof(int));
+		b->sht[s].width = (int *)MwRealloc((void *)b->sht[s].width, (col+1)*sizeof(int));
 		for (i = b->sht[s].used_cols+1; i < col; i++)
 			b->sht[s].width[i] = b->sw;
 		b->sht[s].used_cols = col;
@@ -504,12 +509,12 @@ void set_height(buffer *b, int s, int row, int height)
 	int i;
 
 	if (b->sht[s].height == NULL) {
-		b->sht[s].height = (int *)cmalloc((row+1)*sizeof(int));
+		b->sht[s].height = (int *)MwMalloc((row+1)*sizeof(int));
 		for (i = 0; i < row; i++)
 			b->sht[s].height[i] = b->sh;
 		b->sht[s].used_lines = row;
 	} else if (row > b->sht[s].used_lines) {
-		b->sht[s].height = (int *)crealloc((void *)b->sht[s].height, (row+1)*sizeof(int));
+		b->sht[s].height = (int *)MwRealloc((void *)b->sht[s].height, (row+1)*sizeof(int));
 		for (i = b->sht[s].used_lines+1; i < row; i++)
 			b->sht[s].height[i] = b->sh;
 		b->sht[s].used_lines = row;
