@@ -1,6 +1,6 @@
 /*
    Siag, Scheme In A Grid
-   Copyright (C) 1996-1999  Ulric Eriksson <ulric@edu.stockholm.se>
+   Copyright (C) 1996-2002  Ulric Eriksson <ulric@siag.nu>
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -25,8 +25,6 @@
 #ifndef CALC_H
 #define CALC_H
 
-#include "../common/traceme.h"
-
 #define BUFFER_COLS 100000
 #define BUFFER_ROWS 100000
 
@@ -39,9 +37,14 @@
 #define EMPTY 0
 #define LABEL 1
 #define ERROR 2
+#define CONSTANT 3
 #define EXPRESSION 4
 #define STRING 5
 #define EMBED 6
+#define MNUMBER 7	/* transient number in matrix or such */
+#define MTEXT 8		/* string in matrix or table */
+
+#define IS_NUMBER(x) ((x)==EXPRESSION||(x)==CONSTANT||(x)==MNUMBER)
 
 enum {PORTRAIT = 0, LANDSCAPE};
 
@@ -75,7 +78,11 @@ typedef struct s_property_list {
 } property_list;
 
 typedef struct plugin_t {
+#if 1	/* cell based coords */
 	int row, col;		/* geometry */
+#else	/* pixel based coords */
+	int x, y;		/* geometry */
+#endif
 	int ph;			/* handle */
 	char *name;		/* file name or whatever */
 	int displayed;		/* has it been put up on the screen? */
@@ -183,8 +190,7 @@ extern int split_window(window * );
 extern void hide_cur(window * );
 extern void get_cell_coords(window *, int, int, int, int, int *, int *);
 extern void get_coords_cell(window *w, int, int, int *, int *, int, int);
-extern unsigned int rowcol_format();
-extern int nocomp(char * );
+extern unsigned int rowcol_format(void);
 extern int ask_for_str(char *, char *);
 extern int cell_next_row(window *, int);
 extern int cell_next_col(window *, int);
@@ -211,6 +217,8 @@ extern int lookup_style(char *name, char *fmt, int type);
 extern char **style_list(int *);
 extern void save_styles(FILE *fp, int);
 extern int load_styles(FILE *);
+extern void std_fmt_set(buffer *, int);
+extern int std_fmt_get(buffer *);
 extern void free_rows(buffer *, int, int);
 extern void free_matrix(spread **);
 extern void swap_cells(buffer *, int, int, int, int, int);
@@ -258,7 +266,6 @@ extern int buffer_remove_sheet(buffer *, int);
 extern void buffer_rename_sheet(buffer *, int, char *);
 extern buffer *new_buffer(char *, char *);
 extern buffer *free_buffer(buffer *);
-extern char *plugin_basedir(buffer *, char *);
 extern void plugin_unique_name(char *, char *);
 extern buffer *find_buffer_by_name(char *);
 extern buffer *find_sheet_by_name(char *, buffer *, int *);
@@ -301,9 +308,10 @@ extern char *update_references(buffer *, int, char *,
 extern void update_all_references(buffer *, int, int, int, int, int, int, int);
 extern char *colnum_text(buffer *, int);
 /* execute is no longer siod only */
-#define execute(p) exec_expr(siod_interpreter,(p))
+#define execute(p) exec_unknown(p)
 extern void va_execute(char *, ...);
 extern void exec_expr(int, char *);
+extern void exec_unknown(char *);
 
 /* from fileio.c */
 extern char *loader_patterns[];
@@ -329,6 +337,7 @@ extern position set_mark(window * , position);
 extern position get_mark(window * );
 extern position set_top(window * , position);
 extern position get_top(window *);
+extern void get_siod_coords(int *, int *, int *, buffer **);
 extern void init_position(void);
 extern int inblock(window * , position);
 extern void prot_fixup(window *);
