@@ -1,6 +1,6 @@
 /*
    Siag, Scheme In A Grid
-   Copyright (C) 1996-1999  Ulric Eriksson <ulric@edu.stockholm.se>
+   Copyright (C) 1996-2002  Ulric Eriksson <ulric@siag.nu>
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -28,7 +28,8 @@
 #include <ctype.h>
 #include <locale.h>
 
-#include "../common/cmalloc.h"
+#include <sys/types.h>
+#include <Mowitz/MwUtils.h>
 #include "../common/common.h"
 
 #include "calc.h"
@@ -41,13 +42,14 @@
 #define PUSH(e) (opstack[++opind] = (e))
 #define POP (opstack[opind--])
 #define TOP (opstack[opind])
-#define PUSHRESSTACK(x) (resstack[++resind] = (x))
+#define POPRESSTACK (resstack[resind--])
+#define PUSHRESSTACK(x) (resstack[++resind] = MwStrdup(x))
 
 #define ISOPERATOR prio
 
 typedef enum { ADD = 1, PLUS, ADD_ASS, INC,
         SUB, MINUS, SUB_ASS, DEC,
-        MULT, MULT_ASS, DIV, DIV_ASS,
+        MULT, MULT_ASS, POWER, DIV, DIV_ASS, IDIV,
         MOD, MOD_ASS, RSHIFT, RSHIFT_ASS,
         LSHIFT, LSHIFT_ASS, BAND, BAND_ASS,
         LAND, BOR, BOR_ASS, LOR,
@@ -61,13 +63,11 @@ typedef enum { ADD = 1, PLUS, ADD_ASS, INC,
         SIZEOF, FOR, WHILE, IF,
         ELSE, DO, SWITCH, RETURN,
         BREAK, CONTINUE, GOTO, NOSYMBOL,
+	FUN, RANGE, PERCENT, XREF,
         END
 } opcode;
 
 static char *calcexpr;			/* the expression being calculated */
-static int calcsht;
-static int calcrow, calccol;		/* the cell being calculated */
-
 static int c;			/* the last character read */
 
 static int prio[END + 1];
@@ -75,13 +75,10 @@ static int isinfix[END + 1];
 
 static int opind, resind;
 static int opstack[40];
-static double resstack[40];
+static char *resstack[40];
+static char symbol_text[1024];
 
-static double symbol_val;
-
-typedef enum {
-	REF_START, REF_R, REF_DIG1, REF_C, REF_DIG2, REF_LIMBO, REF_ALNUM
-} ref_state;
+static int inarglist;		/* evaluate function arguments */
 
 #define BREAKCHARS " +-*/%=(),;:!&|^<>?\t\r\n"
 
@@ -99,12 +96,12 @@ static char *update_C_references(buffer *buf, char *expr, int r1, int c1,
 
 	/* rough upper bound on new length. A few bytes extra don't matter */
 	/* strlen("r100000c100000")-strlen("r1c1") = 10 */
-	p = cmalloc(strlen(expr)+10*rc+1);
+	p = MwMalloc(strlen(expr)+10*rc+1);
 	rc = ref_updater(buf, expr, p, BREAKCHARS, r1, c1, r2, c2, rd, cd);
 	if (rc) {
-		expr = cstrdup(p);
+		expr = MwStrdup(p);
 	}
-	cfree(p);
+	MwFree(p);
 	return expr;
 }
 
@@ -116,8 +113,8 @@ static int next_symbol(buffer *b)
 {
 	char *p;
 	int lineno;
-	char tokentext[256];
 	char *endptr;
+	size_t n;
 
 Restart:	/* restart efter comment */
 	while (isspace(c)) {
@@ -153,9 +150,14 @@ Restart:	/* restart efter comment */
 			return SUB;
 		}
 	case '*':
-		if (READCHAR == '=')
+		switch (READCHAR) {
+		case '=':
 			READ_RETURN(MULT_ASS);
-		return MULT;
+		case '*':
+			READ_RETURN(POWER);
+		default:
+			return MULT;
+		}
 	case '/':
 		switch (READCHAR) {
 		case '=':
@@ -175,6 +177,8 @@ Restart:	/* restart efter comment */
 		default:
 			return DIV;
 		}
+	case '\\':
+		READ_RETURN(IDIV);
 	case '%':
 		if (READCHAR == '=')
 			READ_RETURN(MOD_ASS);
@@ -252,10 +256,17 @@ Restart:	/* restart efter comment */
 	case '0':
 		/* hack to not treat 0.1 as octal 0 followed by error */
 		if (*calcexpr == '.') {
-			symbol_val = strtod(calcexpr, &endptr);
+			(void)strtod(calcexpr, &endptr);
+			n = endptr-calcexpr;
+			strncpy(symbol_text, calcexpr, n);
+			symbol_text[n] = '\0';
 		} else {
+			/* this can be in octal or hexadecimal notation,
+			   therefore we reencode in decimal */
+			long m;
 			calcexpr--;
-			symbol_val = strtol(calcexpr, &endptr, 0);
+			m = strtol(calcexpr, &endptr, 0);
+			sprintf(symbol_text, "%ld", m);
 		}
 		if (calcexpr == endptr)
 			return NOSYMBOL;
@@ -274,172 +285,190 @@ Restart:	/* restart efter comment */
 	case '9':
 		/* read decimal number */
 		calcexpr--;
-		symbol_val = strtod(calcexpr, &endptr);
+		(void)strtod(calcexpr, &endptr);
 		if (calcexpr == endptr)	/* no conversion performed */
 			return NOSYMBOL;
+		n = endptr-calcexpr;
+		strncpy(symbol_text, calcexpr, n);
+		symbol_text[n] = '\0';
 		calcexpr = endptr;
 		READCHAR;
 		return NUMBER;
-	default:		/* read identifier or error */
-		p = tokentext;
-		while (isalnum(c) || c == '_' || c == '.' || c == '@') {
+	case '"':	/* string constant */
+		p = symbol_text;
+		*p++ = c;
+		READCHAR;
+		while (c != '"') {
+			if (c == '\\') {
+				*p++ = c;
+				READCHAR;
+			}
+			if (!c) return NOSYMBOL;
+			*p++ = c;
+			READCHAR;
+		}
+		*p++ = '"';
+		READCHAR;
+		*p = '\0';
+		return IDENT;	/* anything will do, actually */
+	default:		/* read identifier or function */
+		p = symbol_text;
+		while (isalnum(c) ||
+		       c == '_' || c == '.' || c == '@' || c == '$') {
 			*p++ = c;
 			READCHAR;
 		}
 		*p = '\0';
-		if (!cstrcasecmp(tokentext, "R"))
+		if (!MwStrcasecmp(symbol_text, "R")) {
+			strcpy(symbol_text, "(row)");
 			return ROW;
-		if (!cstrcasecmp(tokentext, "C"))
-			return COLUMN;
-
-	/* preprocessor hack to evaluate functions */
-		if (c == '(') {
-			char expr[1024];
-			int par = 1;
-			READCHAR;
-			expr[0] = '(';
-			strcpy(expr+1, tokentext);
-			p = expr+strlen(expr);
-			*p++ = ' ';
-			while (par > 0) {
-				if (!c) return NOSYMBOL;
-				if (c == ',') *p++ = ' ';
-				else *p++ = c;
-				if (c == '(') par++;
-				if (c == ')') par--;
-				READCHAR;
-			}
-			*p = '\0';
-			symbol_val = parse_expr(b, siod_interpreter, expr,
-						calcsht, calcrow, calccol).number;
-		} else { /* let SIOD evaluate it as a symbol */
-			symbol_val = parse_expr(b, siod_interpreter, tokentext,
-						calcsht, calcrow, calccol).number;
 		}
-		if (siag_type == EXPRESSION) return NUMBER;
-		return IDENT;
+		if (!MwStrcasecmp(symbol_text, "C")) {
+			strcpy(symbol_text, "(col)");
+			return COLUMN;
+		}
+		return IDENT;	/* also ranges */
 	}
 	return NOSYMBOL;
 }
 
+static void oper1arg(char *p)
+{
+	char *tmp1 = POPRESSTACK;
+	char a[2048];
+	MwSnprintf(a, sizeof a, "(%s %s)", p, tmp1);
+	MwFree(tmp1);
+	PUSHRESSTACK(a);
+}
+
+static void oper2arg(char *p)
+{
+	char *tmp1 = POPRESSTACK;
+	char *tmp2 = POPRESSTACK;
+	char a[2048];
+	MwSnprintf(a, sizeof a, "(%s %s %s)", p, tmp2, tmp1);
+	MwFree(tmp1);
+	MwFree(tmp2);
+	PUSHRESSTACK(a);
+}
+
 static void calculate(buffer *b, int op)
 {
-	register int i;
-	register double sum;
-	register double tmp;
-	int n1, n2;
+	register char *tmp1, *tmp2;
+	char a[2048];
 
+	/* the first two are legacy ugliness which are implemented in Scheme */
 	switch (op) {
 	case SEMICOLON:
-		sum = 0;
-		tmp = resstack[resind--];
-		for (i = resstack[resind]; i <= tmp; i++)
-			sum += ret_val(b, calcsht, i, calccol).number;
-		resstack[resind] = sum;
+		oper2arg("siag_rowsum");
 		break;
 	case COLON:
-		sum = 0;
-		tmp = resstack[resind--];
-		for (i = resstack[resind]; i <= tmp; i++)
-			sum += ret_val(b, calcsht, calcrow, i).number;
-		resstack[resind] = sum;
+		oper2arg("siag_colsum");
 		break;
+	/* comma can only appear in argument lists, *except* in expressions
+	   which do not contain any function call. In that case, backwards
+	   compatibility mandates that it is interpreted as get-cell */
 	case COMMA:
-		tmp = resstack[resind--];
-		resstack[resind] =
-			ret_val(b, calcsht, (int)resstack[resind], (int)tmp).number;
+		if (!inarglist) {
+			oper2arg("get-cell");
+		} else { /* just cons'em up */
+			tmp1 = POPRESSTACK;
+			tmp2 = POPRESSTACK;
+			MwSnprintf(a, sizeof a, "%s %s", tmp2, tmp1);
+			MwFree(tmp1);
+			MwFree(tmp2);
+			PUSHRESSTACK(a);
+		}
+		break;
+	case FUN:
+		tmp1 = POPRESSTACK;
+		tmp2 = POPRESSTACK;
+		MwSnprintf(a, sizeof a, "(%s %s)", tmp2, tmp1);
+		MwFree(tmp1);
+		MwFree(tmp2);
+		PUSHRESSTACK(a);
 		break;
 	case LOR:
-		n1 = resstack[resind--];
-		n2 = resstack[resind];
-		resstack[resind] = n2 || n1;
+		oper2arg("@OR");
 		break;
 	case LAND:
-		n1 = resstack[resind--];
-		n2 = resstack[resind];
-		resstack[resind] = n2 && n1;
+		oper2arg("@AND");
 		break;
 	case BOR:
-		n1 = resstack[resind--];
-		n2 = resstack[resind];
-		resstack[resind] = n2 | n1;
+		oper2arg("bit-or");
 		break;
 	case XOR:
-		n1 = resstack[resind--];
-		n2 = resstack[resind];
-		resstack[resind] = n2 ^ n1;
+		oper2arg("bit-xor");
 		break;
 	case BAND:
-		n1 = resstack[resind--];
-		n2 = resstack[resind];
-		resstack[resind] = n2 & n1;
+		oper2arg("bit-and");
 		break;
 	case EQUAL:
-		tmp = resstack[resind--];
-		resstack[resind] = resstack[resind] == tmp;
+		oper2arg("@EQ");	/* lives in 123.scm */
 		break;
 	case NE:
-		tmp = resstack[resind--];
-		resstack[resind] = resstack[resind] != tmp;
+		oper2arg("@NE");
 		break;
 	case LT:
-		tmp = resstack[resind--];
-		resstack[resind] = resstack[resind] < tmp;
+		oper2arg("@LT");
 		break;
 	case LE:
-		tmp = resstack[resind--];
-		resstack[resind] = resstack[resind] <= tmp;
+		oper2arg("@LE");
 		break;
 	case GT:
-		tmp = resstack[resind--];
-		resstack[resind] = resstack[resind] > tmp;
+		oper2arg("@GT");
 		break;
 	case GE:
-		tmp = resstack[resind--];
-		resstack[resind] = resstack[resind] >= tmp;
+		oper2arg("@GE");
 		break;
 	case RSHIFT:
-		n1 = resstack[resind--];
-		n2 = resstack[resind];
-		resstack[resind] = n2 >> n1;
+		oper1arg("-");
+		oper2arg("ash");
 		break;
 	case LSHIFT:
-		n1 = resstack[resind--];
-		n2 = resstack[resind];
-		resstack[resind] = n2 << n1;
+		oper2arg("ash");
 		break;
 	case ADD:
-		tmp = resstack[resind--];
-		resstack[resind] += tmp;
+		oper2arg("+");
 		break;
 	case SUB:
-		tmp = resstack[resind--];
-		resstack[resind] -= tmp;
+		oper2arg("-");
 		break;
 	case MULT:
-		tmp = resstack[resind--];
-		resstack[resind] *= tmp;
+		oper2arg("*");
+		break;
+	case POWER:
+		oper2arg("pow");
 		break;
 	case DIV:
-		tmp = resstack[resind--];
-		resstack[resind] /= tmp;
+		oper2arg("/");
+		break;
+	case IDIV:
+		oper2arg("quotient");
 		break;
 	case MOD:
-		n1 = resstack[resind--];
-		n2 = resstack[resind];
-		resstack[resind] = n2 % n1;
+		oper2arg("fmod");
 		break;
 	case LNOT:
-		resstack[resind] = !resstack[resind];
+		oper1arg("@NOT");
 		break;
 	case BNOT:
-		n1 = resstack[resind];
-		resstack[resind] = ~n1;
+		oper1arg("bit-not");
 		break;
 	case PLUS:
+		oper1arg("+");
 		break;
 	case MINUS:
-		resstack[resind] = -resstack[resind];
+		oper1arg("-");
+		break;
+	case PERCENT:
+		tmp1 = POPRESSTACK;
+		MwSnprintf(a, sizeof a, "(/ %s 100)", tmp1);
+		MwFree(tmp1);
+		PUSHRESSTACK(a);
+		break;
+	case XREF:
+		oper2arg("get_xref");
 		break;
 	default:
 		errorflag = TRUE;
@@ -459,24 +488,25 @@ static int operand(buffer *b)
       Operand:
 	if (errorflag)
 		return TRUE;
-	switch (next_symbol(b)) {
+	op = next_symbol(b);
+      Operand2:
+	switch (op) {
+	case RANGE:
+	case IDENT:
 	case NUMBER:
-		PUSHRESSTACK(symbol_val);
-		break;
 	case ROW:
-		PUSHRESSTACK((double) calcrow);
-		break;
 	case COLUMN:
-		PUSHRESSTACK((double) calccol);
+		PUSHRESSTACK(symbol_text);
+		break;
+	case RPAR:
+		PUSHRESSTACK("");	/* empty arg list */
+		inarglist--;
+		goto Restart;	/* which will make a function call */
 		break;
 	case LPAR:
-		PUSH(LPAR);
-		goto Operand;
 	case LNOT:
-		PUSH(LNOT);
-		goto Operand;
 	case BNOT:
-		PUSH(BNOT);
+		PUSH(op);
 		goto Operand;
 	case SUB:
 		PUSH(MINUS);
@@ -495,8 +525,23 @@ static int operand(buffer *b)
       Restart:
 	if (errorflag)
 		return TRUE;
-	if (isinfix[op]) {
-		if (EMPTY_STACK || prio[op] > prio[TOP]) {
+	if (op == LPAR) {
+		inarglist++;
+		if (TOP == PERCENT) {
+			TOP = MOD;
+			PUSH(LPAR);
+		} else {
+			PUSH(FUN);
+		}
+		goto Operand;
+	} else if (op == MOD) {
+		PUSH(PERCENT);
+		goto Operator;
+	} else if (op == LNOT) {
+		op = XREF;
+		goto Restart;
+	} else if (isinfix[op]) {
+		if ( (EMPTY_STACK || prio[op] > prio[TOP]) ) {
 			PUSH(op);
 			goto Operand;
 		} else {
@@ -505,9 +550,9 @@ static int operand(buffer *b)
 		}
 	} else if (op == END) {
 		while (!EMPTY_STACK) {
-			if (ISOPERATOR[TOP])
+			if (ISOPERATOR[TOP]) {
 				calculate(b, POP);
-			else {
+			} else {
 				return errorflag = TRUE;
 			}
 		}
@@ -516,14 +561,19 @@ static int operand(buffer *b)
 		if (EMPTY_STACK) {
 			return errorflag = TRUE;
 		}
-		while (TOP != LPAR) {
+		while (TOP != LPAR && TOP != FUN) {
 			calculate(b, POP);
 			if (EMPTY_STACK) {
 				return errorflag = TRUE;
 			}
 		}
-		(void)POP;
+		if (POP == FUN) {
+			calculate(b, FUN);
+		}
 		goto Operator;
+	} else if (POP == PERCENT) {
+		PUSH(MOD);
+		goto Operand2;
 	}
 	return errorflag = TRUE;
 }
@@ -535,16 +585,22 @@ static cval parse_C_expr(buffer *b, char *expr, int s, int row, int col)
 	cval value;
 	calcexpr = expr;
 	READCHAR;
-	calcsht = s;
-	calcrow = row;
-	calccol = col;
 
+	setlocale(LC_NUMERIC, "C");
+	/* for default COMMA meaning in polish and spanish language  (Albert) */
+
+	inarglist = 0;
 	siag_type = EXPRESSION;
 	opind = resind = 0;
 	/* index 0 will never contain anything, it's used as a safety margin */
 	operand(b);
-	if (errorflag) siag_type = ERROR;
-	value.number = resstack[1];
+	if (errorflag) {
+		value.number = 0;
+		siag_type = ERROR;
+		return value;
+	}
+	value = parse_expr(b, siod_interpreter, resstack[1], s, row, col);
+	MwFree(resstack[1]);
 	return value;
 }
 
@@ -560,9 +616,7 @@ static void exec_C_expr(char *s)
 */
 int init_C_parser(void)
 {
-	static int p = 0;
-
-	setlocale(LC_NUMERIC, "C");
+	int p = 0;
 
 	prio[LPAR] = p++;
 	prio[SEMICOLON] = prio[COLON] = prio[COMMA] = p++;
@@ -576,17 +630,23 @@ int init_C_parser(void)
 	prio[RSHIFT] = prio[LSHIFT] = p++;
 	prio[ADD] = prio[SUB] = p++;
 	prio[MULT] = prio[DIV] = prio[MOD] = p++;
+	prio[POWER] = prio[IDIV] = p++;
 	prio[LNOT] = prio[BNOT] = prio[PLUS] = prio[MINUS] = p++;
+	prio[PERCENT] = p++;
+	prio[XREF] = p++;
 
-	isinfix[LPAR] = isinfix[SEMICOLON] = isinfix[COLON] = isinfix[COMMA] =
-		isinfix[LOR] = isinfix[LAND] = isinfix[BOR] = isinfix[XOR] = isinfix[BAND] =
-		isinfix[EQUAL] = isinfix[NE] =
-		isinfix[LT] = isinfix[LE] = isinfix[GT] = isinfix[GE] =
-		isinfix[RSHIFT] = isinfix[LSHIFT] =
-		isinfix[ADD] = isinfix[SUB] = isinfix[MULT] = isinfix[DIV] = isinfix[MOD] =
-		isinfix[LNOT] = isinfix[BNOT] = isinfix[PLUS] = isinfix[MINUS] = TRUE;
+	isinfix[LPAR] 	= isinfix[SEMICOLON] 	= isinfix[COLON]	= 
+	isinfix[COMMA] 	= isinfix[LOR] 		= isinfix[LAND] 	= 
+	isinfix[BOR] 	= isinfix[XOR] 		= isinfix[BAND] 	= 
+	isinfix[EQUAL] 	= isinfix[NE] 		= isinfix[LT] 		= 
+	isinfix[LE] 	= isinfix[GT] 		= isinfix[GE] 		= 
+	isinfix[RSHIFT]	= isinfix[LSHIFT] 	= isinfix[ADD] 		= 
+	isinfix[SUB] 	= isinfix[MULT] 	= isinfix[DIV] 		= 
+	isinfix[MOD] 	= isinfix[XREF] 	/*= isinfix[BNOT]*/ 	= 
+	isinfix[POWER]	= isinfix[IDIV]		=
+	isinfix[PLUS] 	= isinfix[MINUS] 	= TRUE;
 
 	return register_interpreter("C", parse_C_expr, exec_C_expr,
-				update_C_references); /* no exec */
+				update_C_references);
 }
 
