@@ -1,6 +1,6 @@
 /*
    Siag, Scheme In A Grid
-   Copyright (C) 1996, 1997  Ulric Eriksson <ulric@edu.stockholm.se>
+   Copyright (C) 1996-2002  Ulric Eriksson <ulric@siag.nu>
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -20,6 +20,7 @@
 
 /* These are not declared in calc.h because they will only be called here */
 extern void fileio_siag_init(void);
+extern void fileio_xls_init(void);
 extern void fileio_txt_init(void);
 extern void fileio_ps_init(void);
 extern void fileio_html_init(void);
@@ -27,3 +28,4 @@ extern void fileio_wk1_init(void);
 extern void fileio_scm_init(void);
 extern void fileio_tbl_init(void);
 extern void fileio_latex_init(void);
+extern void fileio_abs_init(void);
