@@ -1,6 +1,6 @@
 /*
    Siag, Scheme In A Grid
-   Copyright (C) 1996-1999  Ulric Eriksson <ulric@edu.stockholm.se>
+   Copyright (C) 1996-2002  Ulric Eriksson <ulric@siag.nu>
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -104,8 +104,8 @@
 #include <unistd.h>
 #include <sys/stat.h>
 
-#include "../common/cmalloc.h"
-#include "../common/fonts.h"
+#include <Mowitz/MwUtils.h>
+#include <Mowitz/MwFormat.h>
 #include "../common/common.h"
 #include "../common/plugin.h"
 #include "calc.h"
@@ -136,12 +136,12 @@ static char *file_name(buffer *buf, char *n)
 {
 	char b[1024];
 	if (n[0] == '/') {		/* link */
-		return cstrdup(n);
+		return MwStrdup(n);
 	}
-	plugin_basedir(buf, b);
+	plugin_basedir(b, buf->name);
 	strcat(b, "/");
 	strcat(b, n);
-	return cstrdup(b);
+	return MwStrdup(b);
 }
 
 
@@ -154,12 +154,13 @@ static int save_flat(char *fn, buffer * buf)
 	int i, j, lastcell, lr;
 	int s;
 	FILE *fp;
-	int sw = buf->sw, sh = buf->sh, sf = buf->sf;
-	int intp, fmt;
+	int sw = buf->sw, sh = buf->sh, sf = std_fmt_get(buf);
+	int intp, f;
+	MwFmt fmt;
 	char *taddr;
 	property_list *p;
-	char *used_fmt = ccalloc(nformat+1, 1);
-	char *used_style = ccalloc(nstyle+1, 1);
+	char *used_fmt = MwCalloc(MwFormatCount+1, 1);
+	char *used_style = MwCalloc(nstyle+1, 1);
 
 	if ((fp = fopen(fn, "w")) == (FILE *) 0)
 		return 1;
@@ -182,14 +183,15 @@ static int save_flat(char *fn, buffer * buf)
         fprintf(fp, ".first_page %d\n", buf->first_page_number);
 	fprintf(fp, ".a1_refs %d\n", buf->a1_refs);
 
-	if (!used_style[format_table[sf].style]) {
+	MwDecodeFormat(sf, ~0, &fmt);
+	if (!used_style[fmt.style]) {
 		/* haven't saved style before */
-		save_styles(fp, format_table[sf].style);
-		used_style[format_table[sf].style] = 1;
+		save_styles(fp, fmt.style);
+		used_style[fmt.style] = 1;
 	}
 	if (!used_fmt[sf]) {
 		/* we haven't saved this format before */
-		save_formats(fp, sf);
+		MwSaveFormats(fp, sf);
 		used_fmt[sf] = 1;
 	}
 	fprintf(fp, ".nsf %d\n", sf);
@@ -232,33 +234,37 @@ static int save_flat(char *fn, buffer * buf)
 			fprintf(fp, "# Line %d\n", i);
 			lastcell = col_last_changed(buf, s, i, sf);
 			for (j = 1; j <= lastcell; j++) {
-				fmt = ret_format(buf, s, i, j);
-				if (!used_style[format_table[fmt].style]) {
+				f = ret_format(buf, s, i, j);
+				MwDecodeFormat(f, ~0, &fmt);
+				if (!used_style[fmt.style]) {
 					/* haven't saved style before */
-					save_styles(fp, format_table[fmt].style);
-					used_style[format_table[fmt].style] = 1;
+					save_styles(fp, fmt.style);
+					used_style[fmt.style] = 1;
 				}
-				if (!used_fmt[fmt]) {
+				if (!used_fmt[f]) {
 					/* we haven't saved this format before */
-					save_formats(fp, fmt);
-					used_fmt[fmt] = 1;
+					MwSaveFormats(fp, f);
+					used_fmt[f] = 1;
 				}
 	
 				switch (ret_type(buf, s, i, j)) {
 				case EMPTY:
-					if (fmt != sf)
+					if (f != sf)
 						fprintf(fp, "%d %d %d\t#\n",
-							i, j, fmt);
+							i, j, f);
 					break;
 				case LABEL:
 					fprintf(fp, "%d %d %d\t\"%s\n", i, j,
-						fmt, ret_text(buf, s, i, j));
+						f, ret_text(buf, s, i, j));
 					break;
 				case EMBED:
 					fprintf(fp, "%d %d %d\tm%s\n", i, j,
-						fmt, ret_text(buf, s, i, j));
+						f, ret_text(buf, s, i, j));
 					break;
-			/* ERRORs are stored as EXPRESSION */
+				case MNUMBER:
+				case MTEXT:
+					break;	/* not stored at all */
+			/* ERRORs and CONSTANTs are stored as EXPRESSION */
 				default:	/* EXPRESSION */
 		/* Special case SIOD and C for backward compatibility. */
 					intp = ret_interpreter(buf, s, i, j);
@@ -270,13 +276,13 @@ static int save_flat(char *fn, buffer * buf)
 					}
 					if (intp == siod_interpreter) {
 						fprintf(fp, "%d %d %d\t=%s\n",
-							i, j, fmt, taddr);
+							i, j, f, taddr);
 					} else if (intp == C_interpreter) {
 						fprintf(fp, "%d %d %d\t==%s\n",
-							i, j, fmt, taddr);
+							i, j, f, taddr);
 					} else {
 						fprintf(fp, "%d %d %d\t+%s,%s\n",
-							i, j, fmt,
+							i, j, f,
 							interpreter2name(intp),
 							taddr);
 					}
@@ -286,8 +292,8 @@ static int save_flat(char *fn, buffer * buf)
 	}
 	fprintf(fp, "# End of file %s\n", fn);
 	fclose(fp);
-	cfree(used_fmt);
-	cfree(used_style);
+	MwFree(used_fmt);
+	MwFree(used_style);
 	return 0;
 }				/* save_flat */
 
@@ -309,9 +315,11 @@ static int load_flat(char *fn, buffer *buf)
 	int *styles = NULL;
 	int nsty = 0;
 	int n;
-	sfmt fmt;
+	MwFmt fmt;
 	int lastph = -1;
 	cval value;
+	char *endp;
+	int type;
 	value.number = 0;
 
 	if ((fp = fopen(fn, "r")) == NULL)
@@ -332,6 +340,7 @@ static int load_flat(char *fn, buffer *buf)
 	s = 0;	/* old files have no .sheet tags, so start at first sheet */
 	while (fgets(instring, 250, fp) != NULL) {
 		char b[1024];
+		b[0] = '\0';	/* make sure we don't keep stuff between loops */
 
 		/* strip off \r\n */
 /*
@@ -360,13 +369,13 @@ static int load_flat(char *fn, buffer *buf)
                                        &(buf->paper_width),
                                        &(buf->paper_height),
                                        &(buf->orientation));
-                                buf->paper_name = cstrdup(b);
+                                buf->paper_name = MwStrdup(b);
                         } else if (!strncmp(instring, ".header ", 8)) {
                                 sscanf(instring, ".header %[^\n]", b);
-                                buf->header = cstrdup(b);
+                                buf->header = MwStrdup(b);
                         } else if (!strncmp(instring, ".footer ", 8)) {
                                 sscanf(instring, ".footer %[^\n]", b);
-                                buf->footer = cstrdup(b);
+                                buf->footer = MwStrdup(b);
                         } else if (!strncmp(instring, ".header_on_first ", 17)) {
                                 sscanf(instring, ".header_on_first %d",
                                        &(buf->header_on_first));
@@ -384,7 +393,7 @@ must no longer be used. Thus .nsf (new standard format)
 */
 			} else if (!strncmp(instring, ".nsf ", 5)) {
 				sscanf(instring, ".nsf %d", &sf);
-				buf->sf = sf;
+				std_fmt_set(buf, sf);
 			} else if (!strncmp(instring, ".cw ", 4)) {
 				int w;
 				sscanf(instring, ".cw %d %d", &i, &w);
@@ -397,19 +406,19 @@ must no longer be used. Thus .nsf (new standard format)
 				sscanf(instring, ".ft%d", &n);
 				if (n > nfmt) {
 					nfmt = n;
-					fmts = crealloc(fmts,
+					fmts = MwRealloc(fmts,
 							(nfmt+1)*sizeof *fmts);
 				}
-				fmts[n] = load_formats(fp);
+				fmts[n] = MwLoadFormats(fp);
 				/* now replace style with the real one */
-				decode_format(fmts[n], ~0, &fmt);
+				MwDecodeFormat(fmts[n], ~0, &fmt);
 				/* Careful now. Some versions of Siag
 				   produced bogus styles
 				*/
 				if (fmt.style < nsty
 					&& styles[fmt.style] < nstyle) {
 					fmt.style = styles[fmt.style];
-					fmts[n] = encode_format(~0, &fmt);
+					fmts[n] = MwEncodeFormat(~0, &fmt);
 				} else {
 					fmt.style = 0;
 				}
@@ -418,7 +427,7 @@ must no longer be used. Thus .nsf (new standard format)
 				sscanf(instring, ".style %d", &n);
 				if (n >= nsty) {
 					nsty = n;
-					styles = crealloc(styles,
+					styles = MwRealloc(styles,
 							(nsty+1)*sizeof *styles);
 				}
 				styles[n] = load_styles(fp);
@@ -432,7 +441,7 @@ must no longer be used. Thus .nsf (new standard format)
 				int h;
 				char b[256];
 				sscanf(instring, ".fmt%d %[^\n]", &h, b);
-				h >>= FMT_SHIFT;	/* 0 <= h <= 15 */
+				h >>= MW_FMT_SHIFT;	/* 0 <= h <= 15 */
 				lookup_style(style2name(h), b,
 						style_table[h].type);
 			} else if (!strncmp(instring, ".plugin-geometry ", 17)) {
@@ -452,14 +461,14 @@ must no longer be used. Thus .nsf (new standard format)
 					&row, &col, name);
 				plugin.row = row;
 				plugin.col = col;
-				plugin.name = cstrdup(name);
+				plugin.name = MwStrdup(name);
 				p = file_name(buf, name);
 				lastph = plugin.ph = plugin_start(p);
-				cfree(p);
+				MwFree(p);
 				plugin.displayed = 0;
 				if (plugin.ph != -1) {
 					n = buf->sht[s].nplugin++;
-					buf->sht[s].plugin = crealloc(buf->sht[s].plugin,
+					buf->sht[s].plugin = MwRealloc(buf->sht[s].plugin,
 						buf->sht[s].nplugin*sizeof(plugin_t));
 					buf->sht[s].plugin[n] = plugin;
 				}
@@ -467,11 +476,11 @@ must no longer be used. Thus .nsf (new standard format)
 				int n;
 				char key[256], *value;
 				sscanf(instring, ".p%d %s", &n, key);
-				value = cmalloc(n+1);
+				value = MwMalloc(n+1);
 				fread(value, n, 1, fp);
 				value[n] = '\0';
 				put_property(buf, key, value);
-				cfree(value);
+				MwFree(value);
 			}
 			break;
 		default:	/* cell definition */
@@ -489,7 +498,7 @@ must no longer be used. Thus .nsf (new standard format)
 				break;
 			f = atoi(p);
 			if (nfmt == -1 || f > nfmt) {	/* old */
-				f = fmt_old2new(f);
+				f = MwFmtOldToNew(f);
 			} else {
 				f = fmts[f];
 			}
@@ -510,9 +519,15 @@ must no longer be used. Thus .nsf (new standard format)
 					intp = siod_interpreter;
 					texti = (contents+1);
 				}
+				value.number = strtod(texti, &endp);
+				if (texti != endp && only_space(endp)) {
+					type = CONSTANT;
+				} else {
+					type = EXPRESSION;
+				}
 				if (texti == 0) return 1;
 				ins_data(buf, intp, texti,
-					value, EXPRESSION, s, i, j);
+					value, type, s, i, j);
 				ins_format(buf, s, i, j, f);
 				break;
 			case '+':	/* new style expression */
@@ -558,11 +573,9 @@ must no longer be used. Thus .nsf (new standard format)
 	}
 
 	fclose(fp);
-	cfree(fmts);
-	cfree(styles);
-	decode_format(buf->sf, ~0, &fmt);
-	fmt.borders = 0;
-	buf->sf = encode_format(~0, &fmt);
+	MwFree(fmts);
+	MwFree(styles);
+	std_fmt_set(buf, sf);
 	return 0;
 } /* load_flat */
 
@@ -613,23 +626,23 @@ static int save(char *fn, buffer *buf)
 		for (i = 0; i < buf->sht[s].nplugin; i++) {
 			b = file_name(buf, buf->sht[s].plugin[i].name);
 			plugin_save(buf->sht[s].plugin[i].ph, b);
-			cfree(b);
+			MwFree(b);
 		}
 	}
 	/* save the main file */
 	b = file_name(buf, "INDEX.siag");
 	result = save_flat(b, buf);
-	cfree(b);
+	MwFree(b);
 	/* tar up the lot */
 	sprintf(cmd, "(cd %s;tar cf - *)>%s", dir, fn);
 	system(cmd);
-	cfree(dir);
+	MwFree(dir);
 	return result;
 }
 
 static int load(char *fn, buffer *buf)
 {
-	char cmd[1024];
+	char cmd[1024], b[1024];
 	char *p;
 	int n;
 
@@ -638,7 +651,7 @@ static int load(char *fn, buffer *buf)
 	if (flatfile(fn) || !tryuntar(fn, "INDEX.siag"))
 		return load_flat(fn, buf);
 
-	p = plugin_basedir(buf, NULL);
+	p = plugin_basedir(b, buf->name);
 	sprintf(cmd,
 		"mkdir -p %s;"
 		"cat %s 2> /dev/null |(cd %s;tar xf -) 2> /dev/null",
@@ -646,7 +659,7 @@ static int load(char *fn, buffer *buf)
 	system(cmd);
 	p = file_name(buf, "INDEX.siag");
 	n = load_flat(p, buf);
-	cfree(p);
+	MwFree(p);
 	return n;
 }
  
@@ -667,7 +680,7 @@ static int myformat(char *fn)
 
 	ext = strrchr(fn, '.');
 	if (!ext) return 0;	/* no extension */
-	if (cstrcasecmp(ext, ".siag"))
+	if (MwStrcasecmp(ext, ".siag"))
 		return 0;	/* wrong extension */
 	if (flatfile(fn))
 		return 1;	/* old format */
