@@ -1,6 +1,6 @@
 /*
    Siag, Scheme In A Grid
-   Copyright (C) 1996-1999  Ulric Eriksson <ulric@edu.stockholm.se>
+   Copyright (C) 1996-2002  Ulric Eriksson <ulric@siag.nu>
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -18,7 +18,8 @@
    MA 02111-1307, USA.
  */
 
-#ifdef GUILE
+#include "../config.h"
+#ifdef HAVE_LIBGUILE
 
 /*
  * guilei.c
@@ -26,12 +27,13 @@
 
 #include <stdio.h>
 #include <stdlib.h>
+#include <string.h>
 #include <ctype.h>
 #include <time.h>
 #include <signal.h>
 #include <sys/wait.h>
 
-#include "../common/cmalloc.h"
+#include <Mowitz/MwUtils.h>
 #include "../common/common.h"
 
 #include "calc.h"
@@ -225,7 +227,7 @@ static char *expand_references(buffer *buf, char *orig)
 	if (!rc) return orig;
 
 	/* strlen("(get-cell 10000 10000)")-strlen("a1") = 20 */
-	new = cmalloc(strlen(orig)+20*rc+1);
+	new = MwMalloc(strlen(orig)+20*rc+1);
 	ref_expander(buf, orig, new, BREAKCHARS, TEMPLATE, RANGE);
 	return new;
 }
@@ -244,12 +246,12 @@ static char *update_Guile_references(buffer *buf, char *expr, int r1, int c1,
 
 	/* rough upper bound on new length. A few bytes extra don't matter */
 	/* strlen("r100000c100000")-strlen("r1c1") = 10 */
-	p = cmalloc(strlen(expr)+20*rc+1);
+	p = MwMalloc(strlen(expr)+20*rc+1);
 	rc = ref_updater(buf, expr, p, BREAKCHARS, r1, c1, r2, c2, rd, cd);
 	if (rc) {
-		expr = cstrdup(p);
+		expr = MwStrdup(p);
 	}
-	cfree(p);
+	MwFree(p);
 	return expr;
 }
 
@@ -260,7 +262,7 @@ static SCM wrapper(void *data, SCM jmpbuf)
   char *scheme_code = (char *)data;
   char *expansion = expand_references(siag_buffer, scheme_code);
   SCM res = gh_eval_str(expansion);
-  if (expansion != scheme_code) cfree(expansion);
+  if (expansion != scheme_code) MwFree(expansion);
   return res;
 }
 
@@ -335,7 +337,10 @@ int init_guile_parser(void)
 				parse_guile_expr, execute_guile,
 				update_Guile_references);
 }
-#else	/* for the compiler */
-int guile_is_not_used;
+#else
+int init_guile_parser(void)
+{
+	return -1;
+}
 #endif	/* GUILE */
 
