@@ -1,6 +1,6 @@
 /*
    Siag, Scheme In A Grid
-   Copyright (C) 1996, 1997  Ulric Eriksson <ulric@edu.stockholm.se>
+   Copyright (C) 1996-2002  Ulric Eriksson <ulric@siag.nu>
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -23,20 +23,23 @@
 #include <unistd.h>
 #include <ctype.h>
 #include <string.h>
+#include <locale.h>
 #include <sys/stat.h>
 
-#include "../common/cmalloc.h"
+#include <Mowitz/MwUtils.h>
 #include "../common/common.h"
+#include <Mowitz/MwFormat.h>
 
 #include "../siag/calc.h"
 
+extern void init_db(void);
 extern void mainloop(void);
 
-#ifdef GUILE
+#ifdef HAVE_LIBGUILE
 #include <guile/gh.h>
 #endif
 
-#ifdef TCL
+#ifdef HAVE_LIBTCL
 #include <tcl.h>
 #endif
 
@@ -46,7 +49,12 @@ extern void init_position(void);        /* position.c */
 extern int init_C_parser(void);         /* ci.c */
 extern int init_parser(int, char **);   /* siodi.c */
 extern int init_guile_parser(void);     /* guilei.c */
+extern int init_ruby_parser(void);	/* ruby.c */
 extern void init_interpreters(void);    /* railway.c */
+extern void init_stocks(void);		/* stocks.c */
+extern void init_gmp(void);		/* gmp.c */
+extern void init_ccmath(void);		/* ccmath.c */
+extern void init_mathfunc(void);	/* mathfunc.c */
 
 static char *siagrc;
 
@@ -54,9 +62,7 @@ int ok2print = 0, grid_only = 0, plugin = 0;
 
 int siod_interpreter, C_interpreter;
 
-extern char *siag_format;       /* fileio.siag.c */
-
-#ifdef TCL
+#ifdef HAVE_LIBTCL
 extern int init_tcl_parser(Tcl_Interp *);       /* tcli.c */
 
 /* ---
@@ -69,15 +75,13 @@ int Tcl_AppInit(Tcl_Interp *interp)
 }
 #endif
 
-#ifdef PYTHON
 extern int init_python_parser(void);
-#endif
 
 static void malloc_fail_handler(void)
 {
-        fprintf(stderr, "Out of memory\n");
+	fprintf(stderr, "Memory allocation error.\n");
 
-        fprintf(stderr, "\t(should save all changed buffers before aborting)\n");
+	fprintf(stderr, "(should save all changed buffers before aborting)\n");
         abort();
 }
 
@@ -92,29 +96,32 @@ void realmain(int argc, char **argv)
         char path[1024];
         int i;
 
-	P_MIN = make_position(1, 1); /* real men use (0, 0) */
-	/* they don't have to deal with users, though ;-) */
+	setlocale(LC_NUMERIC, "C");
+	P_MIN = make_position(1, 1);
 
 	common_init("Siag (Scheme In A Grid) %s. No Warranty.");
 
 	sprintf(b, "%s/%ld", siag_basedir, (long)getpid());
 	mkdir(b, 0700);
         sprintf(b, "%s/siag.scm", siag_basedir);
-        siagrc = cstrdup(b);
+        siagrc = MwStrdup(b);
 
         siod_interpreter = init_parser(argc, argv);
         C_interpreter = init_C_parser();
-#ifdef PYTHON
 	init_python_parser();
-#endif
-#ifdef GUILE
         init_guile_parser();
-#endif
+	init_ruby_parser();
         init_mathwrap();        /* standard FP library functions */
 
         init_position();
         init_cmds();
 
+	init_stocks();
+	init_gmp();
+	init_ccmath();
+	init_db();
+	init_mathfunc();
+
         buf = new_buffer("noname.siag", "noname.siag");
 
         /* find runtime library */
@@ -128,10 +135,9 @@ void realmain(int argc, char **argv)
         }
 
         /* must set SIAGHOME like this if SLIBU is undefined */
-	setvar(cintern("libexecdir"), strcons(-1, libexecdir), NIL);
+	setvar(cintern("libdir"), strcons(-1, libdir), NIL);
 	setvar(cintern("datadir"), strcons(-1, datadir), NIL);
 	setvar(cintern("docdir"), strcons(-1, docdir), NIL);
-	setvar(cintern("siaghelp"), strcons(-1, siaghelp), NIL);
 
         /* now load runtime library */
         sprintf(b, "(load \"%s/siag/siag.scm\")", datadir);
@@ -145,6 +151,7 @@ void realmain(int argc, char **argv)
 
 	/* now doing this after siag.scm has been loaded */
         init_windows(buf, &argc, argv);
+	setlocale(LC_NUMERIC, "C");	/* chances are X hosed it */
 
 	/* Set ok2print only after init_windows is called */
         ok2print = 1;
@@ -155,10 +162,10 @@ void realmain(int argc, char **argv)
                 execute(b);
         }
 
-	/* do window initialization: keybindings, tooltips... */
-	execute("(init-windows)");
 	/* now create menus (this should be called from the UI code) */
 	execute("(create-menus)");
+	/* do window initialization: keybindings, tooltips... */
+	execute("(init-windows)");
 
         fileio_init();
         for (i = 1; i < argc; i++) {
@@ -185,10 +192,10 @@ void realmain(int argc, char **argv)
         waitforchild(0);
 
         /* we now have "valuable" data, so need for a better handler */
-        cmalloc_init(malloc_fail_handler, 1);
+        MwMallocInit(malloc_fail_handler, 1);
 
 
-#ifdef TCL
+#ifdef HAVE_LIBTCL
         Tcl_Main(argc, argv, Tcl_AppInit);
 #else
         mainloop();
@@ -199,7 +206,7 @@ void realmain(int argc, char **argv)
 */
 int main(int argc, char **argv)
 {
-#ifdef GUILE
+#ifdef HAVE_LIBGUILE
         gh_enter(argc, argv, realmain);
 #else
         realmain(argc, argv);
