@@ -1,6 +1,6 @@
 /*
    Siag, Scheme In A Grid
-   Copyright (C) 1996  Ulric Eriksson <ulric@edu.stockholm.se>
+   Copyright (C) 1996-2002  Ulric Eriksson <ulric@siag.nu>
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -32,10 +32,10 @@
 #include <time.h>
 
 #include "../common/common.h"
-#include "../common/cmalloc.h"
-#include "../common/fonts.h"
 
 #include "calc.h"
+#include <Mowitz/MwUtils.h>
+#include <Mowitz/MwFormat.h>
 
 
 /* ---
@@ -79,7 +79,7 @@ int name2style(char *name)
 	int i;
 	if (!name) return -1;
 	for (i = 0; i < nstyle; i++) {
-		if (!cstrcasecmp(name, style_table[i].name)) return i;
+		if (!MwStrcasecmp(name, style_table[i].name)) return i;
 	}
 	return -1;
 }
@@ -95,15 +95,15 @@ This function defines a new style/format or changes an existing one.
 int lookup_style(char *name, char *fmt, int type)
 {
 	int i = name2style(name);
-	char *newname = cstrdup(name);
-	char *newfmt = cstrdup(fmt);
+	char *newname = MwStrdup(name);
+	char *newfmt = MwStrdup(fmt);
 
 	if (i == -1) {	/* new style */
 		i = nstyle++;
-		style_table = crealloc(style_table, nstyle*sizeof *style_table);
+		style_table = MwRealloc(style_table, nstyle*sizeof *style_table);
 	} else {	/* redefine existing */
-		cfree(style_table[i].name);
-		cfree(style_table[i].fmt);
+		MwFree(style_table[i].name);
+		MwFree(style_table[i].fmt);
 	}
 	style_table[i].name = newname;
 	style_table[i].fmt = newfmt;
@@ -126,9 +126,9 @@ static int compar(const void *p, const void *q)
 char **style_list(int *n)
 {
 	int i;
-	char **list = (char **)cmalloc((nstyle+1)*sizeof(char *));
+	char **list = (char **)MwMalloc((nstyle+1)*sizeof(char *));
 	for (i = 0; i < nstyle; i++)
-		list[i] = cstrdup(style_table[i].name);
+		list[i] = MwStrdup(style_table[i].name);
 	list[i] = NULL;
 	qsort(list, i, sizeof(char *), compar);
 	*n = i;
@@ -163,7 +163,7 @@ int load_styles(FILE *fp)
 	strcpy(fmt, st.fmt);
 	st.fmt = fmt;
 	while (fgets(b, sizeof b, fp) && strncmp(b, "end", 3)) {
-		chomp(b);
+		MwChomp(b);
 		if (!strncmp(b, "name ", 5))
 			strcpy(st.name, b+5);
 		else if (!strncmp(b, "fmt ", 4))
@@ -177,6 +177,53 @@ int load_styles(FILE *fp)
 
 /* end of style code */
 
+/* ---
+check if a cell has been allocated
+*/
+
+static int is_alloc(buffer *b, int s, int row, int col)
+{
+	if (row < P_MIN.row || row > BUFFER_ROWS ||
+		col < P_MIN.col || col > BUFFER_COLS) return 0;
+	if (b->sht[s].matrix == NULL) return 0;
+	if (row > b->sht[s].alloc_lines) return 0;
+	if (b->sht[s].matrix[row] == NULL) return 0;
+	if (col > b->sht[s].alloc_cols[row]) return 0;
+	return 1;
+}
+
+/* Get and set default formats */
+void std_fmt_set(buffer *b, int newfmt)
+{
+	int s, r, c;
+	MwFmt osfmt, nsfmt;
+	int oldfmt = b->sf;
+	int lastr, lastc;
+	MwDecodeFormat(newfmt, ~MW_FMT_BORDERS, &nsfmt);
+	newfmt = MwEncodeFormat(~MW_FMT_BORDERS, &nsfmt);
+	MwDecodeFormat(oldfmt, ~MW_FMT_BORDERS, &osfmt);
+	oldfmt = MwEncodeFormat(~MW_FMT_BORDERS, &osfmt);
+	b->sf = newfmt;
+	for (s = 0; s < b->nsht; s++) {
+		lastr = line_last_used(b, s);
+		for (r = 1; r <= lastr; r++) {
+			lastc = col_last_used(b, s, r);
+			for (c = 1; c <= lastc; c++) {
+				if (is_alloc(b, s, r, c)
+				    && ret_type(b, s, r, c) == EMPTY
+				    && ret_format(b, s, r, c) == oldfmt) {
+					ins_format(b, s, r, c, newfmt);
+				}
+			}
+		}
+	}
+}
+
+int std_fmt_get(buffer *b)
+{
+	return b->sf;
+}
+
 /* ---
    void free_matrix(spread **matrix)
    Frees the memory used by the matrix.
@@ -184,7 +231,7 @@ int load_styles(FILE *fp)
 
 void free_matrix(spread ** matrix)
 {
-	cfree((char *) matrix);
+	MwFree((char *) matrix);
 }
 
 
@@ -206,7 +253,7 @@ void free_rows(buffer *b, int s, int r)
 
 	b->sht[s].alloc_lines = r-1;
 	while (r <= lr) {
-		cfree(b->sht[s].matrix[r]);
+		MwFree(b->sht[s].matrix[r]);
 		++r;
 	}
 }
@@ -219,19 +266,19 @@ static void alloc_cell(buffer *b, int sht, int row, int col)
 {
 	int i;
 
-	empty_cell.format = b->sf;
+	empty_cell.format = std_fmt_get(b);
 	if (b->sht[sht].matrix == NULL) {
-		b->sht[sht].matrix = (spread **)cmalloc((row+1)*sizeof(spread *));
-		b->sht[sht].alloc_cols = (int *)cmalloc((row+1)*sizeof(int));
+		b->sht[sht].matrix = (spread **)MwMalloc((row+1)*sizeof(spread *));
+		b->sht[sht].alloc_cols = (int *)MwMalloc((row+1)*sizeof(int));
 		for (i = 0; i <= row; i++) {
 			b->sht[sht].matrix[i] = NULL;
 			b->sht[sht].alloc_cols[i] = 0;
 		}
 		b->sht[sht].alloc_lines = row;
 	} else if (row > b->sht[sht].alloc_lines) {
-		b->sht[sht].matrix = (spread **)crealloc(b->sht[sht].matrix,
+		b->sht[sht].matrix = (spread **)MwRealloc(b->sht[sht].matrix,
 							(row+1)*sizeof(spread *));
-		b->sht[sht].alloc_cols = (int *)crealloc(b->sht[sht].alloc_cols,
+		b->sht[sht].alloc_cols = (int *)MwRealloc(b->sht[sht].alloc_cols,
 							(row+1)*sizeof(int));
 		for (i = b->sht[sht].alloc_lines+1; i <= row; i++) {
 			b->sht[sht].matrix[i] = NULL;
@@ -240,12 +287,12 @@ static void alloc_cell(buffer *b, int sht, int row, int col)
 		b->sht[sht].alloc_lines = row;
 	}
 	if (b->sht[sht].matrix[row] == NULL) {
-		b->sht[sht].matrix[row] = (spread *)cmalloc((col+1)*sizeof(spread));
+		b->sht[sht].matrix[row] = (spread *)MwMalloc((col+1)*sizeof(spread));
 		for (i = 0; i <= col; i++)
 			b->sht[sht].matrix[row][i] = empty_cell;
 		b->sht[sht].alloc_cols[row] = col;
 	} else if (col > b->sht[sht].alloc_cols[row]) {
-		b->sht[sht].matrix[row] = (spread *)crealloc(b->sht[sht].matrix[row],
+		b->sht[sht].matrix[row] = (spread *)MwRealloc(b->sht[sht].matrix[row],
 						(col+1)*sizeof(spread));
 		for (i = b->sht[sht].alloc_cols[row]+1; i <= col; i++)
 			b->sht[sht].matrix[row][i] = empty_cell;
@@ -289,18 +336,18 @@ int ins_data(buffer *b, int interpreter, char *texti, cval v, short t,
 		change = TRUE;
 	mrowcol->interpreter = interpreter;
 	if (mrowcol->text != texti) {	/* we could be restoring the same string */
-		if (mrowcol->text) cfree(mrowcol->text);
-		mrowcol->text = cstrdup(texti);
+		if (mrowcol->text) MwFree(mrowcol->text);
+		mrowcol->text = MwStrdup(texti);
 	}
 
 
 	if (t == STRING) {
-		if (v.text) p = cstrdup(v.text);
-		else p = cstrdup("");
+		if (v.text) p = MwStrdup(v.text);
+		else p = MwStrdup("");
 	}
 
 	if (mrowcol->type == STRING)	/* free the old value */
-		cfree(mrowcol->value.text);
+		MwFree(mrowcol->value.text);
 	
 	if (t == STRING)
 		mrowcol->value.text = p;
@@ -310,35 +357,28 @@ int ins_data(buffer *b, int interpreter, char *texti, cval v, short t,
 	return change;
 }				/* ins_data */
 
-/* ---
-check if a cell has been allocated
-*/
-
-static int is_alloc(buffer *b, int s, int row, int col)
-{
-	if (row < P_MIN.row || row > BUFFER_ROWS ||
-		col < P_MIN.col || col > BUFFER_COLS) return 0;
-	if (b->sht[s].matrix == NULL) return 0;
-	if (row > b->sht[s].alloc_lines) return 0;
-	if (b->sht[s].matrix[row] == NULL) return 0;
-	if (col > b->sht[s].alloc_cols[row]) return 0;
-	return 1;
-}
-
 /* ---
 */
 int ins_format(buffer *b, int s, int row, int col, int format)
 {
+	MwFmt fmt;
+	int nsfmt;
+
 	if (row > BUFFER_ROWS || col > BUFFER_COLS) {
-		b->sf = format;
+		std_fmt_set(b, format);
 		return FALSE;
 	}
+	MwDecodeFormat(format, ~0, &fmt);
+	nsfmt = MwEncodeFormat(~MW_FMT_BORDERS, &fmt);
 
-	if ( (format & BORDER_MASK) || is_alloc(b, s, row, col) ) {
+	if ( (fmt.borders & MW_BORDER_MASK) || is_alloc(b, s, row, col) ) {
 		alloc_cell(b, s, row, col);
 		b->sht[s].matrix[row][col].format = format;
-	} else {
-		b->sf = format;
+	}
+	if (!(fmt.borders & MW_BORDER_MASK)
+	    && ret_type(b, s, row, col) == EMPTY
+	    && std_fmt_get(b) != nsfmt) {
+		std_fmt_set(b, nsfmt);
 	}
 
 	return 1;
@@ -405,19 +445,10 @@ short ret_type(buffer *b, int s, int row, int col)
 */
 int ret_format(buffer *b, int s, int row, int col)
 {
-	if (!is_alloc(b, s, row, col)) return b->sf;
+	if (!is_alloc(b, s, row, col)) return std_fmt_get(b);
 	return b->sht[s].matrix[row][col].format;
 }
 
-/* ---
-this should probably go
-*/
-
-int ret_font(buffer *b, int s, int row, int col)
-{
-	return format_table[ret_format(b, s, row, col)].font;
-}
-
 /* ---
 */
 char *ret_pvalue(char *buf, buffer *b, int s, int row, int col, int mode)
@@ -429,6 +460,7 @@ char *ret_pvalue(char *buf, buffer *b, int s, int row, int col, int mode)
 	time_t ttime;
 	struct tm *ltime;
 	char *fmt;
+	MwFmt mfmt;
 
 	f = 0.0;
 
@@ -439,7 +471,10 @@ char *ret_pvalue(char *buf, buffer *b, int s, int row, int col, int mode)
 	}
 	type = ret_type(b, s, row, col);
 
-	if (mode < 0) mode = format_table[ret_format(b, s, row, col)].style;
+	if (mode < 0) {
+		MwDecodeFormat(ret_format(b, s, row, col), MW_FMT_STYLE, &mfmt);
+		mode = mfmt.style;
+	}
 
 	if (type == EMPTY || style_table[mode].type == INVISIBLE) {
 		return buf;
@@ -450,7 +485,7 @@ char *ret_pvalue(char *buf, buffer *b, int s, int row, int col, int mode)
 	if (type == ERROR) {
 		return strcpy(buf, "ERROR");
 	}
-	if (type == LABEL || type == EMBED) {
+	if (type == LABEL || type == EMBED || type == MTEXT) {
 		return strncpy(buf, ret_text(b, s, row, col), 1000);
 	}
 
@@ -520,23 +555,25 @@ void downshift_matrix(buffer *b, int s, int row)
 {
 	int i;
 
+	alloc_cell(b, s, 1, 1);	/* magic */
+
 	/* free the last line, if there is anything in it */
 	if (b->sht[s].alloc_lines > BUFFER_ROWS && b->sht[s].matrix[BUFFER_ROWS])
-		cfree(b->sht[s].matrix[BUFFER_ROWS]);
+		MwFree(b->sht[s].matrix[BUFFER_ROWS]);
 
 	/* extend the line allocation in the matrix */
 	if (b->sht[s].alloc_lines >= row && b->sht[s].alloc_lines < BUFFER_ROWS) {
 		b->sht[s].alloc_lines++;
-		b->sht[s].matrix = (spread **)crealloc(b->sht[s].matrix,
+		b->sht[s].matrix = (spread **)MwRealloc(b->sht[s].matrix,
 						(b->sht[s].alloc_lines+1)*sizeof(spread *));
-		b->sht[s].alloc_cols = (int *)crealloc(b->sht[s].alloc_cols,
+		b->sht[s].alloc_cols = (int *)MwRealloc(b->sht[s].alloc_cols,
 						(b->sht[s].alloc_lines+1)*sizeof(int));
 	}
 
 	/* extend the height table */
 	if (b->sht[s].used_lines >= row && b->sht[s].used_lines < BUFFER_ROWS) {
 		b->sht[s].used_lines++;
-		b->sht[s].height = (int *)crealloc(b->sht[s].height, (b->sht[s].used_lines+1)*sizeof(int));
+		b->sht[s].height = (int *)MwRealloc(b->sht[s].height, (b->sht[s].used_lines+1)*sizeof(int));
 	}
 
 	/* move all the stuff down one line */
@@ -570,9 +607,11 @@ void upshift_matrix(buffer *b, int s, int row)
 {
 	int i;
 
+	alloc_cell(b, s, 1, 1);	/* magic */
+
 	/* free the first line, if there is anything in it */
 	if (b->sht[s].alloc_lines > row && b->sht[s].matrix[row])
-		cfree(b->sht[s].matrix[row]);
+		MwFree(b->sht[s].matrix[row]);
 
 	/* we don't bother to shrink the matrix or height table */
 
@@ -606,11 +645,14 @@ void upshift_matrix(buffer *b, int s, int row)
 void rightshift_matrix(buffer *b, int s, int col)
 {
 	int i, j;
-	empty_cell.format = b->sf;
+	empty_cell.format = std_fmt_get(b);
+
+	alloc_cell(b, s, 1, 1);	/* magic */
+
 	/* extend the width table if necessary */
 	if (b->sht[s].used_cols >= col && b->sht[s].used_cols < BUFFER_COLS) {
 		b->sht[s].used_cols++;
-		b->sht[s].width = (int *)crealloc(b->sht[s].width, (b->sht[s].used_cols+1)*sizeof(int));
+		b->sht[s].width = (int *)MwRealloc(b->sht[s].width, (b->sht[s].used_cols+1)*sizeof(int));
 		for (i = b->sht[s].used_cols; i > col; i--)
 			b->sht[s].width[i] = b->sht[s].width[i-1];
 		b->sht[s].width[col] = 80;
@@ -622,7 +664,7 @@ void rightshift_matrix(buffer *b, int s, int col)
 			/* check if it needs to grow */
 			if (b->sht[s].alloc_cols[i] >= col) {
 				b->sht[s].alloc_cols[i]++;
-				b->sht[s].matrix[i] = (spread *)crealloc(b->sht[s].matrix[i],
+				b->sht[s].matrix[i] = (spread *)MwRealloc(b->sht[s].matrix[i],
 						(b->sht[s].alloc_cols[i]+1)*sizeof(spread));
 			}
 
@@ -653,8 +695,11 @@ void leftshift_matrix(buffer *b, int s, int col)
 {
 	int i, j;
 
-	empty_cell.format = b->sf;
+	empty_cell.format = std_fmt_get(b);
 	/* do not shrink the width table */
+
+	alloc_cell(b, s, 1, 1);	/* magic */
+
 	for (j = col; j < b->sht[s].used_cols; j++)
 		b->sht[s].width[j] = b->sht[s].width[j + 1];
 	if (b->sht[s].used_cols >= col)
@@ -696,18 +741,18 @@ void fill_area(buffer *b, int s, int r1, int c1, int r2, int c2)
 	int tr = ret_type(b, s, r1+1, c1);
 	int tc = ret_type(b, s, r1, c1+1);
 
-	af = (type == EXPRESSION
-	      && (r1 == r2 || tr == EXPRESSION)
-	      && (c1 == c2 || tc == EXPRESSION));
+	af = (IS_NUMBER(type)
+	      && (r1 == r2 || IS_NUMBER(tr))
+	      && (c1 == c2 || IS_NUMBER(tc)));
 
-	if (type == EXPRESSION) {
+	if (IS_NUMBER(type)) {
 		d1 = value.number;
 		/* figure out row delta */
-		if (tr == EXPRESSION) {
+		if (IS_NUMBER(tr)) {
 			d2 = ret_val(b, s, r1+1, c1).number;
 			dr = d2-d1;
 		}
-		if (tc == EXPRESSION) {
+		if (IS_NUMBER(tc)) {
 			d2 = ret_val(b, s, r1, c1+1).number;
 			dc = d2-d1;
 		}
@@ -721,7 +766,7 @@ void fill_area(buffer *b, int s, int r1, int c1, int r2, int c2)
 				dd.number = d1+(r-r1)*dr+(c-c1)*dc;
 				sprintf(p, "%g", dd.number);
 				ins_data(b, C_interpreter, p, dd,
-					type, s, r, c);
+					CONSTANT, s, r, c);
 			} else {
 				ins_data(b, intp, text, value,
 					type, s, r, c);
@@ -746,7 +791,7 @@ char *pack_area(buffer *b, int s, int r1, int c1, int r2, int c2,
 
 	/* use fixed size buffer for now */
 	*size = 32000;
-	p = cmalloc(*size);
+	p = MwMalloc(*size);
 	data = p;
 	sprintf(data, "%d %d", r2-r1+1, c2-c1+1);
 	data += strlen(data)+1;
@@ -761,6 +806,10 @@ char *pack_area(buffer *b, int s, int r1, int c1, int r2, int c2,
 				sprintf(data, "\"%s",
 					ret_text(b, s, r, c));
 				break;
+			case CONSTANT:
+				sprintf(data, "=%s",
+					ret_text(b, s, r, c));
+				break;
 			case EMBED:
 				sprintf(data, "m%s",
 					ret_text(b, s, r, c));
@@ -774,7 +823,7 @@ char *pack_area(buffer *b, int s, int r1, int c1, int r2, int c2,
 			}
 			data += strlen(data)+1;
 			if (data-p > 31000) {
-				cfree(p);
+				MwFree(p);
 				return NULL;
 			}
 		}
@@ -801,7 +850,6 @@ void unpack_area(buffer *b, char *data, int s, int r1, int c1)
 	int len;
 
 	if (!data) return;
-	value.number = 0;
 	sscanf(data, "%d %d", &rows, &cols);
 
 	data += strlen(data)+1;
@@ -817,12 +865,19 @@ void unpack_area(buffer *b, char *data, int s, int r1, int c1)
 	r = r1;
 	c = c1;
 	while (*data) {
+		value.number = 0;
 		switch (*data++) {
 		case '"':
 			texti = data;
 			ins_data(b, siod_interpreter,
 				texti, value, LABEL, s, r, c++);
 			break;
+		case '=':
+			texti = data;
+			value.number = strtod(texti, NULL);
+			ins_data(b, siod_interpreter,
+				texti, value, CONSTANT, s, r, c++);
+			break;
 		case '+':
 			comma = strchr(data, ',');
 			if (!comma) {
@@ -871,7 +926,7 @@ int undo_save(buffer *b, int s, int r1, int c1, int r2, int c2)
 {
 	int size;
 
-	cfree(undo_buffer.data);
+	MwFree(undo_buffer.data);
 	undo_buffer.s = s;
 	undo_buffer.r1 = r1;
 	undo_buffer.c1 = c1;
