@@ -1,6 +1,6 @@
 /*
    Siag, Scheme In A Grid
-   Copyright (C) 1996-1999  Ulric Eriksson <ulric@edu.stockholm.se>
+   Copyright (C) 1996-2002  Ulric Eriksson <ulric@siag.nu>
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -28,7 +28,7 @@
 #include <stdlib.h>
 #include <string.h>
 
-#include "../common/cmalloc.h"
+#include <Mowitz/MwUtils.h>
 #include "../common/common.h"
 
 #include "calc.h"
@@ -43,12 +43,43 @@ extern void init_tar(void);
 /* from slib.c */
 extern char *repl_c_string_arg;
 extern long repl_c_string_flag;
-extern LISP repl_c_string_read();
+extern LISP repl_c_string_read(void);
 
 static int siag_sht;
 static int siag_row, siag_col;
 static cval siag_result;
 static buffer *siag_buffer;
+/*
+;@siag_rowsum(r1, r2)
+;@Returns the sum of all cells in the current column from row r1 to r2.
+;@
+;@siag_colsum
+*/
+static LISP lsiag_rowsum(LISP c1, LISP c2)
+{
+	double sum = 0;
+	int i;
+	long tmp = get_c_long(c2);
+	for (i = get_c_long(c1); i <= tmp; i++)
+		sum += ret_val(siag_buffer, siag_sht, i, siag_col).number;
+	return flocons(sum);
+}
+
+/*
+;@siag_colsum(c1, c2)
+;@Returns the sum of all cells on the current row from column c1 to c2.
+;@
+;@siag_rowsum
+*/
+static LISP lsiag_colsum(LISP c1, LISP c2)
+{
+	double sum = 0;
+	int i;
+	long tmp = get_c_long(c2);
+	for (i = get_c_long(c1); i <= tmp; i++)
+		sum += ret_val(siag_buffer, siag_sht, siag_row, i).number;
+	return flocons(sum);
+}
 
 static LISP lput_property(LISP bname, LISP key, LISP value)
 {
@@ -125,6 +156,9 @@ static LISP x_get_cell(LISP row, LISP col, LISP bname)
 	case LABEL:
 		p = ret_text(buf, s, r, c);
 		return strcons(strlen(p), p);
+	case EMPTY:
+	case ERROR:
+		return NIL;
 	default:
 		return flocons(ret_val(buf, s, r, c).number);
 	}
@@ -169,7 +203,7 @@ static LISP get_string(LISP row, LISP col)
 static LISP get_type(LISP bname, LISP row, LISP col)
 {
 	buffer *buf;
-	int s;
+	int s, t, r, c;
 
 	if (NULLP (bname)) {
 		buf = buffer_of_window(w_list);
@@ -179,7 +213,10 @@ static LISP get_type(LISP bname, LISP row, LISP col)
 					w_list->buf, &s);
 	}
 
-	return flocons(ret_type(buf, s, get_c_long(row), get_c_long(col)));
+	r = get_c_long(row);
+	c = get_c_long(col);
+	t = ret_type(buf, s, r, c);
+	return flocons(t);
 }
 
 static LISP get_text(LISP row, LISP col)
@@ -252,6 +289,19 @@ static void siag_print(LISP p)
 #define TEMPLATE "(get-cell %ld %ld)"
 #define RANGE "'RANGE %ld %ld %ld %ld"
 
+static LISP get_xref(LISP bname, LISP cell)
+{
+	char new[1000];
+	char *old = get_c_string(cell);
+	long row, col;
+	buffer *buf;
+	if (NULLP(bname)) buf = buffer_of_window(w_list);
+	else buf = find_buffer_by_name(get_c_string(bname));
+	ref_expander(buf, old, new, BREAKCHARS, "%ld %ld", RANGE);
+	sscanf(new, "%ld %ld", &row, &col);
+	return x_get_cell(flocons(row), flocons(col), bname);
+}
+
 /* ---
 expand Visicalc references
 */
@@ -264,7 +314,7 @@ static char *expand_references(buffer *buf, char *orig)
 	if (!rc) return orig;
 
 	/* strlen("(get-cell 10000 10000)")-strlen("a1") = 20 */
-	new = cmalloc(strlen(orig)+20*rc+1);
+	new = MwMalloc(strlen(orig)+20*rc+1);
 
 	ref_expander(buf, orig, new, BREAKCHARS, TEMPLATE, RANGE);
 	return new;
@@ -285,12 +335,12 @@ static char *update_SIOD_references(buffer *buf, char *expr, int r1, int c1,
 
 	/* rough upper bound on new length. A few bytes extra don't matter */
 	/* strlen("r100000c100000")-strlen("r1c1") = 10 */
-	p = cmalloc(strlen(expr)+10*rc+1);
+	p = MwMalloc(strlen(expr)+10*rc+1);
 	rc = ref_updater(buf, expr, p, BREAKCHARS, r1, c1, r2, c2, rd, cd);
 	if (rc) {
-		expr = cstrdup(p);
+		expr = MwStrdup(p);
 	}
-	cfree(p);
+	MwFree(p);
 	return expr;
 }
 
@@ -318,7 +368,7 @@ static long wrapper(buffer *b, char *expr, int s, int row, int col)
 	setvar(cintern("C"), flocons((double)siag_col), NIL);
 
 	retval = repl_driver(want_sigint, want_init, &h);
-	if (expansion != expr) cfree(expansion);
+	if (expansion != expr) MwFree(expansion);
 	want_init = 0;			/* only once... */
 	return retval;
 }
@@ -466,6 +516,91 @@ static LISP set_pr_scr(void)
 	return NIL;
 }
 
+/* Convert (R . I) to R or "R+Ij". Result is number if I = 0, else string */
+static LISP imint2ext(LISP v)
+{
+	double r, i;
+	char b[1024];
+	r = get_c_double(CAR(v));
+	i = get_c_double(CDR(v));
+	if (i == 0) return CAR(v);
+	if (r == 0) {
+		if (i == -1) strcpy(b, "-i");
+		else if (i == 1) strcpy(b, "i");
+		else sprintf(b, "%gi", i);
+	} else {
+		if (i == -1) sprintf(b, "%g-i", r);
+		else if (i == 1) sprintf(b, "%g+i", r);
+		else if (i < 0) sprintf(b, "%g-%gi", r, -i);
+		else sprintf(b, "%g+%gi", r, i);
+	}
+	return strcons(strlen(b), b);
+}
+
+/* If v is number, returns (R . 0). If v is string, it is assumed to be
+   of the form [+-]?R[+-]I[ij] where R and I are floating point numbers. */
+static LISP imext2int(LISP v)
+{
+	char *p, *q;
+	double rv, iv;
+	if (FLONUMP(v)) return cons(v, flocons(0));
+	p = get_c_string(v);
+	if (!strcmp(p, "i") || !strcmp(p, "j")) {
+		rv = 0;
+		iv = 1;
+	} else if (!strcmp(p, "-i") || !strcmp(p, "-j")) {
+		rv = 0;
+		iv = -1;
+	} else {
+		rv = strtod(p, &q);
+		if (q == p) return NIL;
+		if (*q == 'i' || *q == 'j') {
+			iv = rv;
+			rv = 0;
+		} else if (*q == '\0') {
+			iv = 0;
+		} else if (!strcmp(q, "+i") || !strcmp(q, "+j")) {
+			iv = 1;
+		} else if (!strcmp(q, "-i") || !strcmp(q, "-j")) {
+			iv = -1;
+		} else {
+			iv = strtod(q, &p);
+			if (p == q) return NIL;
+			if (*p != 'i' && *p != 'j') return NIL;
+		}
+	}
+	return cons(flocons(rv), flocons(iv));
+}
+
+static LISP lset_array_value(LISP row, LISP col, LISP value)
+{
+	cval val;
+	int r = get_c_long(row), c = get_c_long(col);
+	char i[100];
+
+	if (FLONUMP(value)) {
+		val.number = get_c_double(value);
+		sprintf(i, "%g", val.number);
+		ins_data(siag_buffer, C_interpreter,
+			i, val, MNUMBER, siag_sht, r, c);
+	} else if (TYPEP(value, tc_string)) {
+		val.text = get_c_string(value);
+		ins_data(siag_buffer, C_interpreter,
+			val.text, val, MTEXT, siag_sht, r, c);
+	} else {
+		;
+	}
+	return value;
+}
+
+void get_siod_coords(int *row, int *col, int *sheet, buffer **buf)
+{
+	*row = siag_row;
+	*col = siag_col;
+	*sheet = siag_sht;
+	*buf = siag_buffer;
+}
+
 /* ---
 */
 void init_position(void)
@@ -487,6 +622,9 @@ void init_position(void)
 	init_subr_0("set-pr-scr", set_pr_scr);
 	init_subr_3("put-property", lput_property);
 	init_subr_2("get-property", lget_property);
+	init_subr_2("siag_rowsum", lsiag_rowsum);
+	init_subr_2("siag_colsum", lsiag_colsum);
+	init_subr_3("set_array_value", lset_array_value);
 }
 
 /* dummy args for SIOD */
@@ -521,10 +659,13 @@ int init_parser(int argc, char **argv)
 	init_subr_2("get-string", get_string);
 	init_subr_3("get-type", get_type);
 	init_subr_2("get-text", get_text);
+	init_subr_2("get_xref", get_xref);
 	init_subr_2("sum", siag_sum);
 	init_subr_3("x-get-cell", x_get_cell);
 	init_subr_3("x-get-string", x_get_string);
 	init_subr_0("time", siag_time);
+	init_subr_1("imint2ext", imint2ext);
+	init_subr_1("imext2int", imext2int);
 	init_subr_2("exec-expr", lexec_expr);
 
 	return register_interpreter("SIOD", parse_SIOD_expr, execute_siod,
