@@ -1,6 +1,6 @@
 /*
    Siag, Scheme In A Grid
-   Copyright (C) 1996, 1997  Ulric Eriksson <ulric@edu.stockholm.se>
+   Copyright (C) 1996-2002  Ulric Eriksson <ulric@siag.nu>
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -18,7 +18,8 @@
    MA 02111-1307, USA.
  */
 
-#ifdef TCL
+#include "../config.h"
+#ifdef HAVE_LIBTCL
 
 /*
  * tcli.c
@@ -48,11 +49,6 @@ static int siag_sht;
 static double value;
 static int tcl_interpreter;
 
-static int only_space(char *p)
-{
-	while (*p && isspace(*p)) p++;
-	return (*p == '\0');
-}
 
 static int guess_type(char *p)
 {
@@ -157,8 +153,9 @@ static int get_cell(ClientData clientdata, Tcl_Interp *interp,
 {
 	int r = args[0].intValue;
 	int c = args[1].intValue;
+	int type = ret_type(siag_buffer, siag_sht, r, c);
 
-	if (ret_type(siag_buffer, siag_sht, r, c) == EXPRESSION)
+	if (IS_NUMBER(type))
 		resultPtr->doubleValue = ret_val(siag_buffer,
 						siag_sht, r, c).number;
 		else resultPtr->doubleValue = 0;
