@@ -90,7 +90,7 @@ gjc@world.std.com
 
 static void init_slib_version(void)
 {setvar(cintern("*slib-version*"),
-	cintern("$Id: slib.c,v 1.2 1999/01/05 22:40:52 ulric Exp $"),
+	cintern("$Id: slib.c,v 1.3 2000/11/01 15:04:13 ulric Exp $"),
 	NIL);}
 
 char *siod_version(void)
@@ -838,13 +838,13 @@ char *must_malloc(unsigned long size)
 
 LISP gen_intern(char *name,long copyp)
 {LISP l,sym,sl;
- char *cname;
+ unsigned char *cname;
  long hash=0,n,c,flag;
  flag = no_interrupt(1);
  if (obarray_dim > 1)
    {hash = 0;
     n = obarray_dim;
-    cname = name;
+    cname = (unsigned char *)name;
     while((c = *cname++)) hash = ((hash * 17) ^ c) % n;
     sl = obarray[hash];}
  else
@@ -854,10 +854,10 @@ LISP gen_intern(char *name,long copyp)
      {no_interrupt(flag);
       return(CAR(l));}
  if (copyp == 1)
-   {cname = (char *) must_malloc(strlen(name)+1);
-    strcpy(cname,name);}
+   {cname = (unsigned char *) must_malloc(strlen(name)+1);
+    strcpy((char *)cname,name);}
  else
-   cname = name;
+   cname = (unsigned char *)name;
  sym = symcons(cname,unbound_marker);
  if (obarray_dim > 1) obarray[hash] = cons(sym,sl);
  oblistvar = cons(sym,oblistvar);
