@@ -27,6 +27,9 @@ Removed all dynamic library code.
 #ifndef unix
 #define unix
 #endif
+#ifndef __USE_XOPEN
+#define __USE_XOPEN
+#endif
 
 #include <stdio.h>
 #include <string.h>
@@ -80,7 +83,7 @@ Removed all dynamic library code.
 
 static void init_slibu_version(void)
 {setvar(cintern("*slibu-version*"),
-	cintern("$Id: slibu.c,v 1.5 1999/01/31 00:05:52 ulric Exp $"),
+	cintern("$Id: slibu.c,v 1.6 2000/10/12 14:55:34 ulric Exp $"),
 	NIL);}
 
 
