@@ -2,53 +2,22 @@
 #include <stdlib.h>
 #include <string.h>
 #include "../common/common.h"
-#include "../common/cmalloc.h"
+#include <Mowitz/MwUtils.h>
 #include "../siod/siod.h"
 #include "../siag/calc.h"
 #include "tsiag.h"
 
-LISP add_menu(LISP label)
-{
-	return NIL;
-}
+static LISP lbogus(void) { return NIL; }
+static LISP lbogus1(LISP a) { return NIL; }
+static LISP lbogus2(LISP a, LISP b) { return NIL; }
+static LISP lbogus3(LISP a, LISP b, LISP c) { return NIL; }
+static LISP lbogus4(LISP a, LISP b, LISP c, LISP d) { return NIL; }
 
-LISP remove_menu(LISP label)
-{
-	return NIL;
-}
-
-LISP add_menu_entry(LISP lisp_menu, LISP label, LISP function)
-{
-	return NIL;
-}
-
-LISP add_submenu(LISP label, LISP sublabel)
-{
-	return NIL;
-}
-
-LISP remove_submenu(LISP label, LISP sublabel)
-{
-	return NIL;
-}
-
-LISP add_submenu_entry(LISP menu, LISP submenu,
-                                  LISP label, LISP function)
-{
-	return NIL;
-}
-
-LISP remove_submenu_entry(LISP menu, LISP submenu,
-                                  LISP label, LISP function)
-{
-	return NIL;
-}
-
-int select_file(char *path, char *name, char **patterns, char *fmt)
+int select_file(char *path, char *name, char **patterns, char *fmt, int e)
 {
 	int nchoices, format;
 
-	TRACEME((f, "select_file"));
+	MW_TRACE((f, "select_file"));
 
 	for (nchoices = 0; patterns[nchoices]; nchoices++);
 
@@ -64,14 +33,24 @@ int alert_box(char *text, char **buttons, int nbuttons)
 	return select_from_list(text, buttons, nbuttons);
 }
 
+void about_box(char *text)
+{
+	llpr(text);
+}
+
+void about_siag(void)
+{
+	llpr("Siag Office");
+}
+
 void error_box(char *message)
 {
 	llpr(message);
 }
 
-LISP set_block(void)
+static LISP set_block(void)
 {
-	TRACEME((f, "set_block is starting"));
+	MW_TRACE((f, "set_block is starting"));
 
         if (get_point(w_list).row < get_mark(w_list).row) {
                 set_blku_row(w_list, get_point(w_list).row);
@@ -93,9 +72,9 @@ LISP set_block(void)
         return NIL;
 }
 
-LISP unset_block()
+static LISP unset_block()
 {
-	TRACEME((f, "unset_block is starting"));
+	MW_TRACE((f, "unset_block is starting"));
 
         set_blku(w_list, sub_position(P_MIN, make_position(1, 1)));
         set_blkl(w_list, sub_position(P_MIN, make_position(1, 1)));
@@ -105,11 +84,11 @@ LISP unset_block()
 }
 
 /* this one overrides the one in siag/cmds.c */
-LISP execute_extended_command()
+static LISP execute_extended_command()
 {
 	char b[256];
 
-	TRACEME((f, "execute_extended_command"));
+	MW_TRACE((f, "execute_extended_command"));
 
 	b[0] = '\0';
 
@@ -135,7 +114,6 @@ int ps_font_size(int index) { return 10; }
 char **plugin_patterns = NULL;
 int plugin_write(int ph, char *b)			{ return 0; }
 int plugin_read(int ph, char *b)			{ return 0; }
-LISP lplugin_register(LISP desc, LISP ext, LISP cmd)	{ return NIL; }
 int plugin_register(char *desc, char *ext, char *cmd)	{ return -1; }
 int plugin_start(char *fn)				{ return -1; } 
 int plugin_stop(int ph)					{ return -1; }
@@ -147,19 +125,28 @@ int plugin_print(int ph, FILE *fp, int x, int y, int t)	{ return -1; }
 
 void interp_startup()
 {
-	TRACEME((f,"interp_startup"));
+	MW_TRACE((f,"interp_startup"));
 
+	init_subr_0("get-geometry", lbogus);
+	init_subr_0("fit-block-width", lbogus);
+	init_subr_0("fit-block-height", lbogus);
+	init_subr_0("embed-object", lbogus);
+	init_subr_0("embed-remove", lbogus);
+	init_subr_0("embed-open", lbogus);
+	init_subr_0("embed-save", lbogus);
+	init_subr_0("copy-block", lbogus);
 	init_subr_0("set-block", set_block);
 	init_subr_0("unset-block", unset_block);
 	init_subr_0("execute-extended-command", execute_extended_command);
-	init_subr_1("add-menu", add_menu);
-	init_subr_3("add-menu-entry", add_menu_entry);
-	init_subr_2("add-submenu", add_submenu);
-	init_subr_4("add-submenu-entry", add_submenu_entry);
-	init_subr_1("remove-menu", add_menu);
-	init_subr_3("remove-menu-entry", add_menu_entry);
-	init_subr_2("remove-submenu", add_submenu);
-	init_subr_4("remove-submenu-entry", add_submenu_entry);
-	init_subr_3("plugin-register", lplugin_register);
+	init_subr_1("add-menu", lbogus1);
+	init_subr_3("add-menu-entry", lbogus3);
+	init_subr_2("add-submenu", lbogus2);
+	init_subr_4("add-submenu-entry", lbogus4);
+	init_subr_1("remove-menu", lbogus1);
+	init_subr_3("remove-menu-entry", lbogus3);
+	init_subr_2("remove-submenu", lbogus2);
+	init_subr_4("remove-submenu-entry", lbogus4);
+	init_subr_1("tooltip-mode", lbogus1);
+	init_subr_3("plugin-register", lbogus3);
 }
 
