@@ -1,6 +1,6 @@
 /*
    Siag, Scheme In A Grid
-   Copyright (C) 1996  Ulric Eriksson <ulric@edu.stockholm.se>
+   Copyright (C) 1996-2002  Ulric Eriksson <ulric@siag.nu>
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -31,25 +31,26 @@
 #include <unistd.h>
 #include <ctype.h>
 
+#include <termios.h>
 #include <sys/stat.h>
 #include <sys/ioctl.h>
 
 #include "../config.h"
 
-#include "../common/cmalloc.h"
+#include <Mowitz/MwUtils.h>
+#include <Mowitz/MwFormat.h>
 #include "../common/common.h"
-#include "../common/fonts.h"
 
 #include "../siag/calc.h"
 #include "../siod/siod.h"
 
 #include "tsiag.h"
 
-#ifdef GUILE
+#ifdef HAVE_LIBGUILE
 #include <guile/gh.h>
 #endif
 
-#ifdef TCL
+#ifdef HAVE_LIBTCL
 #include <tcl.h>
 #endif
 
@@ -92,14 +93,16 @@ struct {
 	int index, size;
 } input_queue;
 
-sfmt fmt0 = {"Helvetica", 100, 0, 0, 0, "black", "white", 0, 0, 0, 0};
-sfmt fmt1 = {"Helvetica", 120, 0, 0, 0, "black", "grey", 0, VADJ_CENTER, HADJ_CENTER, 0};
+MwFmt fmt0 = {"Helvetica", 100, 0, 0, 0, 0, "black", "white", 0, 0, 0, 0};
+MwFmt fmt1 = {"Helvetica", 120, 0, 0, 0, 0, "black", "grey", 0, MW_VADJ_CENTER, MW_HADJ_CENTER, 0};
 
 int columns;    /* number of cells per line */
 int width;      /* default cell width */
 int left_margin;
 /*int right_margin = 5;*/
 
+float zoom = 1.0;	/* unused */
+
 position old;
 
 int rowcol_fmt_index;
@@ -132,27 +135,27 @@ void pr_region(window *w, position screen_start, position screen_size, position
 
 	for (j = 0; j < screen_size.col; j++) {
 		for (i = 0; i < screen_size.row; i++) {
-			sfmt fmt;
-			decode_format(ret_format(buffer_of_window(w), w->sht, data_start.row + i, data_start.col + j), ~0, &fmt);
+			MwFmt fmt;
+			MwDecodeFormat(ret_format(buffer_of_window(w), w->sht, data_start.row + i, data_start.col + j), ~0, &fmt);
 
-			if (fmt.borders & BORDER_RIGHT) {
+			if (fmt.borders & MW_BORDER_RIGHT) {
 				wmove(stdscr, 1 + screen_start.row + i, left_margin + (screen_start.col + j + 1) * width - 1);
 				waddch(stdscr, VLINE);
 			}
-			if (fmt.borders & BORDER_LEFT) {
+			if (fmt.borders & MW_BORDER_LEFT) {
 				wmove(stdscr, 1 + screen_start.row + i, left_margin + (screen_start.col + j) * width - 1);
 				waddch(stdscr, VLINE);
 			}
-			if (fmt.borders & BORDER_TOP) {
+			if (fmt.borders & MW_BORDER_TOP) {
 				int k;
 				wmove(stdscr, 1 + screen_start.row + i, 1 + left_margin + (screen_start.col + j) * width);
-				for (k = 0; k < width - (fmt.borders & BORDER_RIGHT ? 2 : 1); k++)
+				for (k = 0; k < width - (fmt.borders & MW_BORDER_RIGHT ? 2 : 1); k++)
 					waddch(stdscr, S1);
 			}
-			if (fmt.borders & BORDER_BOTTOM) {
+			if (fmt.borders & MW_BORDER_BOTTOM) {
 				int k;
 				wmove(stdscr, 1 + screen_start.row + i, 1 + left_margin + (screen_start.col + j) * width);
-				for (k = 0; k < width - (fmt.borders & BORDER_RIGHT ? 2 : 1); k++)
+				for (k = 0; k < width - (fmt.borders & MW_BORDER_RIGHT ? 2 : 1); k++)
 					waddch(stdscr, S9);
 			}
 
@@ -213,14 +216,17 @@ void pr_scr(window *w)
 {
 	buffer *b = b_list;
 
-	TRACEME((f, "pr_scr(): b->recalc=%d, recalc=%d", b->recalc, recalc));
+	MW_TRACE((f, "pr_scr(): b->recalc=%d, recalc=%d", b->recalc, recalc));
 
 	do {
 		if (b->recalc) {
 			int i, s;
 			b->recalc = 0;
-			for (s = 0; s < b->nsht; s++)
-				for (i = 0; i < recalc; i++) calc_matrix(b);
+			for (i = 0; i < recalc; i++) {
+				for (s = 0; s < b->nsht; s++) {
+					calc_matrix(b);
+				}
+			}
 		}
 		b = b->next;
 	} while (b != b_list);
@@ -262,7 +268,7 @@ int ask_for_str_comp(char *prompt, char *buffr, int (*comp)(char *))
 	int modified_flag = FALSE;
 	textbuf t;
 
-	TRACEME((f, "ask_for_str_comp: %s | %s", prompt, buffr));
+	MW_TRACE((f, "ask_for_str_comp: %s | %s", prompt, buffr));
 
 	/* this is a temporary fix until xsiag can do macros */
 	t.size=1;
@@ -382,7 +388,7 @@ int ask_for_str_comp(char *prompt, char *buffr, int (*comp)(char *))
 /* EXTERNAL */
 int edit_cell(char *p, char *b)
 {
-	TRACEME((f, "edit_cell"));
+	MW_TRACE((f, "edit_cell"));
 
 	wmove(stdscr, 1 - P_MIN.row + get_point(w_list).row - get_top(w_list).row + get_prot(w_list).row, left_margin + width * (get_point(w_list).col - get_top(w_list).col - P_MIN.col + get_prot(w_list).col) - 1);
 	waddch(stdscr, RARROW);
@@ -397,7 +403,7 @@ int edit_cell(char *p, char *b)
 Macros longer than KB_MAX charactesr are not allowed. */
 void record_macro(int c)
 {
-	TRACEME((f, "record_macro"));
+	MW_TRACE((f, "record_macro"));
 
 	if (kbd_macro.size >= KB_MAX) {
 		llpr("Macro too long; definition terminated");
@@ -482,14 +488,14 @@ int get_char_from_input_queue()
 	}
 	if (macro_flag) record_macro(c);
 
-	TRACEME((f, "\tgcfiq: %d %c", c, c));
+	MW_TRACE((f, "\tgcfiq: %d %c", c, c));
 
 	return c;
 }
 
 void mainloop()
 {
-	TRACEME((f, "Now entering the main loop!"));
+	MW_TRACE((f, "Now entering the main loop!"));
 
 	old = get_point(w_list);
 	pr_scr_flag = TRUE;
@@ -505,7 +511,7 @@ void mainloop()
 /* Prints the string p on the bottom line of the screen. */
 void llpr(char *p) /* important */
 {
-	TRACEME((f, "this is llpr speaking (%s)", p));
+	MW_TRACE((f, "this is llpr speaking (%s)", p));
 
 	wmove(stdscr, size.ws_row - 1, 0);
 	waddnstr(stdscr, p, size.ws_col);
@@ -520,7 +526,7 @@ void free_window(window *w)
 {
 	window *pw;
   
-	TRACEME((f, "free_window"));
+	MW_TRACE((f, "free_window"));
 
 	/* unlink from window list */
 	for (pw = w_list; next_window(pw) != w && next_window(pw) != pw; pw = next_window(pw));
@@ -533,7 +539,7 @@ void free_window(window *w)
 	/* no windows in the list => w_list = NULL */
 	if (w_list == w) w_list = NULL;
 
-	cfree(w);
+	MwFree(w);
 }
 
 /*X
@@ -547,9 +553,9 @@ window *new_window(buffer *b, window *prev)
 {
 	window *w;
 
-	TRACEME((f, "new_window"));
+	MW_TRACE((f, "new_window"));
 
-	if((w = (window *)cmalloc(sizeof(window))) == NULL) return NULL;
+	if((w = (window *)MwMalloc(sizeof(window))) == NULL) return NULL;
 
 	set_window_buffer(w, b);
 	w->sht = w->bsht = 0;
@@ -565,7 +571,7 @@ window *new_window(buffer *b, window *prev)
 /* the goal is to not do this */
 void die(char *s)
 {
-	TRACEME((f, "Die: %s", s));
+	MW_TRACE((f, "Die: %s", s));
 	exit_windows();			/* Reset the terminal, */
 	fprintf(stderr, "%s\n", s);	/* tell'm what happened, */
 	exit(EXIT_FAILURE);		/* and split! */
@@ -574,12 +580,12 @@ void die(char *s)
 /* Internal */
 void resize_ncurses()
 {
-	TRACEME((f, "resize_ncurses"));
+	MW_TRACE((f, "resize_ncurses"));
 #ifdef HAVE_RESIZETERM
 	if (ioctl(fileno(stdout), TIOCGWINSZ, &size) != 0 &&
 	    resizeterm(size.ws_row, size.ws_col) != OK) {
 #endif
-		TRACEME((f, "resizing: Not so cool if this happens"));
+		MW_TRACE((f, "resizing: Not so cool if this happens"));
 		size.ws_row = LINES;
 		size.ws_col = COLS;
 #ifdef HAVE_RESIZETERM
@@ -602,7 +608,7 @@ void resize_ncurses()
 
 void new_ncurses()
 {
-	TRACEME((f,"new_ncurses"));
+	MW_TRACE((f,"new_ncurses"));
 
 	if ((stdscr = newwin(0, 0, 0, 0)) == NULL)
 		die("Error creating window");
@@ -624,7 +630,7 @@ void new_ncurses()
 /* Much nicer then attempting to spawn a shell :) */
 LISP suspend_function()
 {
-	TRACEME((f,"suspend_function"));
+	MW_TRACE((f,"suspend_function"));
 #ifdef SIGTSTP
 	delwin(stdscr);
 	raise(SIGTSTP);
@@ -639,7 +645,7 @@ LISP suspend_function()
 /* What to do when someone resizes the xterm (for example) */
 void sig_winch_handler()
 {
-	TRACEME((f,"sig_winch_handler"));
+	MW_TRACE((f,"sig_winch_handler"));
 	wclear(stdscr);
 	resize_ncurses();
 }
@@ -659,7 +665,7 @@ LISP get_geometry(void)
 {
 	LISP result;
 
-	TRACEME((f, "get_geometry"));
+	MW_TRACE((f, "get_geometry"));
 
 	/* Say the magic words... */
 	result = cons(flocons(0), NIL);		/* depth */
@@ -677,7 +683,7 @@ The window list w_list is set to a list with a single window with the
 buffer b. */
 void init_windows(buffer *b, int *argc, char **argv)
 {
-	TRACEME((f,"init_windows"));
+	MW_TRACE((f,"init_windows"));
 
 	initscr();    /* this curses function must be called first */
 
@@ -702,13 +708,13 @@ void init_windows(buffer *b, int *argc, char **argv)
 
 	init_calc_cmds();
 
-	encode_format(~0, &fmt0);
-	rowcol_fmt_index = encode_format(~0, &fmt1);
+	MwEncodeFormat(~0, &fmt0);
+	rowcol_fmt_index = MwEncodeFormat(~0, &fmt1);
 
 	kbd_macro.maxsize = KB_MAX;
-	kbd_macro.text = (char *)ccalloc(KB_MAX, sizeof(char));
+	kbd_macro.text = (char *)MwCalloc(KB_MAX, sizeof(char));
   
-	input_queue.buf = (char *)ccalloc(IQ_MAX, sizeof(char));
+	input_queue.buf = (char *)MwCalloc(IQ_MAX, sizeof(char));
 	input_queue.index = 0;
 	input_queue.size = 0;
 }
@@ -716,7 +722,7 @@ void init_windows(buffer *b, int *argc, char **argv)
 /* Cleans up after Calc before exit.  All buffers and windows are freed. */
 void exit_windows()
 {
-	TRACEME((f, "exit_windows"));
+	MW_TRACE((f, "exit_windows"));
 
 	/* free all buffers */
 	while (b_list != NULL) free_buffer(b_list);
@@ -764,9 +770,9 @@ void show_cur(window *w)
 	char *b;
 	int i;
 
-	b = (char *)cmalloc(size.ws_col); /* Is there a better way to do this? */
+	b = (char *)MwMalloc(size.ws_col); /* Is there a better way to do this? */
 
-	TRACEME((f,"\tshow_cur(): enter: point=(%d,%d) top=(%d,%d)",
+	MW_TRACE((f,"\tshow_cur(): enter: point=(%d,%d) top=(%d,%d)",
 	         get_point(w).row, get_point(w).col,
 	         get_top(w).row, get_top(w).col));
 
@@ -791,7 +797,7 @@ void show_cur(window *w)
 		pr_scr_flag = TRUE;
 	}
 
-	TRACEME((f,"\tshow_cur() point=(%d,%d) top=(%d,%d) pr_scr_flag=(%d)",
+	MW_TRACE((f,"\tshow_cur() point=(%d,%d) top=(%d,%d) pr_scr_flag=(%d)",
 	         get_point(w).row, get_point(w).col,
 	         get_top(w).row, get_top(w).col, pr_scr_flag));
 
@@ -837,7 +843,7 @@ void show_cur(window *w)
 /* This function is used */
 void activate_window(window *w)
 {
-	TRACEME((f,"activate_window"));
+	MW_TRACE((f,"activate_window"));
 	w_list = w;
 }
 
@@ -846,7 +852,7 @@ int select_from_list(char *text, char **choices, int nchoices)
 	int i;
 	int offset = 0;
 
-	TRACEME((f,"select_from_list(%s,%s...,%d)",text,*choices,nchoices));
+	MW_TRACE((f,"select_from_list(%s,%s...,%d)",text,*choices,nchoices));
 
 	pr_scr_flag = TRUE;
 
