@@ -1,6 +1,6 @@
 /*
    Siag Office
-   Copyright (C) 1997-1999  Ulric Eriksson <ulric@edu.stockholm.se>
+   Copyright (C) 1997-2001  Ulric Eriksson <ulric@siag.nu>
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -33,16 +33,10 @@
 #include <X11/Xaw/Form.h>
 #include <X11/Xaw/Command.h>
 #include <X11/Xaw/Dialog.h>
-#include <X11/Xaw/MenuButton.h>
-#include <X11/Xaw/SimpleMenu.h>
-#include <X11/Xaw/SmeBSB.h>
-#include <X11/Xaw/SmeLine.h>
+#include <Mowitz/Mowitz.h>
 
 #include "../siod/siod.h"
-#include "../common/cmalloc.h"
 #include "../common/common.h"
-#include "TextField.h"
-#include "Check.h"
 #include "xcommon.h"
 
 #define siod_interpreter 0
@@ -126,7 +120,7 @@ static LISP form_begin(void)
 	c_list = NULL;
 	form_shell = XtVaCreatePopupShell("form_shell",
 		transientShellWidgetClass, top,
-		XtNtitle, translate("Form"),
+		XtNtitle, _("Form"),
 		(char *)0);
 	form_dialog = XtVaCreateManagedWidget("form_dialog",
 		formWidgetClass, form_shell, (char *)0);
@@ -139,14 +133,14 @@ static LISP form_label(LISP text)
 	Widget w = lastw = XtVaCreateManagedWidget("form_label",
 		labelWidgetClass, form_dialog,
 		(char *)0);
-	label_set(w, label);
+	MwLabelSet(w, label);
 	horiz = place(w, vert, horiz, LEFT);
 	return NIL;
 }
 
 static control *new_control(int type, char *name)
 {
-	control *c = (control *)cmalloc(sizeof(control));
+	control *c = (control *)MwMalloc(sizeof(control));
 	if (!c_list) {
 		c_list = c;
 		c->next = c;
@@ -158,7 +152,7 @@ static control *new_control(int type, char *name)
 		c_list->prev = c;
 	}
 	c->type = type;
-	c->name = cstrdup(name);
+	c->name = MwStrdup(name);
 	return c;
 }
 
@@ -168,15 +162,15 @@ static LISP form_check(LISP n, LISP text)
 	char *label = get_c_string(text);
 	control *c = new_control(CHECK, name);
 	c->w = lastw = XtVaCreateManagedWidget("form_check",
-		checkWidgetClass, form_dialog,
+		mwCheckWidgetClass, form_dialog,
 		XtNstate, False,
 		XtNlabel, label,
-		XtNcheckStyle, SiagCheckWin,
+		XtNcheckStyle, MwCheckWin,
 		XtNwidth, 200,
 		XtNheight, 20,
 		XtNborderWidth, 0,
 		(char *)0);
-	label_set(c->w, label);
+	MwLabelSet(c->w, label);
 	horiz = place(c->w, vert, horiz, LEFT);
 	return NIL;
 }
@@ -186,7 +180,7 @@ static LISP form_text(LISP n)
 	char *name = get_c_string(n);
 	control *c = new_control(TEXT, name);
 	c->w = lastw = XtVaCreateManagedWidget(name,
-		textfieldWidgetClass, form_dialog,
+		mwTextfieldWidgetClass, form_dialog,
 		XtNdisplayCaret, False, (char *)0);
 
 	XtOverrideTranslations(lastw,
@@ -204,33 +198,60 @@ static LISP form_text(LISP n)
 
 static LISP form_menu(LISP n)
 {
-	char *name = get_c_string(n);
+	char *name = MwStrdup(get_c_string(n));
 	control *c = new_control(MENU, name);
-	c->w = lastw = XtVaCreateManagedWidget(name,
-		menuButtonWidgetClass, form_dialog,
+
+	c->w = lastw = XtVaCreateManagedWidget("form_menu",
+		mwMenuButtonWidgetClass, form_dialog,
+		XtNmenu_name, name,
+		XtNlabel, name,
+		XtNheight, 20,
+		(char *)0);
+	menu = XtVaCreatePopupShell(name,
+		mwMenuWidgetClass, form_dialog,
 		(char *)0);
-	label_set(c->w, name);
-	menu = XtVaCreatePopupShell("menu",
-		simpleMenuWidgetClass, c->w, (char *)0);
 
 	horiz = place(c->w, vert, horiz, RIGHT);
 	return NIL;
 }
 
+static control *find_menubutton_by_entry(Widget w)
+{
+	control *c = c_list;
+	char *name, *mnu;
+	Widget mw = XtParent(w);	/* menu widget */
+	name = XtName(mw);		/* menu name */
+	if (!c) return NULL;
+	do {
+		if (XtClass(c->w) == mwMenuButtonWidgetClass) {
+			mnu = NULL;
+			XtVaGetValues(c->w, XtNmenu_name, &mnu, (char *)0);
+			if (mnu && !strcmp(mnu, name)) return c;
+		}
+		c = c->next;
+	} while (c != c_list);
+	return NULL;
+}
+
 static void menu_select(Widget w, XtPointer client_data, XtPointer call_data)
 {
 	String p = (String)client_data;
-	label_set(XtParent(XtParent(w)), p);
+	control *c = find_menubutton_by_entry(w);
+	if (!c) {
+		MwErrorBox(form_dialog, _("No such menu button"));
+		return;
+	}
+	XtVaSetValues(c->w, XtNlabel, p, (char *)0);
 }
 
 static LISP form_menuentry(LISP n)
 {
-	char *name = get_c_string(n);
+	char *name = MwStrdup(get_c_string(n));
 	Widget entry = XtVaCreateManagedWidget(name,
-		smeBSBObjectClass, menu, (char *)0);
-	XtAddCallback(entry,
-		XtNcallback, menu_select, name);
-	label_set(XtParent(XtParent(entry)), name);
+		mwLabelMEObjectClass, menu,
+		XtNlabel, name,
+		(char *)0);
+	XtAddCallback(entry, XtNcallback, menu_select, name);
 	return NIL;
 }
 
@@ -346,7 +367,7 @@ static Widget add_button(Widget pw, char *name, char *label,
         Widget w = XtVaCreateManagedWidget(name,
                 commandWidgetClass, pw,
                 (char *)0);
-        label_set(w, label);
+        MwLabelSet(w, label);
         XtVaSetValues(w, XtNwidth, 80, (char *)0);
         if (cb) XtAddCallback(w, XtNcallback, cb, data);
         return w;
@@ -414,7 +435,7 @@ static LISP form_end(void)
 
 	XtRealizeWidget(form_shell);
 	XtUnrealizeWidget(form_shell);
-	center(top, form_shell);
+	MwCenter(form_shell);
 	XtPopup(form_shell, XtGrabNonexclusive);
 
 	XWarpPointer(XtDisplay(form_shell), None, XtWindow(form_shell),
@@ -438,10 +459,10 @@ static LISP form_end(void)
 		Boolean state;
 		switch (c->type) {
 		case TEXT:
-			value = TextFieldGetString(c->w);
+			value = MwTextFieldGetString(c->w);
 			break;
 		case MENU:
-			value = label_get(c->w);
+			value = MwLabelGet(c->w);
 			break;
 		case CHECK:
 			XtVaGetValues(c->w, XtNstate, &state, (char *)0);
