@@ -83,14 +83,8 @@ static char abouttext[] = "\n\n\n\
 #include "../common/bitmaps/xedplus.xpm"
 
 #include "../common/common.h"
-#include "../xcommon/icon.h"
-#include "../xcommon/Frame.h"
-#include "../xcommon/Rudegrid.h"
-#include "../xcommon/Tooltip.h"
-#include "../xcommon/Handle.h"
-#include "../xcommon/SiagMenuButton.h"
+#include <Mowitz/Mowitz.h>
 #include "../xcommon/xcommon.h"
-#include "../xcommon/DragAndDrop.h"
 
 /* Stop Bitmap */
 #define stop_width 31
@@ -109,22 +103,6 @@ static unsigned char stop_bits[] =
   0x40, 0xfe, 0x3f, 0x81, 0x80, 0xfc, 0x9f, 0x80, 0x00, 0x01, 0x40, 0x80,
 	0x00, 0xfe, 0x3f, 0x80};
 
-#define saved_width 16
-#define saved_height 16
-static unsigned char saved_bits[] =
-{
-  0x00, 0x00, 0x00, 0x00, 0x00, 0x20, 0x00, 0x10, 0x00, 0x10, 0x00, 0x08,
-  0x00, 0x08, 0x00, 0x04, 0x08, 0x02, 0x10, 0x02, 0x20, 0x01, 0x40, 0x01,
-	0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00};
-
-#define notsaved_width 16
-#define notsaved_height 16
-static unsigned char notsaved_bits[] =
-{
-  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
-  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
-	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00};
-
 #define MENUBAR (1)
 #define TOOLBAR (2)
 #define FORMATBAR (4)
@@ -136,12 +114,13 @@ String fallback_resources[] =
 #include "../xcommon/xcommon-ad.h"
 #include "../xcommon/dialogs-ad.h"
 #include "../xcommon/filesel-ad.h"
+#include "../xcommon/nws-ad.h"
 #include "app-defaults.h"
 	NULL
 };
 
 /* Global widgets */
-Widget menubar, menubox, toolbar, toolbox, tooltip;
+Widget menubar, menubox, toolbar, toolbox, tooltip, statusbox;
 Widget textwindow, messwidget, labelwindow, filenamewindow;
 Widget file_s;
 Widget line_popup, line_text, error_popup, error_label;
@@ -161,7 +140,6 @@ Display *CurDpy;
 XtTranslations inserttrans, overwritetrans;
 Widget modelabel, dirtylabel;
 static XtInputId pipe_id;
-Pixmap savedbitmap, notsavedbitmap;
 
 struct _app_resources app_resources;
 
@@ -346,7 +324,7 @@ Widget top;
 	/* Popup for Goto Line */
 	line_popup = XtCreatePopupShell("Goto line", transientShellWidgetClass, top, args, 0);
 	widget = XtCreateManagedWidget("line_box", boxWidgetClass, line_popup, NULL, 0);
-	XtSetArg(args[0], XtNlabel, translate("Line number?"));
+	XtSetArg(args[0], XtNlabel, _("Line number?"));
 	XtSetArg(args[1], XtNborderWidth, 0);
 	XtCreateManagedWidget("line_label", labelWidgetClass, widget, args, 2);
 	XtSetArg(args[0], XtNeditType, XawtextEdit);
@@ -363,21 +341,21 @@ Widget top;
 	XtSetArg(args[0], XtNbitmap, bitmap);
 	XtSetArg(args[1], XtNborderWidth, 0);
 	XtCreateManagedWidget("stop_icon", labelWidgetClass, widget, args, 2);
-	XtSetArg(args[0], XtNlabel, translate("Error Message!"));
+	XtSetArg(args[0], XtNlabel, _("Error Message!"));
 	XtSetArg(args[1], XtNborderWidth, 0);
 	error_label = XtCreateManagedWidget("error_label", labelWidgetClass, widget, args, 2);
-	XtSetArg(args[0], XtNlabel, translate("OK"));
+	XtSetArg(args[0], XtNlabel, _("OK"));
 	widget = XtCreateManagedWidget("error_ok", commandWidgetClass, widget, args, 1);
 	XtAddCallback(widget, XtNcallback, error_ready, 0);
 
 	/* Popup for warning messages */
-	warn_popup = XtCreatePopupShell("Warning", transientShellWidgetClass, top, args, 0);
+	warn_popup = XtCreatePopupShell(_("Warning"), transientShellWidgetClass, top, args, 0);
 	XtSetArg(args[0], XtNorientation, XtorientVertical);
 	warn_box = widget = XtCreateManagedWidget("warn_box", boxWidgetClass, warn_popup, args, 1);
 	XtSetArg(args[0], XtNbitmap, bitmap);
 	XtSetArg(args[1], XtNborderWidth, 0);
 	XtCreateManagedWidget("stop_icon2", labelWidgetClass, widget, args, 2);
-	XtSetArg(args[0], XtNlabel, translate("Warning!"));
+	XtSetArg(args[0], XtNlabel, _("Warning!"));
 	XtSetArg(args[1], XtNborderWidth, 0);
 	warn_label = XtCreateManagedWidget("warn_label", labelWidgetClass, widget, args, 2);
 	XtSetArg(args[0], XtNborderWidth, 0);
@@ -385,10 +363,10 @@ Widget top;
 	XtSetArg(args[2], XtNshowGrip, False);
 	XtSetArg(args[3], XtNskipAdjust, True);
 	widget = XtCreateManagedWidget("warn_box2", boxWidgetClass, warn_box, args, 4);
-	XtSetArg(args[0], XtNlabel, translate("Cancel"));
+	XtSetArg(args[0], XtNlabel, _("Cancel"));
 	widget2 = XtCreateManagedWidget("warn_abort", commandWidgetClass, widget, args, 1);
 	XtAddCallback(widget2, XtNcallback, warn_ready, XED_ABORT);
-	XtSetArg(args[0], XtNlabel, translate("OK"));
+	XtSetArg(args[0], XtNlabel, _("OK"));
 	widget2 = XtCreateManagedWidget("warn_continue", commandWidgetClass, widget, args, 1);
 	XtAddCallback(widget2, XtNcallback, warn_ready, (caddr_t) CONTINUE);
 
@@ -408,24 +386,24 @@ Widget top;
 	XtSetArg(args[0], XtNborderWidth, 0);
 	XtSetArg(args[1], XtNorientation, XtorientHorizontal);
 	box2 = XtCreateManagedWidget("option_box2", boxWidgetClass, box, args, 2);
-	XtSetArg(args[0], XtNlabel, translate("Wrap mode:"));
+	XtSetArg(args[0], XtNlabel, _("Wrap mode:"));
 	XtSetArg(args[1], XtNborderWidth, 0);
 	XtCreateManagedWidget("warp_label", labelWidgetClass, box2, args, 2);
-	XtSetArg(args[0], XtNlabel, translate("Never"));
+	XtSetArg(args[0], XtNlabel, _("Never"));
 	XtSetArg(args[1], XtNradioData, (caddr_t) wrapmode[0]);
 	wrap_group = widget = XtCreateManagedWidget("wrap_never", toggleWidgetClass, box2, args, 2);
-	XtSetArg(args[0], XtNlabel, translate("Line"));
+	XtSetArg(args[0], XtNlabel, _("Line"));
 	XtSetArg(args[1], XtNradioGroup, widget);
 	XtSetArg(args[2], XtNradioData, (caddr_t) wrapmode[1]);
 	XtCreateManagedWidget("wrap_line", toggleWidgetClass, box2, args, 3);
-	XtSetArg(args[0], XtNlabel, translate("Word"));
+	XtSetArg(args[0], XtNlabel, _("Word"));
 	XtSetArg(args[1], XtNradioGroup, widget);
 	XtSetArg(args[2], XtNradioData, (caddr_t) wrapmode[2]);
 	XtCreateManagedWidget("wrap_word", toggleWidgetClass, box2, args, 3);
 	XtSetArg(args[0], XtNborderWidth, 0);
 	XtSetArg(args[1], XtNorientation, XtorientHorizontal);
 	box2 = XtCreateManagedWidget("option_box4", boxWidgetClass, box, args, 2);
-	XtSetArg(args[0], XtNlabel, translate("Tab size:"));
+	XtSetArg(args[0], XtNlabel, _("Tab size:"));
 	XtSetArg(args[1], XtNborderWidth, 0);
 	XtCreateManagedWidget("tab_label", labelWidgetClass, box2, args, 2);
 	XtSetArg(args[0], XtNeditType, XawtextEdit);
@@ -438,13 +416,13 @@ Widget top;
 	XtSetArg(args[0], XtNborderWidth, 0);
 	XtSetArg(args[1], XtNorientation, XtorientHorizontal);
 	box2 = XtCreateManagedWidget("option_box4", boxWidgetClass, box, args, 2);
-	XtSetArg(args[0], XtNlabel, translate("Autoindent:"));
+	XtSetArg(args[0], XtNlabel, _("Autoindent:"));
 	XtSetArg(args[1], XtNborderWidth, 0);
 	XtCreateManagedWidget("indent_label", labelWidgetClass, box2, args, 2);
-	XtSetArg(args[0], XtNlabel, translate("Yes"));
+	XtSetArg(args[0], XtNlabel, _("Yes"));
 	XtSetArg(args[1], XtNradioData, (caddr_t) indentmode[0]);
 	indent_group = XtCreateManagedWidget("indent_yes", toggleWidgetClass, box2, args, 2);
-	XtSetArg(args[0], XtNlabel, translate("No"));
+	XtSetArg(args[0], XtNlabel, _("No"));
 	XtSetArg(args[1], XtNradioGroup, indent_group);
 	XtSetArg(args[2], XtNradioData, (caddr_t) indentmode[1]);
 	widget = XtCreateManagedWidget("indent_no", toggleWidgetClass, box2, args, 3);
@@ -457,13 +435,13 @@ Widget top;
 	XtSetArg(args[0], XtNborderWidth, 0);
 	XtSetArg(args[1], XtNorientation, XtorientHorizontal);
 	box2 = XtCreateManagedWidget("option_box6", boxWidgetClass, box, args, 2);
-	XtSetArg(args[0], XtNlabel, translate("Autofill:"));
+	XtSetArg(args[0], XtNlabel, _("Autofill:"));
 	XtSetArg(args[1], XtNborderWidth, 0);
 	XtCreateManagedWidget("autofill_label", labelWidgetClass, box2, args, 2);
-	XtSetArg(args[0], XtNlabel, translate("Yes"));
+	XtSetArg(args[0], XtNlabel, _("Yes"));
 	XtSetArg(args[1], XtNradioData, (caddr_t) autofillmode[0]);
 	autofill_group = XtCreateManagedWidget("autofill_yes", toggleWidgetClass, box2, args, 2);
-	XtSetArg(args[0], XtNlabel, translate("No"));
+	XtSetArg(args[0], XtNlabel, _("No"));
 	XtSetArg(args[1], XtNradioGroup, autofill_group);
 	XtSetArg(args[2], XtNradioData, (caddr_t) autofillmode[1]);
 	widget = XtCreateManagedWidget("autofill_no", toggleWidgetClass, box2, args, 3);
@@ -478,11 +456,11 @@ Widget top;
 	XtSetArg(args[0], XtNborderWidth, 0);
 	XtSetArg(args[1], XtNorientation, XtorientHorizontal);
 	box2 = XtCreateManagedWidget("option_box5", boxWidgetClass, box, args, 2);
-	XtSetArg(args[0], XtNlabel, translate("OK"));
+	XtSetArg(args[0], XtNlabel, _("OK"));
 	widget2 = XtCreateManagedWidget("option_ok",
 				      commandWidgetClass, box2, args, 1);
 	XtAddCallback(widget2, XtNcallback, option_ready, OK);
-	XtSetArg(args[0], XtNlabel, translate("Cancel"));
+	XtSetArg(args[0], XtNlabel, _("Cancel"));
 	widget2 = XtCreateManagedWidget("option_cancel",
 				      commandWidgetClass, box2, args, 1);
 	XtAddCallback(widget2, XtNcallback, option_ready, (caddr_t) CANCEL);
@@ -490,7 +468,7 @@ Widget top;
 	/* Popup for sed commands */
 	sed_popup = XtCreatePopupShell("sed", wmShellWidgetClass, top, args, 0);
 	box = XtCreateManagedWidget("sed_paned", panedWidgetClass, sed_popup, args, 0);
-	XtSetArg(args[0], XtNlabel, translate("Perform a stream editor command (sed)"));
+	XtSetArg(args[0], XtNlabel, _("Perform a stream editor command (sed)"));
 	XtSetArg(args[1], XtNborderWidth, 0);
 	XtSetArg(args[2], XtNshowGrip, False);
 	XtCreateManagedWidget("sed_label", labelWidgetClass, box, args, 3);
@@ -502,7 +480,7 @@ Widget top;
 	box2 = XtCreateManagedWidget("option_box4", panedWidgetClass, box, args, 4);
 
 	XtSetArg(args[0], XtNborderWidth, 0);
-	XtSetArg(args[1], XtNlabel, translate("Command:"));
+	XtSetArg(args[1], XtNlabel, _("Command:"));
 	XtSetArg(args[2], XtNshowGrip, False);
 	XtCreateManagedWidget("sed_label2", labelWidgetClass, box2, args, 3);
 
@@ -516,26 +494,26 @@ Widget top;
 	XtSetArg(args[3], XtNskipAdjust, True);
 	box2 = XtCreateManagedWidget("sed_box3", boxWidgetClass, box, args, 4);
 
-	XtSetArg(args[0], XtNlabel, translate("Do it"));
+	XtSetArg(args[0], XtNlabel, _("Do it"));
 	widget = XtCreateManagedWidget("sed_doit", commandWidgetClass, box2, args, 1);
 	XtAddCallback(widget, XtNcallback, sed_do, NULL);
 
-	XtSetArg(args[0], XtNlabel, translate("Do it Selection"));
+	XtSetArg(args[0], XtNlabel, _("Do it Selection"));
 	widget = XtCreateManagedWidget("sed_doit_sel", commandWidgetClass, box2, args, 1);
 	XtAddCallback(widget, XtNcallback, sed_do_sel, NULL);
 
-	XtSetArg(args[0], XtNlabel, translate("Undo it"));
+	XtSetArg(args[0], XtNlabel, _("Undo it"));
 	widget = XtCreateManagedWidget("sed_undoit", commandWidgetClass, box2, args, 1);
 	XtAddCallback(widget, XtNcallback, sed_undo, NULL);
 
-	XtSetArg(args[0], XtNlabel, translate("Close"));
+	XtSetArg(args[0], XtNlabel, _("Close"));
 	widget = XtCreateManagedWidget("sed_close", commandWidgetClass, box2, args, 1);
 	XtAddCallback(widget, XtNcallback, sed_close, NULL);
 
 	/* Popup for command */
 	command_popup = XtCreatePopupShell("command", wmShellWidgetClass, top, args, 0);
 	box = XtCreateManagedWidget("command_paned", panedWidgetClass, command_popup, args, 0);
-	XtSetArg(args[0], XtNlabel, translate("Perform a User command"));
+	XtSetArg(args[0], XtNlabel, _("Perform a User command"));
 	XtSetArg(args[1], XtNborderWidth, 0);
 	XtSetArg(args[2], XtNshowGrip, False);
 	XtCreateManagedWidget("command_label", labelWidgetClass, box, args, 3);
@@ -547,7 +525,7 @@ Widget top;
 	box2 = XtCreateManagedWidget("option_box4", panedWidgetClass, box, args, 4);
 
 	XtSetArg(args[0], XtNborderWidth, 0);
-	XtSetArg(args[1], XtNlabel, translate("Command:"));
+	XtSetArg(args[1], XtNlabel, _("Command:"));
 	XtSetArg(args[2], XtNshowGrip, False);
 	XtCreateManagedWidget("command_label2", labelWidgetClass, box2, args, 3);
 
@@ -561,18 +539,18 @@ Widget top;
 	XtSetArg(args[3], XtNskipAdjust, True);
 	box2 = XtCreateManagedWidget("command_box3", boxWidgetClass, box, args, 4);
 
-	XtSetArg(args[0], XtNlabel, translate("Do it"));
+	XtSetArg(args[0], XtNlabel, _("Do it"));
 	widget = XtCreateManagedWidget("command_doit", commandWidgetClass, box2, args, 1);
 	XtAddCallback(widget, XtNcallback, command_do, NULL);
 
-	XtSetArg(args[0], XtNlabel, translate("Close"));
+	XtSetArg(args[0], XtNlabel, _("Close"));
 	widget = XtCreateManagedWidget("command_close", commandWidgetClass, box2, args, 1);
 	XtAddCallback(widget, XtNcallback, command_close, NULL);
 
 	/* Popup for command */
 	pipe_popup = XtCreatePopupShell("pipe", wmShellWidgetClass, top, args, 0);
 	box = XtCreateManagedWidget("pipe_paned", panedWidgetClass, pipe_popup, args, 0);
-	XtSetArg(args[0], XtNlabel, translate("Perform a User pipe"));
+	XtSetArg(args[0], XtNlabel, _("Perform a User pipe"));
 	XtSetArg(args[1], XtNborderWidth, 0);
 	XtSetArg(args[2], XtNshowGrip, False);
 	XtCreateManagedWidget("pipe_label", labelWidgetClass, box, args, 3);
@@ -584,7 +562,7 @@ Widget top;
 	box2 = XtCreateManagedWidget("option_box4", panedWidgetClass, box, args, 4);
 
 	XtSetArg(args[0], XtNborderWidth, 0);
-	XtSetArg(args[1], XtNlabel, translate("Command:"));
+	XtSetArg(args[1], XtNlabel, _("Command:"));
 	XtSetArg(args[2], XtNshowGrip, False);
 	XtCreateManagedWidget("pipe_label2", labelWidgetClass, box2, args, 3);
 
@@ -598,11 +576,11 @@ Widget top;
 	XtSetArg(args[3], XtNskipAdjust, True);
 	box2 = XtCreateManagedWidget("pipe_box3", boxWidgetClass, box, args, 4);
 
-	XtSetArg(args[0], XtNlabel, translate("Do it"));
+	XtSetArg(args[0], XtNlabel, _("Do it"));
 	widget = XtCreateManagedWidget("pipe_doit", commandWidgetClass, box2, args, 1);
 	XtAddCallback(widget, XtNcallback, pipe_do, NULL);
 
-	XtSetArg(args[0], XtNlabel, translate("Close"));
+	XtSetArg(args[0], XtNlabel, _("Close"));
 	widget = XtCreateManagedWidget("pipe_close", commandWidgetClass, box2, args, 1);
 	XtAddCallback(widget, XtNcallback, pipe_close, NULL);
 
@@ -626,7 +604,7 @@ Widget top;
 		XtCreateManagedWidget("about_text", asciiTextWidgetClass, box, args, 5);
 	}
 
-	XtSetArg(args[0], XtNlabel, translate("Close"));
+	XtSetArg(args[0], XtNlabel, _("Close"));
 	XtSetArg(args[1], XtNshowGrip, False);
 	XtSetArg(args[2], XtNskipAdjust, True);
 	widget = XtCreateManagedWidget("about_close", commandWidgetClass, box, args, 3);
@@ -643,19 +621,19 @@ Widget top;
 	XtSetArg(args[3], XtNskipAdjust, True);
 	box2 = XtCreateManagedWidget("search_box1", boxWidgetClass, box, args, 4);
 
-	XtSetArg(args[0], XtNlabel, translate("Start at:"));
+	XtSetArg(args[0], XtNlabel, _("Start at:"));
 	XtSetArg(args[1], XtNborderWidth, 0);
 	XtCreateManagedWidget("start_at", labelWidgetClass, box2, args, 2);
 
-	XtSetArg(args[0], XtNlabel, translate("Cursor position"));
+	XtSetArg(args[0], XtNlabel, _("Cursor position"));
 	XtSetArg(args[1], XtNstate, True);
 	start_group = widget = XtCreateManagedWidget("Cursor position", toggleWidgetClass, box2, args, 2);
 
-	XtSetArg(args[0], XtNlabel, translate("Textbeginning"));
+	XtSetArg(args[0], XtNlabel, _("Textbeginning"));
 	XtSetArg(args[1], XtNradioGroup, widget);
 	XtCreateManagedWidget("Textbeginning", toggleWidgetClass, box2, args, 2);
 
-	XtSetArg(args[0], XtNlabel, translate("Textending"));
+	XtSetArg(args[0], XtNlabel, _("Textending"));
 	XtSetArg(args[1], XtNradioGroup, widget);
 	XtCreateManagedWidget("Textending", toggleWidgetClass, box2, args, 2);
 
@@ -665,15 +643,15 @@ Widget top;
 	XtSetArg(args[3], XtNskipAdjust, True);
 	box2 = XtCreateManagedWidget("search_box2", boxWidgetClass, box, args, 4);
 
-	XtSetArg(args[0], XtNlabel, translate("Direction:"));
+	XtSetArg(args[0], XtNlabel, _("Direction:"));
 	XtSetArg(args[1], XtNborderWidth, 0);
 	XtCreateManagedWidget("direction", labelWidgetClass, box2, args, 2);
 
-	XtSetArg(args[0], XtNlabel, translate("Forward"));
+	XtSetArg(args[0], XtNlabel, _("Forward"));
 	XtSetArg(args[1], XtNstate, True);
 	direction_group = widget = XtCreateManagedWidget("Forward", toggleWidgetClass, box2, args, 2);
 
-	XtSetArg(args[0], XtNlabel, translate("Backward"));
+	XtSetArg(args[0], XtNlabel, _("Backward"));
 	XtSetArg(args[1], XtNradioGroup, widget);
 	XtCreateManagedWidget("Backward", toggleWidgetClass, box2, args, 2);
 
@@ -685,7 +663,7 @@ Widget top;
 	box2 = XtCreateManagedWidget("search_box3", panedWidgetClass, box, args, 5);
 
 	XtSetArg(args[0], XtNborderWidth, 1);
-	XtSetArg(args[1], XtNlabel, translate("Search for:"));
+	XtSetArg(args[1], XtNlabel, _("Search for:"));
 	XtSetArg(args[2], XtNshowGrip, False);
 	XtSetArg(args[3], XtNinternalWidth, 8);
 	XtSetArg(args[4], XtNinternalHeight, 8);
@@ -705,7 +683,7 @@ Widget top;
 	box2 = XtCreateManagedWidget("search_box4", panedWidgetClass, box, args, 5);
 
 	XtSetArg(args[0], XtNborderWidth, 0);
-	XtSetArg(args[1], XtNlabel, translate("Replace with:"));
+	XtSetArg(args[1], XtNlabel, _("Replace with:"));
 	XtSetArg(args[2], XtNshowGrip, False);
 	XtSetArg(args[3], XtNinternalWidth, 8);
 	XtSetArg(args[4], XtNinternalHeight, 8);
@@ -724,30 +702,30 @@ Widget top;
 	XtSetArg(args[3], XtNskipAdjust, True);
 	box2 = XtCreateManagedWidget("search_box5", boxWidgetClass, box, args, 4);
 
-	XtSetArg(args[0], XtNlabel, translate("Search"));
+	XtSetArg(args[0], XtNlabel, _("Search"));
 	widget = XtCreateManagedWidget("search", commandWidgetClass, box2, args, 1);
 	XtAddCallback(widget, XtNcallback, search, NULL);
 
-	XtSetArg(args[0], XtNlabel, translate("Replace"));
+	XtSetArg(args[0], XtNlabel, _("Replace"));
 	widget = XtCreateManagedWidget("replace", commandWidgetClass, box2, args, 1);
 	XtAddCallback(widget, XtNcallback, replace, REPLACE);
 
-	XtSetArg(args[0], XtNlabel, translate("Replace veto"));
+	XtSetArg(args[0], XtNlabel, _("Replace veto"));
 	widget = XtCreateManagedWidget("replace_veto", commandWidgetClass, box2, args, 1);
 	XtAddCallback(widget, XtNcallback, replace, (caddr_t) REPLACE_VETO);
 
-	XtSetArg(args[0], XtNlabel, translate("Replace all"));
+	XtSetArg(args[0], XtNlabel, _("Replace all"));
 	widget = XtCreateManagedWidget("replace_all", commandWidgetClass, box2, args, 1);
 	XtAddCallback(widget, XtNcallback, replace, (caddr_t) REPLACE_ALL);
 
-	XtSetArg(args[0], XtNlabel, translate("Cancel"));
+	XtSetArg(args[0], XtNlabel, _("Cancel"));
 	widget = XtCreateManagedWidget("dirrection", commandWidgetClass, box2, args, 1);
 	XtAddCallback(widget, XtNcallback, search_ready, NULL);
 
 	/* Popup for Replace veto */
 	veto_popup = XtCreatePopupShell("Veto", transientShellWidgetClass, top, args, 0);
 	box = XtCreateManagedWidget("veto_box", boxWidgetClass, veto_popup, NULL, 0);
-	XtSetArg(args[0], XtNlabel, translate("Replace?"));
+	XtSetArg(args[0], XtNlabel, _("Replace?"));
 	XtSetArg(args[1], XtNborderWidth, 0);
 	XtCreateManagedWidget("veto_label", labelWidgetClass, box, args, 2);
 
@@ -755,15 +733,15 @@ Widget top;
 	XtSetArg(args[1], XtNorientation, XtorientHorizontal);
 	box2 = XtCreateManagedWidget("veto_box2", boxWidgetClass, box, args, 2);
 
-	XtSetArg(args[0], XtNlabel, translate("Yes"));
+	XtSetArg(args[0], XtNlabel, _("Yes"));
 	widget = XtCreateManagedWidget("veto_yes", commandWidgetClass, box2, args, 1);
 	XtAddCallback(widget, XtNcallback, veto_ready, (caddr_t) YES);
 
-	XtSetArg(args[0], XtNlabel, translate("No"));
+	XtSetArg(args[0], XtNlabel, _("No"));
 	widget = XtCreateManagedWidget("veto_no", commandWidgetClass, box2, args, 1);
 	XtAddCallback(widget, XtNcallback, veto_ready, (caddr_t) NO);
 
-	XtSetArg(args[0], XtNlabel, translate("Cancel"));
+	XtSetArg(args[0], XtNlabel, _("Cancel"));
 	widget = XtCreateManagedWidget("veto_cancel", commandWidgetClass, box2, args, 1);
 	XtAddCallback(widget, XtNcallback, veto_ready, (caddr_t) CANCEL);
 }
@@ -781,14 +759,24 @@ static Widget make_command(void (*cmd) (), Widget pw, char *pm, char *tt)
 				    commandWidgetClass, pw,
 				    XtNforeground, color,
 				    (char *) NULL);
-	pm_return = load_pixmap(pw, pm);
+	pm_return = load_pixmap(XtDisplay(pw), color, pm);
 	XtVaSetValues(w, XtNbitmap, pm_return, (char *) 0);
 
 	XtAddCallback(w, XtNcallback, cmd, (XtPointer) NULL);
-	TooltipAdd(tooltip, w, translate(tt));
+	MwTooltipAdd(tooltip, w, _(tt));
 	return w;
 }
 
+static void make_vsep(Widget pw)
+{
+	unsigned long bg;
+	XtVaGetValues(pw, XtNbackground, &bg, (char *)0);
+	XtVaCreateManagedWidget("vsep",
+		labelWidgetClass, pw,
+		XtNborderColor, bg,
+		(char *)0);
+}
+
 /* There is plenty to do here */
 static void create_toolbar(Widget pw)
 {
@@ -800,19 +788,24 @@ static void create_toolbar(Widget pw)
 		     "Save the file");
 	make_command(DoFilePrint, pw, "printer.xpm",
 		     "Print the file");
+	make_vsep(pw);
 	make_command(DoEditCut, pw, "cut.xpm", "Cut");
 	make_command(DoEditPaste, pw, "paste.xpm", "Paste");
+	modelabel = make_command(xedtoggleoverwrite, pw, "insert.xpm",
+			"Toggle overwrite/insert");
 	make_command(DoSpezialHelp, pw, "info.xpm",
-		     "Display the online documentation");
+			"Display the online documentation");
 }
 
 static Widget add_menu_entry(Widget pw, char *name, char *label,
 	     void (*cb) (Widget, XtPointer, XtPointer), XtPointer * data)
 {
 	Widget w;
-	w = XtCreateManagedWidget(name, smeBSBObjectClass, pw, NULL, 0);
+	w = XtVaCreateManagedWidget(name,
+		mwLabelMEObjectClass, pw,
+		XtNlabel, _(label),
+		(char *)0);
 	XtAddCallback(w, XtNcallback, cb, data);
-	label_set(w, label);
 	return w;
 }
 
@@ -827,38 +820,22 @@ static void remake_ylayout(void)
 		(char *)0);
 }
 
-static void attach_bar(Widget w)
+static void attach_bar(Widget w, XtPointer client_data, XtPointer call_data)
 {
-	if (w == menubar) bars |= MENUBAR;
-	if (w == toolbar) bars |= TOOLBAR;
+	Widget vw = (Widget)call_data;
+	if (vw == menubar) bars |= MENUBAR;
+	if (vw == toolbar) bars |= TOOLBAR;
 	remake_ylayout();
 }
 
-static void detach_bar(Widget w)
+static void detach_bar(Widget w, XtPointer client_data, XtPointer call_data)
 {
-	if (w == menubar) bars &= ~MENUBAR;
-	if (w == toolbar) bars &= ~TOOLBAR;
+	Widget vw = (Widget)call_data;
+	if (vw == menubar) bars &= ~MENUBAR;
+	if (vw == toolbar) bars &= ~TOOLBAR;
 	remake_ylayout();
 }
 
-static Widget make_handle(Widget pw, Widget victim)
-{
-	Pixmap pm;
-	Pixel color;
-	XtVaGetValues(pw,
-		      XtNbackground, &color,
-		      (char *)0);
-	pm = load_pixmap(pw, "handlebg.xpm");
-	return XtVaCreateManagedWidget("handle",
-		handleWidgetClass, pw,
-		XtNforeground, color,
-		XtNbackgroundPixmap, pm,
-		XtNshadowWidth, 1,
-		XtNhandleDetach, detach_bar,
-		XtNhandleAttach, attach_bar,
-		XtNhandleVictim, victim,
-		(char *)0);
-}
 
 /********************************************************************************
  *    Creating menus, statusline and textwindow				        *
@@ -875,213 +852,246 @@ char *filename;
 	XFontStruct *font;
 
 	menubar = XtVaCreateManagedWidget("menubar",
-					  frameWidgetClass, parent,
-					  (char *) 0);
+		mwRudegridWidgetClass, parent,
+		XtNborderWidth, 0,
+		XtNxLayout, "9 100%",
+		(char *)0);
+	MwMakeHandle(menubar, menubar, detach_bar, attach_bar);
 	menubox = XtVaCreateManagedWidget("menubox",
-					  boxWidgetClass, menubar,
+					  mwMenuBarWidgetClass, menubar,
+					  XtNgridx, 1,
 					  (char *) 0);
 	bars |= MENUBAR;
-	make_handle(menubox, menubar);
 	toolbar = XtVaCreateManagedWidget("toolbar",
-					  frameWidgetClass, parent,
-					  (char *) 0);
+		  mwRudegridWidgetClass, parent,
+		  XtNborderWidth, 0,
+		  XtNxLayout, "9 100%",
+		  (char *)0);
+	MwMakeHandle(toolbar, toolbar, detach_bar, attach_bar);
+	toolbox = XtVaCreateManagedWidget("frame2",
+		mwFrameWidgetClass, toolbar,
+		XtNgridx, 1,
+		XtNshadowWidth, 1,
+		(char *)0);
 	toolbox = XtVaCreateManagedWidget("toolbox",
-					  boxWidgetClass, toolbar,
+					  boxWidgetClass, toolbox,
 					  (char *) 0);
 	bars |= TOOLBAR;
-	make_handle(toolbox, toolbar);
-	{
 
-		/* File - Menue */
-		XtSetArg(arglist[0], XtNlabel, translate("File"));
-		XtSetArg(arglist[1], XtNmenuName, "filemenu");
-		widget = XtCreateManagedWidget("file_menu_button",
-			     siagMenuButtonWidgetClass, menubox, arglist, 2);
+	/* File - Menue */
+	XtSetArg(arglist[0], XtNlabel, _("File"));
+	XtSetArg(arglist[1], XtNmenu_name, "filemenu");
+	widget = XtCreateManagedWidget("file_menu_button",
+		     mwMBButtonObjectClass, menubox, arglist, 2);
 
-		menu = XtCreatePopupShell("filemenu", simpleMenuWidgetClass, parent, NULL, 0);
+	menu = XtCreatePopupShell("filemenu",
+		mwMenuWidgetClass, menubox, NULL, 0);
 
-		add_menu_entry(menu, "load", "Open", DoFileLoad, NULL);
-		add_menu_entry(menu, "insert", "Insert", DoFileInsert, NULL);
+	add_menu_entry(menu, "load", "Open", DoFileLoad, NULL);
+	add_menu_entry(menu, "insert", "Insert", DoFileInsert, NULL);
 
-		XtCreateManagedWidget("line", smeLineObjectClass, menu, NULL, 0);
+	XtVaCreateManagedWidget("line",
+		mwLineMEObjectClass, menu,
+		(char *)0);
 
-		add_menu_entry(menu, "save", "Save", DoFileSave, NULL);
-		add_menu_entry(menu, "saveas", "Save As", DoFileSaveAs, NULL);
-		add_menu_entry(menu, "savesel", "Save Selection",
-			       DoFileSaveSelection, NULL);
+	add_menu_entry(menu, "save", "Save", DoFileSave, NULL);
+	add_menu_entry(menu, "saveas", "Save As", DoFileSaveAs, NULL);
+	add_menu_entry(menu, "savesel", "Save Selection",
+		       DoFileSaveSelection, NULL);
 
-		XtCreateManagedWidget("line", smeLineObjectClass, menu, NULL, 0);
+	XtVaCreateManagedWidget("line",
+		mwLineMEObjectClass, menu,
+		(char *)0);
 
-		add_menu_entry(menu, "print", "Print", DoFilePrint, NULL);
-		add_menu_entry(menu, "printsel", "Print Selection",
-			       DoFilePrintSelection, NULL);
+	add_menu_entry(menu, "print", "Print", DoFilePrint, NULL);
+	add_menu_entry(menu, "printsel", "Print Selection",
+		       DoFilePrintSelection, NULL);
 
-		XtCreateManagedWidget("line", smeLineObjectClass, menu, NULL, 0);
+	XtVaCreateManagedWidget("line",
+		mwLineMEObjectClass, menu,
+		(char *)0);
 
-		add_menu_entry(menu, "quit", "Exit", DoFileQuit, NULL);
+	add_menu_entry(menu, "quit", "Exit", DoFileQuit, NULL);
 
 
-		/* Edit Menue */
-		XtSetArg(arglist[0], XtNlabel, translate("Edit"));
-		XtSetArg(arglist[1], XtNmenuName, "editmenu");
-		XtCreateManagedWidget("edit_menu_button",
-			     siagMenuButtonWidgetClass, menubox, arglist, 2);
+	/* Edit Menue */
+	XtSetArg(arglist[0], XtNlabel, _("Edit"));
+	XtSetArg(arglist[1], XtNmenu_name, "editmenu");
+	XtCreateManagedWidget("edit_menu_button",
+		     mwMBButtonObjectClass, menubox, arglist, 2);
 
-		menu = XtCreatePopupShell("editmenu", simpleMenuWidgetClass, parent, NULL, 0);
+	menu = XtCreatePopupShell("editmenu",
+		mwMenuWidgetClass, menubox, NULL, 0);
 
-		add_menu_entry(menu, "cut", "Cut", DoEditCut, NULL);
-		add_menu_entry(menu, "paste", "Paste", DoEditCut, NULL);
-		add_menu_entry(menu, "right", "Shift Selection Right",
-			       DoEditShiftSelRight, NULL);
-		add_menu_entry(menu, "left", "Shift Selection Left",
-			       DoEditShiftSelLeft, NULL);
+	add_menu_entry(menu, "cut", "Cut", DoEditCut, NULL);
+	add_menu_entry(menu, "paste", "Paste", DoEditCut, NULL);
+	add_menu_entry(menu, "right", "Shift Selection Right",
+		       DoEditShiftSelRight, NULL);
+	add_menu_entry(menu, "left", "Shift Selection Left",
+		       DoEditShiftSelLeft, NULL);
 
-		/* Jump - Menue */
-		XtSetArg(arglist[0], XtNlabel, translate("Jump"));
-		XtSetArg(arglist[1], XtNmenuName, "jumpmenu");
-		XtCreateManagedWidget("jump_menu_button",
-			     siagMenuButtonWidgetClass, menubox, arglist, 2);
+	/* Jump - Menue */
+	XtSetArg(arglist[0], XtNlabel, _("Jump"));
+	XtSetArg(arglist[1], XtNmenu_name, "jumpmenu");
+	XtCreateManagedWidget("jump_menu_button",
+		     mwMBButtonObjectClass, menubox, arglist, 2);
 
-		menu = XtCreatePopupShell("jumpmenu", simpleMenuWidgetClass, parent, NULL, 0);
+	menu = XtCreatePopupShell("jumpmenu",
+		mwMenuWidgetClass, menubox, NULL, 0);
 
-		add_menu_entry(menu, "line", "Line", DoJumpLine, NULL);
-		add_menu_entry(menu, "begin", "Begin", DoJumpLine, NULL);
-		add_menu_entry(menu, "end", "End", DoJumpEnd, NULL);
-		add_menu_entry(menu, "selstart", "Selection Start",
-			       DoJumpSelStart, NULL);
-		add_menu_entry(menu, "selend", "Selection End",
-			       DoJumpSelEnd, NULL);
+	add_menu_entry(menu, "line", "Line", DoJumpLine, NULL);
+	add_menu_entry(menu, "begin", "Begin", DoJumpBegin, NULL);
+	add_menu_entry(menu, "end", "End", DoJumpEnd, NULL);
+	add_menu_entry(menu, "selstart", "Selection Start",
+		       DoJumpSelStart, NULL);
+	add_menu_entry(menu, "selend", "Selection End",
+		       DoJumpSelEnd, NULL);
 
-		/* Search - Menue */
-		XtSetArg(arglist[0], XtNlabel, translate("Search"));
-		XtSetArg(arglist[1], XtNmenuName, "searchmenu");
-		XtCreateManagedWidget("search_menu_button",
-			     siagMenuButtonWidgetClass, menubox, arglist, 2);
+	/* Search - Menue */
+	XtSetArg(arglist[0], XtNlabel, _("Search"));
+	XtSetArg(arglist[1], XtNmenu_name, "searchmenu");
+	XtCreateManagedWidget("search_menu_button",
+		     mwMBButtonObjectClass, menubox, arglist, 2);
 
-		menu = XtCreatePopupShell("searchmenu", simpleMenuWidgetClass, parent, NULL, 0);
+	menu = XtCreatePopupShell("searchmenu",
+		mwMenuWidgetClass, menubox, NULL, 0);
 
-		add_menu_entry(menu, "search", "Search", DoSearchSearch, NULL);
-		add_menu_entry(menu, "search_selection", "Search Selection",
-			       DoSearchSearchselection, NULL);
+	add_menu_entry(menu, "search", "Search", DoSearchSearch, NULL);
+	add_menu_entry(menu, "search_selection", "Search Selection",
+		       DoSearchSearchselection, NULL);
 
-		XtCreateManagedWidget("line", smeLineObjectClass, menu, NULL, 0);
+	XtVaCreateManagedWidget("line",
+		mwLineMEObjectClass, menu,
+		(char *)0);
 
-		add_menu_entry(menu, "replace", "Replace", DoSearchReplace, NULL);
-		add_menu_entry(menu, "replace_selection", "Replace Selection",
-			       DoSearchReplaceselection, NULL);
+	add_menu_entry(menu, "replace", "Replace", DoSearchReplace, NULL);
+	add_menu_entry(menu, "replace_selection", "Replace Selection",
+		       DoSearchReplaceselection, NULL);
 
-		XtCreateManagedWidget("line", smeLineObjectClass, menu, NULL, 0);
+	XtCreateManagedWidget("line", mwLineMEObjectClass, menu, NULL, 0);
 
-		add_menu_entry(menu, "find_bracket", "Find Bracket",
-			       DoSearchFindbracket, NULL);
-		add_menu_entry(menu, "check_brackets", "Check Brackets",
-			       DoSearchCheckbrackets, NULL);
+	add_menu_entry(menu, "find_bracket", "Find Bracket",
+		       DoSearchFindbracket, NULL);
+	add_menu_entry(menu, "check_brackets", "Check Brackets",
+		       DoSearchCheckbrackets, NULL);
 
-		/* Spezial - Menue */
-		XtSetArg(arglist[0], XtNlabel, translate("Special"));
-		XtSetArg(arglist[1], XtNmenuName, "spezialmenu");
-		XtCreateManagedWidget("spezial_menu_button",
-			     siagMenuButtonWidgetClass, menubox, arglist, 2);
+	/* Spezial - Menue */
+	XtSetArg(arglist[0], XtNlabel, _("Special"));
+	XtSetArg(arglist[1], XtNmenu_name, "spezialmenu");
+	XtCreateManagedWidget("spezial_menu_button",
+		     mwMBButtonObjectClass, menubox, arglist, 2);
 
-		menu = XtCreatePopupShell("spezialmenu", simpleMenuWidgetClass, parent, NULL, 0);
+	menu = XtCreatePopupShell("spezialmenu",
+		mwMenuWidgetClass, menubox, NULL, 0);
 
-		add_menu_entry(menu, "options", "Options", DoSpezialOptions, NULL);
-		add_menu_entry(menu, "call_sed", "Call Sed", DoSpezialCallSed, NULL);
-		add_menu_entry(menu, "help", "Help", DoSpezialHelp, NULL);
-		add_menu_entry(menu, "about", "About", DoSpezialAbout, NULL);
+	add_menu_entry(menu, "options", "Options", DoSpezialOptions, NULL);
+	add_menu_entry(menu, "call_sed", "Call Sed", DoSpezialCallSed, NULL);
 
-		/* Commands - Menue */
-		XtSetArg(arglist[0], XtNlabel, translate("Commands"));
-		XtSetArg(arglist[1], XtNmenuName, "commandsmenu");
-		XtCreateManagedWidget("commands_menu_button",
-			     siagMenuButtonWidgetClass, menubox, arglist, 2);
+	/* Commands - Menue */
+	XtSetArg(arglist[0], XtNlabel, _("Commands"));
+	XtSetArg(arglist[1], XtNmenu_name, "commandsmenu");
+	XtCreateManagedWidget("commands_menu_button",
+		     mwMBButtonObjectClass, menubox, arglist, 2);
 
-		menu = XtCreatePopupShell("commandsmenu", simpleMenuWidgetClass, parent, NULL, 0);
+	menu = XtCreatePopupShell("commandsmenu",
+		mwMenuWidgetClass, menubox, NULL, 0);
 
-		add_menu_entry(menu, "command0", "Command", DoCommand0, NULL);
+	add_menu_entry(menu, "command0", "Command", DoCommand0, NULL);
 
-		/* Parse User Commands */
-		pos = app_resources.commands;
+	/* Parse User Commands */
+	pos = app_resources.commands;
 
-		while (pos != NULL) {
-			pos2 = index(pos, '\t');
-			if (pos2 == NULL)
-				break;
+	while (pos != NULL) {
+		pos2 = index(pos, '\t');
+		if (pos2 == NULL)
+			break;
+		*pos2 = '\0';
+		pos2++;
+		cname = pos;
+		pos = pos2;
+		pos2 = index(pos, '\n');
+		if (pos2 != NULL) {
 			*pos2 = '\0';
 			pos2++;
-			cname = pos;
-			pos = pos2;
-			pos2 = index(pos, '\n');
-			if (pos2 != NULL) {
-				*pos2 = '\0';
-				pos2++;
-			}
-			XtSetArg(arglist[0], XtNlabel, translate(cname));
-			widget = XtCreateManagedWidget(cname, smeBSBObjectClass, menu, arglist, 1);
-			XtAddCallback(widget, XtNcallback, command_exec, pos);
-			pos = pos2;
 		}
-
-		/* Pipes - Menue */
-		XtSetArg(arglist[0], XtNlabel, translate("Pipes"));
-		XtSetArg(arglist[1], XtNmenuName, "pipesmenu");
-		XtCreateManagedWidget("pipes_menu_button",
-			     siagMenuButtonWidgetClass, menubox, arglist, 2);
-
-		menu = XtCreatePopupShell("pipesmenu", simpleMenuWidgetClass, parent, NULL, 0);
-
-		add_menu_entry(menu, "pipe0", "Pipe", DoPipe0, NULL);
-
-		/* Parse User Pipes */
-		pos = app_resources.pipes;
-
-		while (pos != NULL) {
-			pos2 = index(pos, '\t');
-			if (pos2 == NULL)
-				break;
-			*pos2 = '\0';
-			pos2++;
-			cname = pos;
-			pos = pos2;
-			pos2 = index(pos, '\n');
-			if (pos2 != NULL) {
-				*pos2 = '\0';
-				pos2++;
-			}
-			XtSetArg(arglist[0], XtNlabel, translate(cname));
-			widget = XtCreateManagedWidget(cname, smeBSBObjectClass, menu, arglist, 1);
-			XtAddCallback(widget, XtNcallback, pipe_exec, pos);
-			pos = pos2;
-		}
-
-		/* Dirty Button */
-		savedbitmap = XCreateBitmapFromData(CurDpy, RootWindow(CurDpy, DefaultScreen(CurDpy)),
-				  saved_bits, saved_width, saved_height);
-		notsavedbitmap = XCreateBitmapFromData(CurDpy, RootWindow(CurDpy, DefaultScreen(CurDpy)),
-			 notsaved_bits, notsaved_width, notsaved_height);
-		XtSetArg(arglist[0], XtNbitmap, savedbitmap);
-		XtSetArg(arglist[1], XtNborderWidth, 0);
-		dirtylabel = XtCreateManagedWidget("dirty",
-				  labelWidgetClass, menubox, arglist, 2);
-
-		/* Menue Ending */
-		XtSetArg(arglist[0], XtNlabel, translate("-Insert-"));
-		modelabel = XtCreateManagedWidget("editmode",
-				commandWidgetClass, menubox, arglist, 1);
-		XtAddCallback(modelabel, XtNcallback, xedtoggleoverwrite, 0);
+		widget = XtVaCreateManagedWidget(cname,
+			mwLabelMEObjectClass, menu,
+			XtNlabel, _(cname),
+			(char *)0);
+		XtAddCallback(widget, XtNcallback, command_exec, pos);
+		pos = pos2;
 	}
 
+	/* Pipes - Menue */
+	XtSetArg(arglist[0], XtNlabel, _("Pipes"));
+	XtSetArg(arglist[1], XtNmenu_name, "pipesmenu");
+	XtCreateManagedWidget("pipes_menu_button",
+		     mwMBButtonObjectClass, menubox, arglist, 2);
+
+	menu = XtCreatePopupShell("pipesmenu",
+		mwMenuWidgetClass, menubox, NULL, 0);
+
+	add_menu_entry(menu, "pipe0", "Pipe", DoPipe0, NULL);
+
+	/* Parse User Pipes */
+	pos = app_resources.pipes;
+
+	while (pos != NULL) {
+		pos2 = index(pos, '\t');
+		if (pos2 == NULL)
+			break;
+		*pos2 = '\0';
+		pos2++;
+		cname = pos;
+		pos = pos2;
+		pos2 = index(pos, '\n');
+		if (pos2 != NULL) {
+			*pos2 = '\0';
+			pos2++;
+		}
+		XtSetArg(arglist[0], XtNlabel, _(cname));
+		widget = XtCreateManagedWidget(cname,
+			mwLabelMEObjectClass, menu, arglist, 1);
+		XtAddCallback(widget, XtNcallback, pipe_exec, pos);
+		pos = pos2;
+	}
+
+	/* Help menu */
+	XtSetArg(arglist[0], XtNlabel, _("Help"));
+	XtSetArg(arglist[1], XtNmenu_name, "helpmenu");
+	XtSetArg(arglist[2], XtNgravitation, XtCright);
+	XtCreateManagedWidget("help_menu_button",
+		     mwMBButtonObjectClass, menubox, arglist, 3);
+
+	menu = XtCreatePopupShell("helpmenu",
+		mwMenuWidgetClass, menubox, NULL, 0);
+
+	add_menu_entry(menu, "help", "Help", DoSpezialHelp, NULL);
+
+	XtVaCreateManagedWidget("line",
+		mwLineMEObjectClass, menu,
+		(char *)0);
+
+	add_menu_entry(menu, "about_xedplus", "About XedPlus...",
+		DoSpezialAboutXedplus, NULL);
+	add_menu_entry(menu, "about_siagoffice", "About Siag Office...",
+		DoSpezialAboutSiagOffice, NULL);
+
+
 	create_toolbar(toolbox);
 
-	num_args = 0;
-	if (filename != NULL) {
-		XtSetArg(arglist[num_args], XtNlabel, filename);
-		num_args++;
-	}
-	XtSetArg(arglist[num_args], XtNlabel, translate("no file yet"));
-	num_args++;
-	labelwindow = XtCreateManagedWidget("labelWindow",
-			    labelWidgetClass, parent, arglist, num_args);
+	statusbox = XtVaCreateManagedWidget("statusbox",
+		mwRudegridWidgetClass, parent,
+		(char *)0);
+	labelwindow = XtVaCreateManagedWidget("labelWindow",
+		labelWidgetClass, statusbox /*parent*/,
+		XtNlabel, filename?filename:_("no file yet"),
+		(char *)0);
+
+	dirtylabel = XtVaCreateManagedWidget("dirty",
+		labelWidgetClass, statusbox /*toolbox*/,
+		XtNlabel, "",
+		(char *)0);
 
 	num_args = 0;
 	inserttrans = XtParseTranslationTable(app_resources.inserttranslations);
@@ -1152,7 +1162,6 @@ int main(int argc, char **argv)
 	char c;
 	char workdir[MAXPATHLEN], completename[MAXPATHLEN];
 	XtAppContext app_context;
-	unsigned long highlight_color, unhighlight_color;
 
 	common_init("XedPlus %s. No Warranty.");
 
@@ -1163,23 +1172,20 @@ int main(int argc, char **argv)
 				fallback_resources,
 				(char *) 0);
 
+	theme_init(XtDisplay(top));
+
 	file_s = init_file_select(top);
 
 	XtGetApplicationResources(top, &app_resources, resources,
 				  XtNumber(resources), NULL, 0);
 
 	topbox = XtVaCreateManagedWidget("topbox",
-					 rudegridWidgetClass, top,
+					 mwRudegridWidgetClass, top,
 					 (char *) 0);
 
-	highlight_color = WhitePixel(XtDisplay(top),
-				     DefaultScreen(XtDisplay(top)));
-	XtVaGetValues(top,
-		      XtNbackground, &unhighlight_color,
-		      (char *) 0);
-	tooltip_init(top, highlight_color, unhighlight_color);
+	MwHighlightInit(top);
 	tooltip = XtVaCreatePopupShell("tooltip",
-		tooltipWidgetClass, top,
+		mwTooltipWidgetClass, top,
 		(char *)0);
 
 	CurDpy = XtDisplay(top);
@@ -1231,7 +1237,7 @@ int main(int argc, char **argv)
 	XDefineCursor(XtDisplay(top), XtWindow(top),
 		      XCreateFontCursor(XtDisplay(top), XC_left_ptr));
 
-	icon_set(top, xedplus_xpm);
+	MwSetIcon(top, xedplus_xpm);
 
 	XtAddEventHandler(top, NoEventMask, True, wm_delete_event, NULL);
 	XtAddEventHandler(line_popup, NoEventMask, True, wm_delete_event, NULL);
@@ -1261,10 +1267,10 @@ int main(int argc, char **argv)
 			  (XtPointer) XtInputReadMask, pipe_input, NULL);
 	}
 	/* Drag And Drop protocol stuff */
-	DndInitialize(top);
-	DndRegisterIconDrop(FileDropHandler);
-	DndRegisterDragWidget(labelwindow, FileDragHandler, NULL);
-	DndRegisterDropWidget(labelwindow, FileDropHandler, NULL);
+	MwDndInitialize(top);
+	MwDndRegisterIconDrop(FileDropHandler);
+	MwDndRegisterDragWidget(labelwindow, FileDragHandler, NULL);
+	MwDndRegisterDropWidget(labelwindow, FileDropHandler, NULL);
 
 	XtAppMainLoop(app_context);
 	return EXIT_SUCCESS;
