@@ -33,11 +33,11 @@
 #include <X11/Xmu/Xmu.h>
 #endif
 
+#include "Files.h"
+
 #include "../common/common.h"
 #include "../xcommon/xcommon.h"
-#include "../xcommon/Tooltip.h"
-
-#include "Files.h"
+#include <Mowitz/Mowitz.h>
 
 #define XtRDisplayType "DisplayType"
 #define XtRSortType "SortType"
@@ -110,7 +110,7 @@ static XtResource resource_list[] = {
       XtOffsetOf(Resources, confirm_deletes), XtRImmediate, (XtPointer) True },
   { "confirmDeleteFolder", "Confirm", XtRBoolean, sizeof(Boolean),
       XtOffsetOf(Resources, confirm_delete_folder), XtRImmediate,
-      (XtPointer) True },
+      (XtPointer) False },
   { "confirmMoves", "Confirm", XtRBoolean, sizeof(Boolean),
       XtOffsetOf(Resources, confirm_moves), XtRImmediate, (XtPointer) False },
   { "confirmCopies", "Confirm", XtRBoolean, sizeof(Boolean),
@@ -169,6 +169,7 @@ static XtResource resource_list[] = {
 static String fallback_resources[] = {
 #include "../xcommon/xcommon-ad.h"
 #include "../xcommon/dialogs-ad.h"
+#include "../xcommon/nws-ad.h"
 #include "xfiler-ad.h"
 APPNAME "*bitmapPath: "PIXDIR,
 APPNAME "*pixmapPath: "PIXDIR,
@@ -398,7 +399,6 @@ int main(int argc, char *argv[])
   XtArgVal iconic;
   Window files;
   Display *dpy;
-	unsigned long highlight_color, unhighlight_color;
 	char cwd[1024];
   
   progname = argv[0];
@@ -410,7 +410,7 @@ int main(int argc, char *argv[])
   if ((s = getenv("HOME")))
     strcpy(user.home,s);
   else
-    getwd(user.home);
+    getcwd(user.home, MAXPATHLEN);
 
   if ((s = getenv("SHELL")))
     strcpy(user.shell,s);
@@ -428,6 +428,8 @@ int main(int argc, char *argv[])
 			     &argc, argv, fallback_resources, shell_args,
 			     XtNumber(shell_args) );
 
+  theme_init(XtDisplay(toplevel));
+
   /* make sure we can close-on-exec the display connection */
   if (fcntl(ConnectionNumber(XtDisplay(toplevel)), F_SETFD, 1) == -1)
     abortXfm("Couldn't mark display connection as close-on-exec");
@@ -452,13 +454,9 @@ int main(int argc, char *argv[])
 			(Cardinal) 0, XtCacheAll, NULL);
 #endif /* XPM */
 
-	highlight_color = WhitePixel(dpy, DefaultScreen(dpy));
-	XtVaGetValues(toplevel,
-		XtNbackground, &unhighlight_color,
-		(char *)0);
-	tooltip_init(toplevel, highlight_color, unhighlight_color);
+	MwHighlightInit(toplevel);
 	tooltip = XtVaCreatePopupShell("tooltip",
-		tooltipWidgetClass, toplevel,
+		mwTooltipWidgetClass, toplevel,
 		(char *)0);
 
   /* get the application resources */
@@ -554,9 +552,9 @@ int main(int argc, char *argv[])
     XtAppAddTimeOut(app_context, resources.update_interval, timeoutCb, NULL);
 
   /* Drag and drop stuff */
-  DndInitialize(toplevel);
-  DndRegisterRootDrop(RootDropEventHandler);
-  DndMultipleShells();
+  MwDndInitialize(toplevel);
+  MwDndRegisterRootDrop(RootDropEventHandler);
+  MwDndMultipleShells();
 	
   /* collect & process events */
   XtAppMainLoop(app_context);
