@@ -1,6 +1,6 @@
 /*
    Pathetic Writer
-   Copyright (C) 1997-1999  Ulric Eriksson <ulric@edu.stockholm.se>
+   Copyright (C) 1997-2000  Ulric Eriksson <ulric@siag.nu>
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -42,7 +42,7 @@
 #include <X11/Xmu/StdSel.h>
 
 #include "../common/common.h"
-#include "../common/cmalloc.h"
+#include <Mowitz/Mowitz.h>
 
 #include "../pw/pw.h"
 #include "xpw.h"
@@ -90,39 +90,13 @@ Boolean convert_proc(Widget w,
 		*length_return = lr;
 		*value_return = XtMalloc(*length_return);
 		memcpy(*value_return, data, *length_return);
-		cfree(data);
-#if 0
-		char *data;
-		int s = wl->bsht;
-		sheet *st = wl->buf->sht;
-
-		/* Use a fixed size buffer for now */
-		*length_return = 32000;
-
-		data = XtMalloc(*length_return);
-		pack_selection(wl->buf, data, s,
-				st[s].blku.row, st[s].blku.col,
-				st[s].blkl.row, st[s].blkl.col);
-
-		*value_return = data;
-#endif
+		MwFree(data);
 		*type_return = target_atom;
 
 		*format_return = 8;
 		return True;
 	} else if (*target == XA_STRING) {
 		/* handle string selections (from outside PW) */
-#if 0
-		char *data;
-		int s = wl->bsht;
-		sheet *st = wl->buf->sht;
-		*length_return = 32000;
-		data = XtMalloc(*length_return);
-		pack_string_selection(wl->buf, data, s,
-			st[s].blku.row, st[s].blku.col,
-			st[s].blkl.row, st[s].blkl.col);
-		*value_return = data;
-#endif
 		char *data = pack_area(wl->buf, wl->bsht,
 			block_upper(wl).row, block_upper(wl).col,
 			block_lower(wl).row, block_lower(wl).col,
@@ -132,7 +106,7 @@ Boolean convert_proc(Widget w,
 */
 		*value_return = XtMalloc(*length_return);
 		memcpy(*value_return, data, *length_return);
-		cfree(data);
+		MwFree(data);
 
 		*type_return = XA_STRING;
 		*format_return = 8;
@@ -168,7 +142,7 @@ void lose_ownership_proc(Widget w, Atom *selection)
 
 /* ---
 */
-void transfer_done_proc(void)
+void transfer_done_proc(Widget w, Atom *a, Atom *b)
 {
 	; /* no need to do anything at all */
 }
