@@ -1,6 +1,6 @@
 /*
    Siag, Scheme In A Grid
-   Copyright (C) 1996-1998  Ulric Eriksson <ulric@edu.stockholm.se>
+   Copyright (C) 1996-1998  Ulric Eriksson <ulric@siag.nu>
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -53,7 +53,7 @@
 #include <X11/Xmu/Atoms.h>
 #include <X11/Xmu/StdSel.h>
 
-#include "../common/cmalloc.h"
+#include <Mowitz/Mowitz.h>
 #include "../common/common.h"
 #include "../siag/calc.h"
 #include "../siag/selection.h"
@@ -101,7 +101,7 @@ Boolean convert_proc(Widget w,
 		*length_return = lr;
 		*value_return = XtMalloc(*length_return);
 		memcpy(*value_return, data, *length_return);
-		cfree(data);
+		MwFree(data);
 
 		*type_return = target_atom;
 
@@ -127,7 +127,6 @@ Boolean convert_proc(Widget w,
 				length_return, format_return))
 			return True;
 		else {
-			XtWarning("Siag: unsupported selection type\n");
 			return False;
 		}
 	}
