@@ -1,6 +1,6 @@
 /*
    Siag, Scheme In A Grid
-   Copyright (C) 1996-1999  Ulric Eriksson <ulric@edu.stockholm.se>
+   Copyright (C) 1996-2002  Ulric Eriksson <ulric@siag.nu>
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -23,14 +23,11 @@
 #include <X11/Intrinsic.h>
 #include <X11/StringDefs.h>
 #include <X11/Xatom.h>
+#include <Mowitz/Mowitz.h>
 #include "../siod/siod.h"
 #include "../common/common.h"
-#include "../common/cmalloc.h"
-#include "../common/fonts.h"
-#include "../xcommon/xfonts.h"
-#include "../xcommon/dialogs.h"
 #include "../xcommon/embed.h"
-#include "../xcommon/filesel.h"
+#include "../xcommon/xcommon.h"
 #include "../siag/calc.h"
 #include "xsiag.h"
 
@@ -39,37 +36,46 @@
 
 /* ---
 */
-int select_file(char *path, char *name, char *patterns[], char *fmt)
+int select_file(char *path, char *name, char *patterns[], char *fmt, int e)
 {
 	char extra[1024];
 	sprintf(extra, "Home=%s:Examples=%s/siag/examples",
 		getenv("HOME"), docdir);
-	return fsel_input(topLevel, path, name, patterns, fmt,
-		extra);
+	return MwFileselInput(topLevel, path, name, patterns, fmt, extra, e);
 }
 
 /* ---
 */
 int alert_box(char *text, char *buttons[], int nbuttons)
 {
-	return alertbox(topLevel, text, buttons, nbuttons);
+	return MwAlertBox(topLevel, text, buttons, nbuttons);
+}
+
+void about_box(char *text)
+{
+	MwAboutBox(topLevel, "siag.xpm", text);
+}
+
+void about_siag(void)
+{
+	MwAboutSiag(topLevel);
 }
 
 /* ---
 */
 int select_from_list(char *text, char *choices[], int nchoices)
 {
-	return listsel(topLevel, text, choices, nchoices);
+	return MwListBox(topLevel, text, choices, nchoices);
 }
 
 /* ---
 */
 void error_box(char *message)
 {
-	errorbox(topLevel, message);
+	MwErrorBox(topLevel, message);
 }
 
-#ifdef GUILE
+#ifdef HAVE_LIBGUILE
 static void execute_guile_action(Widget w, XEvent * event,
                            String * params, Cardinal * num_params)
 {
@@ -104,7 +110,7 @@ static void execute_siod_action(Widget w, XEvent * event,
         exec_expr(siod_interpreter, b);
 }
 
-#ifdef TCL
+#ifdef HAVE_LIBTCL
 static void execute_tcl_action(Widget w, XEvent *event,
                            String *params, Cardinal *num_params)
 {
@@ -122,11 +128,11 @@ static void execute_tcl_action(Widget w, XEvent *event,
 
 static XtActionsRec actions[] =
 {
-#ifdef GUILE
+#ifdef HAVE_LIBGUILE
         {"guile", execute_guile_action},
 #endif
 	{"execute", execute_siod_action},
-#ifdef TCL
+#ifdef HAVE_LIBTCL
 	{"tcl", execute_tcl_action}
 #endif
 };
@@ -158,7 +164,7 @@ static LISP fit_block_width(void)
         int r, c, text_width;
         char *p;
 	int s;
-	rich_char *rc;
+	MwRichchar *rc;
 	buffer *buf = w_list->buf;
 
         if (block_upper(w_list).row < 1 || block_upper(w_list).col < 1 ||
@@ -169,12 +175,13 @@ static LISP fit_block_width(void)
         for (c = block_upper(w_list).col; c <= block_lower(w_list).col; c++) {
                 set_width(buf, s, c, 10);
                 for (r = block_upper(w_list).row; r <= block_lower(w_list).row; r++) {
+			if (r > buf->sht[s].alloc_lines) continue;
                         p = ret_pvalue(NULL, buf, s, r, c, -1);
-			rc = rc_makerich(p, ret_format(buf, s, r, c));
-			text_width = rc_strwidth(rc, -1)+10;
+			rc = MwRcMakerich(p, ret_format(buf, s, r, c));
+			text_width = MwRcStrwidth(rc, -1)+10;
                         if (text_width > cell_width(buf, s, c))
                                 set_width(buf, s, c, text_width);
-			cfree(rc);
+			MwFree(rc);
                 }
         }
         pr_scr_flag = 1;
@@ -183,9 +190,11 @@ static LISP fit_block_width(void)
 
 static LISP fit_block_height(void)
 {
-        int r, c, font_index, text_height;
+        int r, c, text_height;
         char *p;
 	int s;
+	MwRichchar *rc;
+	buffer *buf = w_list->buf;
 
         if (block_upper(w_list).row < 1 || block_upper(w_list).col < 1 ||
                 block_lower(w_list).row < 1 || block_lower(w_list).col < 1)
@@ -193,13 +202,15 @@ static LISP fit_block_height(void)
 
 	s = w_list->sht;
         for (r = block_upper(w_list).row; r <= block_lower(w_list).row; r++) {
-                set_height(buffer_of_window(w_list), s, r, 10);
+                set_height(buf, s, r, 10);
                 for (c = block_upper(w_list).col; c <= block_lower(w_list).col; c++) {
-                        font_index = ret_font(buffer_of_window(w_list), s, r, c);
-                        p = ret_pvalue(NULL, buffer_of_window(w_list), s, r, c, -1);
-                        text_height = font_height(font_index) + 10;
-                        if (text_height > cell_height(buffer_of_window(w_list), s, r))
-                                set_height(buffer_of_window(w_list), s, r, text_height);
+			if (c > buf->sht[s].longest_line) continue;
+                        p = ret_pvalue(NULL, buf, s, r, c, -1);
+			rc = MwRcMakerich(p, ret_format(buf, s, r, c));
+			text_height = MwRcStrheight(rc, -1)+10;
+                        if (text_height > cell_height(buf, s, r))
+                                set_height(buf, s, r, text_height);
+			MwFree(rc);
                 }
         }
         pr_scr_flag = 1;
@@ -315,6 +326,7 @@ FIXME: should set sheet too
 
 static LISP set_block(void)
 {
+	Atom clipboard = XInternAtom(XtDisplay(topLevel), "CLIPBOARD", False);
 	position point = get_point(w_list);
 	position mark = get_mark(w_list);
 	w_list->bsht = w_list->sht;
@@ -342,6 +354,11 @@ static LISP set_block(void)
                 set_blku_row(w_list, -1); set_blku_col(w_list, -1);
                 set_blkl_row(w_list, -1); set_blkl_col(w_list, -1);
         }
+        if (XtOwnSelection(grid_of_window(w_list), clipboard,
+                CurrentTime, convert_proc,
+                lose_ownership_proc, NULL) == False) {
+			; /* don't worry, be happy */
+        }
 
         pr_scr_flag = TRUE;
         return NIL;
@@ -349,6 +366,7 @@ static LISP set_block(void)
 
 static LISP unset_block(void)
 {
+	Atom clipboard = XInternAtom(XtDisplay(topLevel), "CLIPBOARD", False);
 	position point = get_point(w_list);
 	position mark = get_point(w_list);
 	w_list->bsht = w_list->sht;
@@ -360,10 +378,33 @@ static LISP unset_block(void)
 	mark = get_point(w_list);
 
         XtDisownSelection(grid_of_window(w_list), XA_PRIMARY, CurrentTime);
+        XtDisownSelection(grid_of_window(w_list), clipboard, CurrentTime);
         pr_scr_flag = TRUE;
         return NIL;
 }
 
+static LISP lselect_theme(void)
+{
+	if (select_theme(topLevel)) llpr("Restart to activate theme");
+	else llpr("No theme selected");
+	return NIL;
+}
+
+static LISP ledit_theme(void)
+{
+	char cmd[1024];
+	sprintf(cmd, "cd %s/.siag; xedplus theme &", getenv("HOME"));
+	system(cmd);
+	return NIL;
+}
+
+static LISP ldelete_theme(void)
+{
+	char b[1024];
+	sprintf(b, "%s/.siag/theme", getenv("HOME"));
+	remove(b);
+	return NIL;
+}
 
 
 /* ---
@@ -383,6 +424,9 @@ void interp_startup(void)
 	init_subr_0("copy-block", copy_block);
 	init_subr_0("set-block", set_block);
 	init_subr_0("unset-block", unset_block);
+	init_subr_0("select_theme", lselect_theme);
+	init_subr_0("edit_theme", ledit_theme);
+	init_subr_0("delete_theme", ldelete_theme);
 }
 
 /* ---
@@ -396,21 +440,21 @@ this is dead wrong because it doesn't take res_x and res_y into account
 
 int ps_text_width(int index, char *s)
 {
-	return font_width(index, s);
+	return MwFontWidth(index, s);
 }
 
 /* ---
 */
 int ps_font_descent(int index)
 {
-	return font_descent(index);
+	return MwFontDescent(index);
 }
 
 /* ---
 */
 int ps_font_height(int font)
 {
-	return font_height(font);
+	return MwFontHeight(font);
 }
 
 /* ---
